# pylint: disable=missing-module-docstring, disable=too-many-lines

import PyKCS11.LowLevel

# This file is generated by "make constants"
# To not edit by hand

# redefine PKCS#11 constants
CK_TRUE = PyKCS11.LowLevel.CK_TRUE
CK_FALSE = PyKCS11.LowLevel.CK_FALSE
CK_UNAVAILABLE_INFORMATION = PyKCS11.LowLevel.CK_UNAVAILABLE_INFORMATION
CK_EFFECTIVELY_INFINITE = PyKCS11.LowLevel.CK_EFFECTIVELY_INFINITE
CK_INVALID_HANDLE = PyKCS11.LowLevel.CK_INVALID_HANDLE


# CKF constants
CKF = {}
CKF_TOKEN_PRESENT = PyKCS11.LowLevel.CKF_TOKEN_PRESENT
CKF["CKF_TOKEN_PRESENT"] = CKF_TOKEN_PRESENT
CKF[CKF_TOKEN_PRESENT] = "CKF_TOKEN_PRESENT"

CKF_REMOVABLE_DEVICE = PyKCS11.LowLevel.CKF_REMOVABLE_DEVICE
CKF["CKF_REMOVABLE_DEVICE"] = CKF_REMOVABLE_DEVICE
CKF[CKF_REMOVABLE_DEVICE] = "CKF_REMOVABLE_DEVICE"

CKF_HW_SLOT = PyKCS11.LowLevel.CKF_HW_SLOT
CKF["CKF_HW_SLOT"] = CKF_HW_SLOT
CKF[CKF_HW_SLOT] = "CKF_HW_SLOT"

CKF_RNG = PyKCS11.LowLevel.CKF_RNG
CKF["CKF_RNG"] = CKF_RNG
CKF[CKF_RNG] = "CKF_RNG"

CKF_WRITE_PROTECTED = PyKCS11.LowLevel.CKF_WRITE_PROTECTED
CKF["CKF_WRITE_PROTECTED"] = CKF_WRITE_PROTECTED
CKF[CKF_WRITE_PROTECTED] = "CKF_WRITE_PROTECTED"

CKF_LOGIN_REQUIRED = PyKCS11.LowLevel.CKF_LOGIN_REQUIRED
CKF["CKF_LOGIN_REQUIRED"] = CKF_LOGIN_REQUIRED
CKF[CKF_LOGIN_REQUIRED] = "CKF_LOGIN_REQUIRED"

CKF_USER_PIN_INITIALIZED = PyKCS11.LowLevel.CKF_USER_PIN_INITIALIZED
CKF["CKF_USER_PIN_INITIALIZED"] = CKF_USER_PIN_INITIALIZED
CKF[CKF_USER_PIN_INITIALIZED] = "CKF_USER_PIN_INITIALIZED"

CKF_RESTORE_KEY_NOT_NEEDED = PyKCS11.LowLevel.CKF_RESTORE_KEY_NOT_NEEDED
CKF["CKF_RESTORE_KEY_NOT_NEEDED"] = CKF_RESTORE_KEY_NOT_NEEDED
CKF[CKF_RESTORE_KEY_NOT_NEEDED] = "CKF_RESTORE_KEY_NOT_NEEDED"

CKF_CLOCK_ON_TOKEN = PyKCS11.LowLevel.CKF_CLOCK_ON_TOKEN
CKF["CKF_CLOCK_ON_TOKEN"] = CKF_CLOCK_ON_TOKEN
CKF[CKF_CLOCK_ON_TOKEN] = "CKF_CLOCK_ON_TOKEN"

CKF_PROTECTED_AUTHENTICATION_PATH = PyKCS11.LowLevel.CKF_PROTECTED_AUTHENTICATION_PATH
CKF["CKF_PROTECTED_AUTHENTICATION_PATH"] = CKF_PROTECTED_AUTHENTICATION_PATH
CKF[CKF_PROTECTED_AUTHENTICATION_PATH] = "CKF_PROTECTED_AUTHENTICATION_PATH"

CKF_DUAL_CRYPTO_OPERATIONS = PyKCS11.LowLevel.CKF_DUAL_CRYPTO_OPERATIONS
CKF["CKF_DUAL_CRYPTO_OPERATIONS"] = CKF_DUAL_CRYPTO_OPERATIONS
CKF[CKF_DUAL_CRYPTO_OPERATIONS] = "CKF_DUAL_CRYPTO_OPERATIONS"

CKF_TOKEN_INITIALIZED = PyKCS11.LowLevel.CKF_TOKEN_INITIALIZED
CKF["CKF_TOKEN_INITIALIZED"] = CKF_TOKEN_INITIALIZED
CKF[CKF_TOKEN_INITIALIZED] = "CKF_TOKEN_INITIALIZED"

CKF_SECONDARY_AUTHENTICATION = PyKCS11.LowLevel.CKF_SECONDARY_AUTHENTICATION
CKF["CKF_SECONDARY_AUTHENTICATION"] = CKF_SECONDARY_AUTHENTICATION
CKF[CKF_SECONDARY_AUTHENTICATION] = "CKF_SECONDARY_AUTHENTICATION"

CKF_USER_PIN_COUNT_LOW = PyKCS11.LowLevel.CKF_USER_PIN_COUNT_LOW
CKF["CKF_USER_PIN_COUNT_LOW"] = CKF_USER_PIN_COUNT_LOW
CKF[CKF_USER_PIN_COUNT_LOW] = "CKF_USER_PIN_COUNT_LOW"

CKF_USER_PIN_FINAL_TRY = PyKCS11.LowLevel.CKF_USER_PIN_FINAL_TRY
CKF["CKF_USER_PIN_FINAL_TRY"] = CKF_USER_PIN_FINAL_TRY
CKF[CKF_USER_PIN_FINAL_TRY] = "CKF_USER_PIN_FINAL_TRY"

CKF_USER_PIN_LOCKED = PyKCS11.LowLevel.CKF_USER_PIN_LOCKED
CKF["CKF_USER_PIN_LOCKED"] = CKF_USER_PIN_LOCKED
CKF[CKF_USER_PIN_LOCKED] = "CKF_USER_PIN_LOCKED"

CKF_USER_PIN_TO_BE_CHANGED = PyKCS11.LowLevel.CKF_USER_PIN_TO_BE_CHANGED
CKF["CKF_USER_PIN_TO_BE_CHANGED"] = CKF_USER_PIN_TO_BE_CHANGED
CKF[CKF_USER_PIN_TO_BE_CHANGED] = "CKF_USER_PIN_TO_BE_CHANGED"

CKF_SO_PIN_COUNT_LOW = PyKCS11.LowLevel.CKF_SO_PIN_COUNT_LOW
CKF["CKF_SO_PIN_COUNT_LOW"] = CKF_SO_PIN_COUNT_LOW
CKF[CKF_SO_PIN_COUNT_LOW] = "CKF_SO_PIN_COUNT_LOW"

CKF_SO_PIN_FINAL_TRY = PyKCS11.LowLevel.CKF_SO_PIN_FINAL_TRY
CKF["CKF_SO_PIN_FINAL_TRY"] = CKF_SO_PIN_FINAL_TRY
CKF[CKF_SO_PIN_FINAL_TRY] = "CKF_SO_PIN_FINAL_TRY"

CKF_SO_PIN_LOCKED = PyKCS11.LowLevel.CKF_SO_PIN_LOCKED
CKF["CKF_SO_PIN_LOCKED"] = CKF_SO_PIN_LOCKED
CKF[CKF_SO_PIN_LOCKED] = "CKF_SO_PIN_LOCKED"

CKF_SO_PIN_TO_BE_CHANGED = PyKCS11.LowLevel.CKF_SO_PIN_TO_BE_CHANGED
CKF["CKF_SO_PIN_TO_BE_CHANGED"] = CKF_SO_PIN_TO_BE_CHANGED
CKF[CKF_SO_PIN_TO_BE_CHANGED] = "CKF_SO_PIN_TO_BE_CHANGED"

CKF_ERROR_STATE = PyKCS11.LowLevel.CKF_ERROR_STATE
CKF["CKF_ERROR_STATE"] = CKF_ERROR_STATE
CKF[CKF_ERROR_STATE] = "CKF_ERROR_STATE"

CKF_ARRAY_ATTRIBUTE = PyKCS11.LowLevel.CKF_ARRAY_ATTRIBUTE
CKF["CKF_ARRAY_ATTRIBUTE"] = CKF_ARRAY_ATTRIBUTE
CKF[CKF_ARRAY_ATTRIBUTE] = "CKF_ARRAY_ATTRIBUTE"


# CKU constants
CKU = {}
CKU_SO = PyKCS11.LowLevel.CKU_SO
CKU["CKU_SO"] = CKU_SO
CKU[CKU_SO] = "CKU_SO"

CKU_USER = PyKCS11.LowLevel.CKU_USER
CKU["CKU_USER"] = CKU_USER
CKU[CKU_USER] = "CKU_USER"

CKU_CONTEXT_SPECIFIC = PyKCS11.LowLevel.CKU_CONTEXT_SPECIFIC
CKU["CKU_CONTEXT_SPECIFIC"] = CKU_CONTEXT_SPECIFIC
CKU[CKU_CONTEXT_SPECIFIC] = "CKU_CONTEXT_SPECIFIC"


# CKS constants
CKS = {}
CKS_RO_PUBLIC_SESSION = PyKCS11.LowLevel.CKS_RO_PUBLIC_SESSION
CKS["CKS_RO_PUBLIC_SESSION"] = CKS_RO_PUBLIC_SESSION
CKS[CKS_RO_PUBLIC_SESSION] = "CKS_RO_PUBLIC_SESSION"

CKS_RO_USER_FUNCTIONS = PyKCS11.LowLevel.CKS_RO_USER_FUNCTIONS
CKS["CKS_RO_USER_FUNCTIONS"] = CKS_RO_USER_FUNCTIONS
CKS[CKS_RO_USER_FUNCTIONS] = "CKS_RO_USER_FUNCTIONS"

CKS_RW_PUBLIC_SESSION = PyKCS11.LowLevel.CKS_RW_PUBLIC_SESSION
CKS["CKS_RW_PUBLIC_SESSION"] = CKS_RW_PUBLIC_SESSION
CKS[CKS_RW_PUBLIC_SESSION] = "CKS_RW_PUBLIC_SESSION"

CKS_RW_USER_FUNCTIONS = PyKCS11.LowLevel.CKS_RW_USER_FUNCTIONS
CKS["CKS_RW_USER_FUNCTIONS"] = CKS_RW_USER_FUNCTIONS
CKS[CKS_RW_USER_FUNCTIONS] = "CKS_RW_USER_FUNCTIONS"

CKS_RW_SO_FUNCTIONS = PyKCS11.LowLevel.CKS_RW_SO_FUNCTIONS
CKS["CKS_RW_SO_FUNCTIONS"] = CKS_RW_SO_FUNCTIONS
CKS[CKS_RW_SO_FUNCTIONS] = "CKS_RW_SO_FUNCTIONS"


# CKF constants
CKF = {}
CKF_RW_SESSION = PyKCS11.LowLevel.CKF_RW_SESSION
CKF["CKF_RW_SESSION"] = CKF_RW_SESSION
CKF[CKF_RW_SESSION] = "CKF_RW_SESSION"

CKF_SERIAL_SESSION = PyKCS11.LowLevel.CKF_SERIAL_SESSION
CKF["CKF_SERIAL_SESSION"] = CKF_SERIAL_SESSION
CKF[CKF_SERIAL_SESSION] = "CKF_SERIAL_SESSION"


# CKO constants
CKO = {}
CKO_DATA = PyKCS11.LowLevel.CKO_DATA
CKO["CKO_DATA"] = CKO_DATA
CKO[CKO_DATA] = "CKO_DATA"

CKO_CERTIFICATE = PyKCS11.LowLevel.CKO_CERTIFICATE
CKO["CKO_CERTIFICATE"] = CKO_CERTIFICATE
CKO[CKO_CERTIFICATE] = "CKO_CERTIFICATE"

CKO_PUBLIC_KEY = PyKCS11.LowLevel.CKO_PUBLIC_KEY
CKO["CKO_PUBLIC_KEY"] = CKO_PUBLIC_KEY
CKO[CKO_PUBLIC_KEY] = "CKO_PUBLIC_KEY"

CKO_PRIVATE_KEY = PyKCS11.LowLevel.CKO_PRIVATE_KEY
CKO["CKO_PRIVATE_KEY"] = CKO_PRIVATE_KEY
CKO[CKO_PRIVATE_KEY] = "CKO_PRIVATE_KEY"

CKO_SECRET_KEY = PyKCS11.LowLevel.CKO_SECRET_KEY
CKO["CKO_SECRET_KEY"] = CKO_SECRET_KEY
CKO[CKO_SECRET_KEY] = "CKO_SECRET_KEY"

CKO_HW_FEATURE = PyKCS11.LowLevel.CKO_HW_FEATURE
CKO["CKO_HW_FEATURE"] = CKO_HW_FEATURE
CKO[CKO_HW_FEATURE] = "CKO_HW_FEATURE"

CKO_DOMAIN_PARAMETERS = PyKCS11.LowLevel.CKO_DOMAIN_PARAMETERS
CKO["CKO_DOMAIN_PARAMETERS"] = CKO_DOMAIN_PARAMETERS
CKO[CKO_DOMAIN_PARAMETERS] = "CKO_DOMAIN_PARAMETERS"

CKO_MECHANISM = PyKCS11.LowLevel.CKO_MECHANISM
CKO["CKO_MECHANISM"] = CKO_MECHANISM
CKO[CKO_MECHANISM] = "CKO_MECHANISM"

CKO_OTP_KEY = PyKCS11.LowLevel.CKO_OTP_KEY
CKO["CKO_OTP_KEY"] = CKO_OTP_KEY
CKO[CKO_OTP_KEY] = "CKO_OTP_KEY"

CKO_PROFILE = PyKCS11.LowLevel.CKO_PROFILE
CKO["CKO_PROFILE"] = CKO_PROFILE
CKO[CKO_PROFILE] = "CKO_PROFILE"

CKO_VENDOR_DEFINED = PyKCS11.LowLevel.CKO_VENDOR_DEFINED

# CKH constants
CKH = {}
CKH_MONOTONIC_COUNTER = PyKCS11.LowLevel.CKH_MONOTONIC_COUNTER
CKH["CKH_MONOTONIC_COUNTER"] = CKH_MONOTONIC_COUNTER
CKH[CKH_MONOTONIC_COUNTER] = "CKH_MONOTONIC_COUNTER"

CKH_CLOCK = PyKCS11.LowLevel.CKH_CLOCK
CKH["CKH_CLOCK"] = CKH_CLOCK
CKH[CKH_CLOCK] = "CKH_CLOCK"

CKH_USER_INTERFACE = PyKCS11.LowLevel.CKH_USER_INTERFACE
CKH["CKH_USER_INTERFACE"] = CKH_USER_INTERFACE
CKH[CKH_USER_INTERFACE] = "CKH_USER_INTERFACE"

CKH_VENDOR_DEFINED = PyKCS11.LowLevel.CKH_VENDOR_DEFINED

# CKK constants
CKK = {}
CKK_RSA = PyKCS11.LowLevel.CKK_RSA
CKK["CKK_RSA"] = CKK_RSA
CKK[CKK_RSA] = "CKK_RSA"

CKK_DSA = PyKCS11.LowLevel.CKK_DSA
CKK["CKK_DSA"] = CKK_DSA
CKK[CKK_DSA] = "CKK_DSA"

CKK_DH = PyKCS11.LowLevel.CKK_DH
CKK["CKK_DH"] = CKK_DH
CKK[CKK_DH] = "CKK_DH"

CKK_ECDSA = PyKCS11.LowLevel.CKK_ECDSA
CKK["CKK_ECDSA"] = CKK_ECDSA
CKK[CKK_ECDSA] = "CKK_ECDSA"

CKK_EC = PyKCS11.LowLevel.CKK_EC
CKK["CKK_EC"] = CKK_EC
CKK[CKK_EC] = "CKK_EC"

CKK_X9_42_DH = PyKCS11.LowLevel.CKK_X9_42_DH
CKK["CKK_X9_42_DH"] = CKK_X9_42_DH
CKK[CKK_X9_42_DH] = "CKK_X9_42_DH"

CKK_KEA = PyKCS11.LowLevel.CKK_KEA
CKK["CKK_KEA"] = CKK_KEA
CKK[CKK_KEA] = "CKK_KEA"

CKK_GENERIC_SECRET = PyKCS11.LowLevel.CKK_GENERIC_SECRET
CKK["CKK_GENERIC_SECRET"] = CKK_GENERIC_SECRET
CKK[CKK_GENERIC_SECRET] = "CKK_GENERIC_SECRET"

CKK_RC2 = PyKCS11.LowLevel.CKK_RC2
CKK["CKK_RC2"] = CKK_RC2
CKK[CKK_RC2] = "CKK_RC2"

CKK_RC4 = PyKCS11.LowLevel.CKK_RC4
CKK["CKK_RC4"] = CKK_RC4
CKK[CKK_RC4] = "CKK_RC4"

CKK_DES = PyKCS11.LowLevel.CKK_DES
CKK["CKK_DES"] = CKK_DES
CKK[CKK_DES] = "CKK_DES"

CKK_DES2 = PyKCS11.LowLevel.CKK_DES2
CKK["CKK_DES2"] = CKK_DES2
CKK[CKK_DES2] = "CKK_DES2"

CKK_DES3 = PyKCS11.LowLevel.CKK_DES3
CKK["CKK_DES3"] = CKK_DES3
CKK[CKK_DES3] = "CKK_DES3"

CKK_CAST = PyKCS11.LowLevel.CKK_CAST
CKK["CKK_CAST"] = CKK_CAST
CKK[CKK_CAST] = "CKK_CAST"

CKK_CAST3 = PyKCS11.LowLevel.CKK_CAST3
CKK["CKK_CAST3"] = CKK_CAST3
CKK[CKK_CAST3] = "CKK_CAST3"

CKK_CAST5 = PyKCS11.LowLevel.CKK_CAST5
CKK["CKK_CAST5"] = CKK_CAST5
CKK[CKK_CAST5] = "CKK_CAST5"

CKK_CAST128 = PyKCS11.LowLevel.CKK_CAST128
CKK["CKK_CAST128"] = CKK_CAST128
CKK[CKK_CAST128] = "CKK_CAST128"

CKK_RC5 = PyKCS11.LowLevel.CKK_RC5
CKK["CKK_RC5"] = CKK_RC5
CKK[CKK_RC5] = "CKK_RC5"

CKK_IDEA = PyKCS11.LowLevel.CKK_IDEA
CKK["CKK_IDEA"] = CKK_IDEA
CKK[CKK_IDEA] = "CKK_IDEA"

CKK_SKIPJACK = PyKCS11.LowLevel.CKK_SKIPJACK
CKK["CKK_SKIPJACK"] = CKK_SKIPJACK
CKK[CKK_SKIPJACK] = "CKK_SKIPJACK"

CKK_BATON = PyKCS11.LowLevel.CKK_BATON
CKK["CKK_BATON"] = CKK_BATON
CKK[CKK_BATON] = "CKK_BATON"

CKK_JUNIPER = PyKCS11.LowLevel.CKK_JUNIPER
CKK["CKK_JUNIPER"] = CKK_JUNIPER
CKK[CKK_JUNIPER] = "CKK_JUNIPER"

CKK_CDMF = PyKCS11.LowLevel.CKK_CDMF
CKK["CKK_CDMF"] = CKK_CDMF
CKK[CKK_CDMF] = "CKK_CDMF"

CKK_AES = PyKCS11.LowLevel.CKK_AES
CKK["CKK_AES"] = CKK_AES
CKK[CKK_AES] = "CKK_AES"

CKK_BLOWFISH = PyKCS11.LowLevel.CKK_BLOWFISH
CKK["CKK_BLOWFISH"] = CKK_BLOWFISH
CKK[CKK_BLOWFISH] = "CKK_BLOWFISH"

CKK_TWOFISH = PyKCS11.LowLevel.CKK_TWOFISH
CKK["CKK_TWOFISH"] = CKK_TWOFISH
CKK[CKK_TWOFISH] = "CKK_TWOFISH"

CKK_SECURID = PyKCS11.LowLevel.CKK_SECURID
CKK["CKK_SECURID"] = CKK_SECURID
CKK[CKK_SECURID] = "CKK_SECURID"

CKK_HOTP = PyKCS11.LowLevel.CKK_HOTP
CKK["CKK_HOTP"] = CKK_HOTP
CKK[CKK_HOTP] = "CKK_HOTP"

CKK_ACTI = PyKCS11.LowLevel.CKK_ACTI
CKK["CKK_ACTI"] = CKK_ACTI
CKK[CKK_ACTI] = "CKK_ACTI"

CKK_CAMELLIA = PyKCS11.LowLevel.CKK_CAMELLIA
CKK["CKK_CAMELLIA"] = CKK_CAMELLIA
CKK[CKK_CAMELLIA] = "CKK_CAMELLIA"

CKK_ARIA = PyKCS11.LowLevel.CKK_ARIA
CKK["CKK_ARIA"] = CKK_ARIA
CKK[CKK_ARIA] = "CKK_ARIA"

CKK_MD5_HMAC = PyKCS11.LowLevel.CKK_MD5_HMAC
CKK["CKK_MD5_HMAC"] = CKK_MD5_HMAC
CKK[CKK_MD5_HMAC] = "CKK_MD5_HMAC"

CKK_SHA_1_HMAC = PyKCS11.LowLevel.CKK_SHA_1_HMAC
CKK["CKK_SHA_1_HMAC"] = CKK_SHA_1_HMAC
CKK[CKK_SHA_1_HMAC] = "CKK_SHA_1_HMAC"

CKK_RIPEMD128_HMAC = PyKCS11.LowLevel.CKK_RIPEMD128_HMAC
CKK["CKK_RIPEMD128_HMAC"] = CKK_RIPEMD128_HMAC
CKK[CKK_RIPEMD128_HMAC] = "CKK_RIPEMD128_HMAC"

CKK_RIPEMD160_HMAC = PyKCS11.LowLevel.CKK_RIPEMD160_HMAC
CKK["CKK_RIPEMD160_HMAC"] = CKK_RIPEMD160_HMAC
CKK[CKK_RIPEMD160_HMAC] = "CKK_RIPEMD160_HMAC"

CKK_SHA256_HMAC = PyKCS11.LowLevel.CKK_SHA256_HMAC
CKK["CKK_SHA256_HMAC"] = CKK_SHA256_HMAC
CKK[CKK_SHA256_HMAC] = "CKK_SHA256_HMAC"

CKK_SHA384_HMAC = PyKCS11.LowLevel.CKK_SHA384_HMAC
CKK["CKK_SHA384_HMAC"] = CKK_SHA384_HMAC
CKK[CKK_SHA384_HMAC] = "CKK_SHA384_HMAC"

CKK_SHA512_HMAC = PyKCS11.LowLevel.CKK_SHA512_HMAC
CKK["CKK_SHA512_HMAC"] = CKK_SHA512_HMAC
CKK[CKK_SHA512_HMAC] = "CKK_SHA512_HMAC"

CKK_SHA224_HMAC = PyKCS11.LowLevel.CKK_SHA224_HMAC
CKK["CKK_SHA224_HMAC"] = CKK_SHA224_HMAC
CKK[CKK_SHA224_HMAC] = "CKK_SHA224_HMAC"

CKK_GOSTR3410 = PyKCS11.LowLevel.CKK_GOSTR3410
CKK["CKK_GOSTR3410"] = CKK_GOSTR3410
CKK[CKK_GOSTR3410] = "CKK_GOSTR3410"

CKK_GOSTR3411 = PyKCS11.LowLevel.CKK_GOSTR3411
CKK["CKK_GOSTR3411"] = CKK_GOSTR3411
CKK[CKK_GOSTR3411] = "CKK_GOSTR3411"

CKK_GOST28147 = PyKCS11.LowLevel.CKK_GOST28147
CKK["CKK_GOST28147"] = CKK_GOST28147
CKK[CKK_GOST28147] = "CKK_GOST28147"

CKK_CHACHA20 = PyKCS11.LowLevel.CKK_CHACHA20
CKK["CKK_CHACHA20"] = CKK_CHACHA20
CKK[CKK_CHACHA20] = "CKK_CHACHA20"

CKK_POLY1305 = PyKCS11.LowLevel.CKK_POLY1305
CKK["CKK_POLY1305"] = CKK_POLY1305
CKK[CKK_POLY1305] = "CKK_POLY1305"

CKK_AES_XTS = PyKCS11.LowLevel.CKK_AES_XTS
CKK["CKK_AES_XTS"] = CKK_AES_XTS
CKK[CKK_AES_XTS] = "CKK_AES_XTS"

CKK_SHA3_224_HMAC = PyKCS11.LowLevel.CKK_SHA3_224_HMAC
CKK["CKK_SHA3_224_HMAC"] = CKK_SHA3_224_HMAC
CKK[CKK_SHA3_224_HMAC] = "CKK_SHA3_224_HMAC"

CKK_SHA3_256_HMAC = PyKCS11.LowLevel.CKK_SHA3_256_HMAC
CKK["CKK_SHA3_256_HMAC"] = CKK_SHA3_256_HMAC
CKK[CKK_SHA3_256_HMAC] = "CKK_SHA3_256_HMAC"

CKK_SHA3_384_HMAC = PyKCS11.LowLevel.CKK_SHA3_384_HMAC
CKK["CKK_SHA3_384_HMAC"] = CKK_SHA3_384_HMAC
CKK[CKK_SHA3_384_HMAC] = "CKK_SHA3_384_HMAC"

CKK_SHA3_512_HMAC = PyKCS11.LowLevel.CKK_SHA3_512_HMAC
CKK["CKK_SHA3_512_HMAC"] = CKK_SHA3_512_HMAC
CKK[CKK_SHA3_512_HMAC] = "CKK_SHA3_512_HMAC"

CKK_BLAKE2B_160_HMAC = PyKCS11.LowLevel.CKK_BLAKE2B_160_HMAC
CKK["CKK_BLAKE2B_160_HMAC"] = CKK_BLAKE2B_160_HMAC
CKK[CKK_BLAKE2B_160_HMAC] = "CKK_BLAKE2B_160_HMAC"

CKK_BLAKE2B_256_HMAC = PyKCS11.LowLevel.CKK_BLAKE2B_256_HMAC
CKK["CKK_BLAKE2B_256_HMAC"] = CKK_BLAKE2B_256_HMAC
CKK[CKK_BLAKE2B_256_HMAC] = "CKK_BLAKE2B_256_HMAC"

CKK_BLAKE2B_384_HMAC = PyKCS11.LowLevel.CKK_BLAKE2B_384_HMAC
CKK["CKK_BLAKE2B_384_HMAC"] = CKK_BLAKE2B_384_HMAC
CKK[CKK_BLAKE2B_384_HMAC] = "CKK_BLAKE2B_384_HMAC"

CKK_BLAKE2B_512_HMAC = PyKCS11.LowLevel.CKK_BLAKE2B_512_HMAC
CKK["CKK_BLAKE2B_512_HMAC"] = CKK_BLAKE2B_512_HMAC
CKK[CKK_BLAKE2B_512_HMAC] = "CKK_BLAKE2B_512_HMAC"

CKK_SALSA20 = PyKCS11.LowLevel.CKK_SALSA20
CKK["CKK_SALSA20"] = CKK_SALSA20
CKK[CKK_SALSA20] = "CKK_SALSA20"

CKK_X2RATCHET = PyKCS11.LowLevel.CKK_X2RATCHET
CKK["CKK_X2RATCHET"] = CKK_X2RATCHET
CKK[CKK_X2RATCHET] = "CKK_X2RATCHET"

CKK_EC_EDWARDS = PyKCS11.LowLevel.CKK_EC_EDWARDS
CKK["CKK_EC_EDWARDS"] = CKK_EC_EDWARDS
CKK[CKK_EC_EDWARDS] = "CKK_EC_EDWARDS"

CKK_EC_MONTGOMERY = PyKCS11.LowLevel.CKK_EC_MONTGOMERY
CKK["CKK_EC_MONTGOMERY"] = CKK_EC_MONTGOMERY
CKK[CKK_EC_MONTGOMERY] = "CKK_EC_MONTGOMERY"

CKK_HKDF = PyKCS11.LowLevel.CKK_HKDF
CKK["CKK_HKDF"] = CKK_HKDF
CKK[CKK_HKDF] = "CKK_HKDF"

CKK_VENDOR_DEFINED = PyKCS11.LowLevel.CKK_VENDOR_DEFINED

# CKC constants
CKC = {}
CKC_X_509 = PyKCS11.LowLevel.CKC_X_509
CKC["CKC_X_509"] = CKC_X_509
CKC[CKC_X_509] = "CKC_X_509"

CKC_X_509_ATTR_CERT = PyKCS11.LowLevel.CKC_X_509_ATTR_CERT
CKC["CKC_X_509_ATTR_CERT"] = CKC_X_509_ATTR_CERT
CKC[CKC_X_509_ATTR_CERT] = "CKC_X_509_ATTR_CERT"

CKC_WTLS = PyKCS11.LowLevel.CKC_WTLS
CKC["CKC_WTLS"] = CKC_WTLS
CKC[CKC_WTLS] = "CKC_WTLS"

CKC_VENDOR_DEFINED = PyKCS11.LowLevel.CKC_VENDOR_DEFINED

# CKA constants
CKA = {}
CKA_CLASS = PyKCS11.LowLevel.CKA_CLASS
CKA["CKA_CLASS"] = CKA_CLASS
CKA[CKA_CLASS] = "CKA_CLASS"

CKA_TOKEN = PyKCS11.LowLevel.CKA_TOKEN
CKA["CKA_TOKEN"] = CKA_TOKEN
CKA[CKA_TOKEN] = "CKA_TOKEN"

CKA_PRIVATE = PyKCS11.LowLevel.CKA_PRIVATE
CKA["CKA_PRIVATE"] = CKA_PRIVATE
CKA[CKA_PRIVATE] = "CKA_PRIVATE"

CKA_LABEL = PyKCS11.LowLevel.CKA_LABEL
CKA["CKA_LABEL"] = CKA_LABEL
CKA[CKA_LABEL] = "CKA_LABEL"

CKA_UNIQUE_ID = PyKCS11.LowLevel.CKA_UNIQUE_ID
CKA["CKA_UNIQUE_ID"] = CKA_UNIQUE_ID
CKA[CKA_UNIQUE_ID] = "CKA_UNIQUE_ID"

CKA_APPLICATION = PyKCS11.LowLevel.CKA_APPLICATION
CKA["CKA_APPLICATION"] = CKA_APPLICATION
CKA[CKA_APPLICATION] = "CKA_APPLICATION"

CKA_VALUE = PyKCS11.LowLevel.CKA_VALUE
CKA["CKA_VALUE"] = CKA_VALUE
CKA[CKA_VALUE] = "CKA_VALUE"

CKA_OBJECT_ID = PyKCS11.LowLevel.CKA_OBJECT_ID
CKA["CKA_OBJECT_ID"] = CKA_OBJECT_ID
CKA[CKA_OBJECT_ID] = "CKA_OBJECT_ID"

CKA_CERTIFICATE_TYPE = PyKCS11.LowLevel.CKA_CERTIFICATE_TYPE
CKA["CKA_CERTIFICATE_TYPE"] = CKA_CERTIFICATE_TYPE
CKA[CKA_CERTIFICATE_TYPE] = "CKA_CERTIFICATE_TYPE"

CKA_ISSUER = PyKCS11.LowLevel.CKA_ISSUER
CKA["CKA_ISSUER"] = CKA_ISSUER
CKA[CKA_ISSUER] = "CKA_ISSUER"

CKA_SERIAL_NUMBER = PyKCS11.LowLevel.CKA_SERIAL_NUMBER
CKA["CKA_SERIAL_NUMBER"] = CKA_SERIAL_NUMBER
CKA[CKA_SERIAL_NUMBER] = "CKA_SERIAL_NUMBER"

CKA_AC_ISSUER = PyKCS11.LowLevel.CKA_AC_ISSUER
CKA["CKA_AC_ISSUER"] = CKA_AC_ISSUER
CKA[CKA_AC_ISSUER] = "CKA_AC_ISSUER"

CKA_OWNER = PyKCS11.LowLevel.CKA_OWNER
CKA["CKA_OWNER"] = CKA_OWNER
CKA[CKA_OWNER] = "CKA_OWNER"

CKA_ATTR_TYPES = PyKCS11.LowLevel.CKA_ATTR_TYPES
CKA["CKA_ATTR_TYPES"] = CKA_ATTR_TYPES
CKA[CKA_ATTR_TYPES] = "CKA_ATTR_TYPES"

CKA_TRUSTED = PyKCS11.LowLevel.CKA_TRUSTED
CKA["CKA_TRUSTED"] = CKA_TRUSTED
CKA[CKA_TRUSTED] = "CKA_TRUSTED"

CKA_CERTIFICATE_CATEGORY = PyKCS11.LowLevel.CKA_CERTIFICATE_CATEGORY
CKA["CKA_CERTIFICATE_CATEGORY"] = CKA_CERTIFICATE_CATEGORY
CKA[CKA_CERTIFICATE_CATEGORY] = "CKA_CERTIFICATE_CATEGORY"

CKA_JAVA_MIDP_SECURITY_DOMAIN = PyKCS11.LowLevel.CKA_JAVA_MIDP_SECURITY_DOMAIN
CKA["CKA_JAVA_MIDP_SECURITY_DOMAIN"] = CKA_JAVA_MIDP_SECURITY_DOMAIN
CKA[CKA_JAVA_MIDP_SECURITY_DOMAIN] = "CKA_JAVA_MIDP_SECURITY_DOMAIN"

CKA_URL = PyKCS11.LowLevel.CKA_URL
CKA["CKA_URL"] = CKA_URL
CKA[CKA_URL] = "CKA_URL"

CKA_HASH_OF_SUBJECT_PUBLIC_KEY = PyKCS11.LowLevel.CKA_HASH_OF_SUBJECT_PUBLIC_KEY
CKA["CKA_HASH_OF_SUBJECT_PUBLIC_KEY"] = CKA_HASH_OF_SUBJECT_PUBLIC_KEY
CKA[CKA_HASH_OF_SUBJECT_PUBLIC_KEY] = "CKA_HASH_OF_SUBJECT_PUBLIC_KEY"

CKA_HASH_OF_ISSUER_PUBLIC_KEY = PyKCS11.LowLevel.CKA_HASH_OF_ISSUER_PUBLIC_KEY
CKA["CKA_HASH_OF_ISSUER_PUBLIC_KEY"] = CKA_HASH_OF_ISSUER_PUBLIC_KEY
CKA[CKA_HASH_OF_ISSUER_PUBLIC_KEY] = "CKA_HASH_OF_ISSUER_PUBLIC_KEY"

CKA_NAME_HASH_ALGORITHM = PyKCS11.LowLevel.CKA_NAME_HASH_ALGORITHM
CKA["CKA_NAME_HASH_ALGORITHM"] = CKA_NAME_HASH_ALGORITHM
CKA[CKA_NAME_HASH_ALGORITHM] = "CKA_NAME_HASH_ALGORITHM"

CKA_CHECK_VALUE = PyKCS11.LowLevel.CKA_CHECK_VALUE
CKA["CKA_CHECK_VALUE"] = CKA_CHECK_VALUE
CKA[CKA_CHECK_VALUE] = "CKA_CHECK_VALUE"

CKA_KEY_TYPE = PyKCS11.LowLevel.CKA_KEY_TYPE
CKA["CKA_KEY_TYPE"] = CKA_KEY_TYPE
CKA[CKA_KEY_TYPE] = "CKA_KEY_TYPE"

CKA_SUBJECT = PyKCS11.LowLevel.CKA_SUBJECT
CKA["CKA_SUBJECT"] = CKA_SUBJECT
CKA[CKA_SUBJECT] = "CKA_SUBJECT"

CKA_ID = PyKCS11.LowLevel.CKA_ID
CKA["CKA_ID"] = CKA_ID
CKA[CKA_ID] = "CKA_ID"

CKA_SENSITIVE = PyKCS11.LowLevel.CKA_SENSITIVE
CKA["CKA_SENSITIVE"] = CKA_SENSITIVE
CKA[CKA_SENSITIVE] = "CKA_SENSITIVE"

CKA_ENCRYPT = PyKCS11.LowLevel.CKA_ENCRYPT
CKA["CKA_ENCRYPT"] = CKA_ENCRYPT
CKA[CKA_ENCRYPT] = "CKA_ENCRYPT"

CKA_DECRYPT = PyKCS11.LowLevel.CKA_DECRYPT
CKA["CKA_DECRYPT"] = CKA_DECRYPT
CKA[CKA_DECRYPT] = "CKA_DECRYPT"

CKA_WRAP = PyKCS11.LowLevel.CKA_WRAP
CKA["CKA_WRAP"] = CKA_WRAP
CKA[CKA_WRAP] = "CKA_WRAP"

CKA_UNWRAP = PyKCS11.LowLevel.CKA_UNWRAP
CKA["CKA_UNWRAP"] = CKA_UNWRAP
CKA[CKA_UNWRAP] = "CKA_UNWRAP"

CKA_SIGN = PyKCS11.LowLevel.CKA_SIGN
CKA["CKA_SIGN"] = CKA_SIGN
CKA[CKA_SIGN] = "CKA_SIGN"

CKA_SIGN_RECOVER = PyKCS11.LowLevel.CKA_SIGN_RECOVER
CKA["CKA_SIGN_RECOVER"] = CKA_SIGN_RECOVER
CKA[CKA_SIGN_RECOVER] = "CKA_SIGN_RECOVER"

CKA_VERIFY = PyKCS11.LowLevel.CKA_VERIFY
CKA["CKA_VERIFY"] = CKA_VERIFY
CKA[CKA_VERIFY] = "CKA_VERIFY"

CKA_VERIFY_RECOVER = PyKCS11.LowLevel.CKA_VERIFY_RECOVER
CKA["CKA_VERIFY_RECOVER"] = CKA_VERIFY_RECOVER
CKA[CKA_VERIFY_RECOVER] = "CKA_VERIFY_RECOVER"

CKA_DERIVE = PyKCS11.LowLevel.CKA_DERIVE
CKA["CKA_DERIVE"] = CKA_DERIVE
CKA[CKA_DERIVE] = "CKA_DERIVE"

CKA_START_DATE = PyKCS11.LowLevel.CKA_START_DATE
CKA["CKA_START_DATE"] = CKA_START_DATE
CKA[CKA_START_DATE] = "CKA_START_DATE"

CKA_END_DATE = PyKCS11.LowLevel.CKA_END_DATE
CKA["CKA_END_DATE"] = CKA_END_DATE
CKA[CKA_END_DATE] = "CKA_END_DATE"

CKA_MODULUS = PyKCS11.LowLevel.CKA_MODULUS
CKA["CKA_MODULUS"] = CKA_MODULUS
CKA[CKA_MODULUS] = "CKA_MODULUS"

CKA_MODULUS_BITS = PyKCS11.LowLevel.CKA_MODULUS_BITS
CKA["CKA_MODULUS_BITS"] = CKA_MODULUS_BITS
CKA[CKA_MODULUS_BITS] = "CKA_MODULUS_BITS"

CKA_PUBLIC_EXPONENT = PyKCS11.LowLevel.CKA_PUBLIC_EXPONENT
CKA["CKA_PUBLIC_EXPONENT"] = CKA_PUBLIC_EXPONENT
CKA[CKA_PUBLIC_EXPONENT] = "CKA_PUBLIC_EXPONENT"

CKA_PRIVATE_EXPONENT = PyKCS11.LowLevel.CKA_PRIVATE_EXPONENT
CKA["CKA_PRIVATE_EXPONENT"] = CKA_PRIVATE_EXPONENT
CKA[CKA_PRIVATE_EXPONENT] = "CKA_PRIVATE_EXPONENT"

CKA_PRIME_1 = PyKCS11.LowLevel.CKA_PRIME_1
CKA["CKA_PRIME_1"] = CKA_PRIME_1
CKA[CKA_PRIME_1] = "CKA_PRIME_1"

CKA_PRIME_2 = PyKCS11.LowLevel.CKA_PRIME_2
CKA["CKA_PRIME_2"] = CKA_PRIME_2
CKA[CKA_PRIME_2] = "CKA_PRIME_2"

CKA_EXPONENT_1 = PyKCS11.LowLevel.CKA_EXPONENT_1
CKA["CKA_EXPONENT_1"] = CKA_EXPONENT_1
CKA[CKA_EXPONENT_1] = "CKA_EXPONENT_1"

CKA_EXPONENT_2 = PyKCS11.LowLevel.CKA_EXPONENT_2
CKA["CKA_EXPONENT_2"] = CKA_EXPONENT_2
CKA[CKA_EXPONENT_2] = "CKA_EXPONENT_2"

CKA_COEFFICIENT = PyKCS11.LowLevel.CKA_COEFFICIENT
CKA["CKA_COEFFICIENT"] = CKA_COEFFICIENT
CKA[CKA_COEFFICIENT] = "CKA_COEFFICIENT"

CKA_PUBLIC_KEY_INFO = PyKCS11.LowLevel.CKA_PUBLIC_KEY_INFO
CKA["CKA_PUBLIC_KEY_INFO"] = CKA_PUBLIC_KEY_INFO
CKA[CKA_PUBLIC_KEY_INFO] = "CKA_PUBLIC_KEY_INFO"

CKA_PRIME = PyKCS11.LowLevel.CKA_PRIME
CKA["CKA_PRIME"] = CKA_PRIME
CKA[CKA_PRIME] = "CKA_PRIME"

CKA_SUBPRIME = PyKCS11.LowLevel.CKA_SUBPRIME
CKA["CKA_SUBPRIME"] = CKA_SUBPRIME
CKA[CKA_SUBPRIME] = "CKA_SUBPRIME"

CKA_BASE = PyKCS11.LowLevel.CKA_BASE
CKA["CKA_BASE"] = CKA_BASE
CKA[CKA_BASE] = "CKA_BASE"

CKA_PRIME_BITS = PyKCS11.LowLevel.CKA_PRIME_BITS
CKA["CKA_PRIME_BITS"] = CKA_PRIME_BITS
CKA[CKA_PRIME_BITS] = "CKA_PRIME_BITS"

CKA_SUBPRIME_BITS = PyKCS11.LowLevel.CKA_SUBPRIME_BITS
CKA["CKA_SUBPRIME_BITS"] = CKA_SUBPRIME_BITS
CKA[CKA_SUBPRIME_BITS] = "CKA_SUBPRIME_BITS"

CKA_SUB_PRIME_BITS = PyKCS11.LowLevel.CKA_SUB_PRIME_BITS
CKA["CKA_SUB_PRIME_BITS"] = CKA_SUB_PRIME_BITS
CKA[CKA_SUB_PRIME_BITS] = "CKA_SUB_PRIME_BITS"

CKA_VALUE_BITS = PyKCS11.LowLevel.CKA_VALUE_BITS
CKA["CKA_VALUE_BITS"] = CKA_VALUE_BITS
CKA[CKA_VALUE_BITS] = "CKA_VALUE_BITS"

CKA_VALUE_LEN = PyKCS11.LowLevel.CKA_VALUE_LEN
CKA["CKA_VALUE_LEN"] = CKA_VALUE_LEN
CKA[CKA_VALUE_LEN] = "CKA_VALUE_LEN"

CKA_EXTRACTABLE = PyKCS11.LowLevel.CKA_EXTRACTABLE
CKA["CKA_EXTRACTABLE"] = CKA_EXTRACTABLE
CKA[CKA_EXTRACTABLE] = "CKA_EXTRACTABLE"

CKA_LOCAL = PyKCS11.LowLevel.CKA_LOCAL
CKA["CKA_LOCAL"] = CKA_LOCAL
CKA[CKA_LOCAL] = "CKA_LOCAL"

CKA_NEVER_EXTRACTABLE = PyKCS11.LowLevel.CKA_NEVER_EXTRACTABLE
CKA["CKA_NEVER_EXTRACTABLE"] = CKA_NEVER_EXTRACTABLE
CKA[CKA_NEVER_EXTRACTABLE] = "CKA_NEVER_EXTRACTABLE"

CKA_ALWAYS_SENSITIVE = PyKCS11.LowLevel.CKA_ALWAYS_SENSITIVE
CKA["CKA_ALWAYS_SENSITIVE"] = CKA_ALWAYS_SENSITIVE
CKA[CKA_ALWAYS_SENSITIVE] = "CKA_ALWAYS_SENSITIVE"

CKA_KEY_GEN_MECHANISM = PyKCS11.LowLevel.CKA_KEY_GEN_MECHANISM
CKA["CKA_KEY_GEN_MECHANISM"] = CKA_KEY_GEN_MECHANISM
CKA[CKA_KEY_GEN_MECHANISM] = "CKA_KEY_GEN_MECHANISM"

CKA_MODIFIABLE = PyKCS11.LowLevel.CKA_MODIFIABLE
CKA["CKA_MODIFIABLE"] = CKA_MODIFIABLE
CKA[CKA_MODIFIABLE] = "CKA_MODIFIABLE"

CKA_COPYABLE = PyKCS11.LowLevel.CKA_COPYABLE
CKA["CKA_COPYABLE"] = CKA_COPYABLE
CKA[CKA_COPYABLE] = "CKA_COPYABLE"

CKA_DESTROYABLE = PyKCS11.LowLevel.CKA_DESTROYABLE
CKA["CKA_DESTROYABLE"] = CKA_DESTROYABLE
CKA[CKA_DESTROYABLE] = "CKA_DESTROYABLE"

CKA_ECDSA_PARAMS = PyKCS11.LowLevel.CKA_ECDSA_PARAMS
CKA["CKA_ECDSA_PARAMS"] = CKA_ECDSA_PARAMS
CKA[CKA_ECDSA_PARAMS] = "CKA_ECDSA_PARAMS"

CKA_EC_PARAMS = PyKCS11.LowLevel.CKA_EC_PARAMS
CKA["CKA_EC_PARAMS"] = CKA_EC_PARAMS
CKA[CKA_EC_PARAMS] = "CKA_EC_PARAMS"

CKA_EC_POINT = PyKCS11.LowLevel.CKA_EC_POINT
CKA["CKA_EC_POINT"] = CKA_EC_POINT
CKA[CKA_EC_POINT] = "CKA_EC_POINT"

CKA_SECONDARY_AUTH = PyKCS11.LowLevel.CKA_SECONDARY_AUTH
CKA["CKA_SECONDARY_AUTH"] = CKA_SECONDARY_AUTH
CKA[CKA_SECONDARY_AUTH] = "CKA_SECONDARY_AUTH"

CKA_AUTH_PIN_FLAGS = PyKCS11.LowLevel.CKA_AUTH_PIN_FLAGS
CKA["CKA_AUTH_PIN_FLAGS"] = CKA_AUTH_PIN_FLAGS
CKA[CKA_AUTH_PIN_FLAGS] = "CKA_AUTH_PIN_FLAGS"

CKA_ALWAYS_AUTHENTICATE = PyKCS11.LowLevel.CKA_ALWAYS_AUTHENTICATE
CKA["CKA_ALWAYS_AUTHENTICATE"] = CKA_ALWAYS_AUTHENTICATE
CKA[CKA_ALWAYS_AUTHENTICATE] = "CKA_ALWAYS_AUTHENTICATE"

CKA_WRAP_WITH_TRUSTED = PyKCS11.LowLevel.CKA_WRAP_WITH_TRUSTED
CKA["CKA_WRAP_WITH_TRUSTED"] = CKA_WRAP_WITH_TRUSTED
CKA[CKA_WRAP_WITH_TRUSTED] = "CKA_WRAP_WITH_TRUSTED"

CKA_WRAP_TEMPLATE = PyKCS11.LowLevel.CKA_WRAP_TEMPLATE
CKA["CKA_WRAP_TEMPLATE"] = CKA_WRAP_TEMPLATE
CKA[CKA_WRAP_TEMPLATE] = "CKA_WRAP_TEMPLATE"

CKA_UNWRAP_TEMPLATE = PyKCS11.LowLevel.CKA_UNWRAP_TEMPLATE
CKA["CKA_UNWRAP_TEMPLATE"] = CKA_UNWRAP_TEMPLATE
CKA[CKA_UNWRAP_TEMPLATE] = "CKA_UNWRAP_TEMPLATE"

CKA_DERIVE_TEMPLATE = PyKCS11.LowLevel.CKA_DERIVE_TEMPLATE
CKA["CKA_DERIVE_TEMPLATE"] = CKA_DERIVE_TEMPLATE
CKA[CKA_DERIVE_TEMPLATE] = "CKA_DERIVE_TEMPLATE"

CKA_OTP_FORMAT = PyKCS11.LowLevel.CKA_OTP_FORMAT
CKA["CKA_OTP_FORMAT"] = CKA_OTP_FORMAT
CKA[CKA_OTP_FORMAT] = "CKA_OTP_FORMAT"

CKA_OTP_LENGTH = PyKCS11.LowLevel.CKA_OTP_LENGTH
CKA["CKA_OTP_LENGTH"] = CKA_OTP_LENGTH
CKA[CKA_OTP_LENGTH] = "CKA_OTP_LENGTH"

CKA_OTP_TIME_INTERVAL = PyKCS11.LowLevel.CKA_OTP_TIME_INTERVAL
CKA["CKA_OTP_TIME_INTERVAL"] = CKA_OTP_TIME_INTERVAL
CKA[CKA_OTP_TIME_INTERVAL] = "CKA_OTP_TIME_INTERVAL"

CKA_OTP_USER_FRIENDLY_MODE = PyKCS11.LowLevel.CKA_OTP_USER_FRIENDLY_MODE
CKA["CKA_OTP_USER_FRIENDLY_MODE"] = CKA_OTP_USER_FRIENDLY_MODE
CKA[CKA_OTP_USER_FRIENDLY_MODE] = "CKA_OTP_USER_FRIENDLY_MODE"

CKA_OTP_CHALLENGE_REQUIREMENT = PyKCS11.LowLevel.CKA_OTP_CHALLENGE_REQUIREMENT
CKA["CKA_OTP_CHALLENGE_REQUIREMENT"] = CKA_OTP_CHALLENGE_REQUIREMENT
CKA[CKA_OTP_CHALLENGE_REQUIREMENT] = "CKA_OTP_CHALLENGE_REQUIREMENT"

CKA_OTP_TIME_REQUIREMENT = PyKCS11.LowLevel.CKA_OTP_TIME_REQUIREMENT
CKA["CKA_OTP_TIME_REQUIREMENT"] = CKA_OTP_TIME_REQUIREMENT
CKA[CKA_OTP_TIME_REQUIREMENT] = "CKA_OTP_TIME_REQUIREMENT"

CKA_OTP_COUNTER_REQUIREMENT = PyKCS11.LowLevel.CKA_OTP_COUNTER_REQUIREMENT
CKA["CKA_OTP_COUNTER_REQUIREMENT"] = CKA_OTP_COUNTER_REQUIREMENT
CKA[CKA_OTP_COUNTER_REQUIREMENT] = "CKA_OTP_COUNTER_REQUIREMENT"

CKA_OTP_PIN_REQUIREMENT = PyKCS11.LowLevel.CKA_OTP_PIN_REQUIREMENT
CKA["CKA_OTP_PIN_REQUIREMENT"] = CKA_OTP_PIN_REQUIREMENT
CKA[CKA_OTP_PIN_REQUIREMENT] = "CKA_OTP_PIN_REQUIREMENT"

CKA_OTP_COUNTER = PyKCS11.LowLevel.CKA_OTP_COUNTER
CKA["CKA_OTP_COUNTER"] = CKA_OTP_COUNTER
CKA[CKA_OTP_COUNTER] = "CKA_OTP_COUNTER"

CKA_OTP_TIME = PyKCS11.LowLevel.CKA_OTP_TIME
CKA["CKA_OTP_TIME"] = CKA_OTP_TIME
CKA[CKA_OTP_TIME] = "CKA_OTP_TIME"

CKA_OTP_USER_IDENTIFIER = PyKCS11.LowLevel.CKA_OTP_USER_IDENTIFIER
CKA["CKA_OTP_USER_IDENTIFIER"] = CKA_OTP_USER_IDENTIFIER
CKA[CKA_OTP_USER_IDENTIFIER] = "CKA_OTP_USER_IDENTIFIER"

CKA_OTP_SERVICE_IDENTIFIER = PyKCS11.LowLevel.CKA_OTP_SERVICE_IDENTIFIER
CKA["CKA_OTP_SERVICE_IDENTIFIER"] = CKA_OTP_SERVICE_IDENTIFIER
CKA[CKA_OTP_SERVICE_IDENTIFIER] = "CKA_OTP_SERVICE_IDENTIFIER"

CKA_OTP_SERVICE_LOGO = PyKCS11.LowLevel.CKA_OTP_SERVICE_LOGO
CKA["CKA_OTP_SERVICE_LOGO"] = CKA_OTP_SERVICE_LOGO
CKA[CKA_OTP_SERVICE_LOGO] = "CKA_OTP_SERVICE_LOGO"

CKA_OTP_SERVICE_LOGO_TYPE = PyKCS11.LowLevel.CKA_OTP_SERVICE_LOGO_TYPE
CKA["CKA_OTP_SERVICE_LOGO_TYPE"] = CKA_OTP_SERVICE_LOGO_TYPE
CKA[CKA_OTP_SERVICE_LOGO_TYPE] = "CKA_OTP_SERVICE_LOGO_TYPE"

CKA_GOSTR3410_PARAMS = PyKCS11.LowLevel.CKA_GOSTR3410_PARAMS
CKA["CKA_GOSTR3410_PARAMS"] = CKA_GOSTR3410_PARAMS
CKA[CKA_GOSTR3410_PARAMS] = "CKA_GOSTR3410_PARAMS"

CKA_GOSTR3411_PARAMS = PyKCS11.LowLevel.CKA_GOSTR3411_PARAMS
CKA["CKA_GOSTR3411_PARAMS"] = CKA_GOSTR3411_PARAMS
CKA[CKA_GOSTR3411_PARAMS] = "CKA_GOSTR3411_PARAMS"

CKA_GOST28147_PARAMS = PyKCS11.LowLevel.CKA_GOST28147_PARAMS
CKA["CKA_GOST28147_PARAMS"] = CKA_GOST28147_PARAMS
CKA[CKA_GOST28147_PARAMS] = "CKA_GOST28147_PARAMS"

CKA_HW_FEATURE_TYPE = PyKCS11.LowLevel.CKA_HW_FEATURE_TYPE
CKA["CKA_HW_FEATURE_TYPE"] = CKA_HW_FEATURE_TYPE
CKA[CKA_HW_FEATURE_TYPE] = "CKA_HW_FEATURE_TYPE"

CKA_RESET_ON_INIT = PyKCS11.LowLevel.CKA_RESET_ON_INIT
CKA["CKA_RESET_ON_INIT"] = CKA_RESET_ON_INIT
CKA[CKA_RESET_ON_INIT] = "CKA_RESET_ON_INIT"

CKA_HAS_RESET = PyKCS11.LowLevel.CKA_HAS_RESET
CKA["CKA_HAS_RESET"] = CKA_HAS_RESET
CKA[CKA_HAS_RESET] = "CKA_HAS_RESET"

CKA_PIXEL_X = PyKCS11.LowLevel.CKA_PIXEL_X
CKA["CKA_PIXEL_X"] = CKA_PIXEL_X
CKA[CKA_PIXEL_X] = "CKA_PIXEL_X"

CKA_PIXEL_Y = PyKCS11.LowLevel.CKA_PIXEL_Y
CKA["CKA_PIXEL_Y"] = CKA_PIXEL_Y
CKA[CKA_PIXEL_Y] = "CKA_PIXEL_Y"

CKA_RESOLUTION = PyKCS11.LowLevel.CKA_RESOLUTION
CKA["CKA_RESOLUTION"] = CKA_RESOLUTION
CKA[CKA_RESOLUTION] = "CKA_RESOLUTION"

CKA_CHAR_ROWS = PyKCS11.LowLevel.CKA_CHAR_ROWS
CKA["CKA_CHAR_ROWS"] = CKA_CHAR_ROWS
CKA[CKA_CHAR_ROWS] = "CKA_CHAR_ROWS"

CKA_CHAR_COLUMNS = PyKCS11.LowLevel.CKA_CHAR_COLUMNS
CKA["CKA_CHAR_COLUMNS"] = CKA_CHAR_COLUMNS
CKA[CKA_CHAR_COLUMNS] = "CKA_CHAR_COLUMNS"

CKA_COLOR = PyKCS11.LowLevel.CKA_COLOR
CKA["CKA_COLOR"] = CKA_COLOR
CKA[CKA_COLOR] = "CKA_COLOR"

CKA_BITS_PER_PIXEL = PyKCS11.LowLevel.CKA_BITS_PER_PIXEL
CKA["CKA_BITS_PER_PIXEL"] = CKA_BITS_PER_PIXEL
CKA[CKA_BITS_PER_PIXEL] = "CKA_BITS_PER_PIXEL"

CKA_CHAR_SETS = PyKCS11.LowLevel.CKA_CHAR_SETS
CKA["CKA_CHAR_SETS"] = CKA_CHAR_SETS
CKA[CKA_CHAR_SETS] = "CKA_CHAR_SETS"

CKA_ENCODING_METHODS = PyKCS11.LowLevel.CKA_ENCODING_METHODS
CKA["CKA_ENCODING_METHODS"] = CKA_ENCODING_METHODS
CKA[CKA_ENCODING_METHODS] = "CKA_ENCODING_METHODS"

CKA_MIME_TYPES = PyKCS11.LowLevel.CKA_MIME_TYPES
CKA["CKA_MIME_TYPES"] = CKA_MIME_TYPES
CKA[CKA_MIME_TYPES] = "CKA_MIME_TYPES"

CKA_MECHANISM_TYPE = PyKCS11.LowLevel.CKA_MECHANISM_TYPE
CKA["CKA_MECHANISM_TYPE"] = CKA_MECHANISM_TYPE
CKA[CKA_MECHANISM_TYPE] = "CKA_MECHANISM_TYPE"

CKA_REQUIRED_CMS_ATTRIBUTES = PyKCS11.LowLevel.CKA_REQUIRED_CMS_ATTRIBUTES
CKA["CKA_REQUIRED_CMS_ATTRIBUTES"] = CKA_REQUIRED_CMS_ATTRIBUTES
CKA[CKA_REQUIRED_CMS_ATTRIBUTES] = "CKA_REQUIRED_CMS_ATTRIBUTES"

CKA_DEFAULT_CMS_ATTRIBUTES = PyKCS11.LowLevel.CKA_DEFAULT_CMS_ATTRIBUTES
CKA["CKA_DEFAULT_CMS_ATTRIBUTES"] = CKA_DEFAULT_CMS_ATTRIBUTES
CKA[CKA_DEFAULT_CMS_ATTRIBUTES] = "CKA_DEFAULT_CMS_ATTRIBUTES"

CKA_SUPPORTED_CMS_ATTRIBUTES = PyKCS11.LowLevel.CKA_SUPPORTED_CMS_ATTRIBUTES
CKA["CKA_SUPPORTED_CMS_ATTRIBUTES"] = CKA_SUPPORTED_CMS_ATTRIBUTES
CKA[CKA_SUPPORTED_CMS_ATTRIBUTES] = "CKA_SUPPORTED_CMS_ATTRIBUTES"

CKA_ALLOWED_MECHANISMS = PyKCS11.LowLevel.CKA_ALLOWED_MECHANISMS
CKA["CKA_ALLOWED_MECHANISMS"] = CKA_ALLOWED_MECHANISMS
CKA[CKA_ALLOWED_MECHANISMS] = "CKA_ALLOWED_MECHANISMS"

CKA_PROFILE_ID = PyKCS11.LowLevel.CKA_PROFILE_ID
CKA["CKA_PROFILE_ID"] = CKA_PROFILE_ID
CKA[CKA_PROFILE_ID] = "CKA_PROFILE_ID"

CKA_VENDOR_DEFINED = PyKCS11.LowLevel.CKA_VENDOR_DEFINED

# CKM constants
CKM = {}
CKM_RSA_PKCS_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_RSA_PKCS_KEY_PAIR_GEN
CKM["CKM_RSA_PKCS_KEY_PAIR_GEN"] = CKM_RSA_PKCS_KEY_PAIR_GEN
CKM[CKM_RSA_PKCS_KEY_PAIR_GEN] = "CKM_RSA_PKCS_KEY_PAIR_GEN"

CKM_RSA_PKCS = PyKCS11.LowLevel.CKM_RSA_PKCS
CKM["CKM_RSA_PKCS"] = CKM_RSA_PKCS
CKM[CKM_RSA_PKCS] = "CKM_RSA_PKCS"

CKM_RSA_9796 = PyKCS11.LowLevel.CKM_RSA_9796
CKM["CKM_RSA_9796"] = CKM_RSA_9796
CKM[CKM_RSA_9796] = "CKM_RSA_9796"

CKM_RSA_X_509 = PyKCS11.LowLevel.CKM_RSA_X_509
CKM["CKM_RSA_X_509"] = CKM_RSA_X_509
CKM[CKM_RSA_X_509] = "CKM_RSA_X_509"

CKM_MD2_RSA_PKCS = PyKCS11.LowLevel.CKM_MD2_RSA_PKCS
CKM["CKM_MD2_RSA_PKCS"] = CKM_MD2_RSA_PKCS
CKM[CKM_MD2_RSA_PKCS] = "CKM_MD2_RSA_PKCS"

CKM_MD5_RSA_PKCS = PyKCS11.LowLevel.CKM_MD5_RSA_PKCS
CKM["CKM_MD5_RSA_PKCS"] = CKM_MD5_RSA_PKCS
CKM[CKM_MD5_RSA_PKCS] = "CKM_MD5_RSA_PKCS"

CKM_SHA1_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA1_RSA_PKCS
CKM["CKM_SHA1_RSA_PKCS"] = CKM_SHA1_RSA_PKCS
CKM[CKM_SHA1_RSA_PKCS] = "CKM_SHA1_RSA_PKCS"

CKM_RIPEMD128_RSA_PKCS = PyKCS11.LowLevel.CKM_RIPEMD128_RSA_PKCS
CKM["CKM_RIPEMD128_RSA_PKCS"] = CKM_RIPEMD128_RSA_PKCS
CKM[CKM_RIPEMD128_RSA_PKCS] = "CKM_RIPEMD128_RSA_PKCS"

CKM_RIPEMD160_RSA_PKCS = PyKCS11.LowLevel.CKM_RIPEMD160_RSA_PKCS
CKM["CKM_RIPEMD160_RSA_PKCS"] = CKM_RIPEMD160_RSA_PKCS
CKM[CKM_RIPEMD160_RSA_PKCS] = "CKM_RIPEMD160_RSA_PKCS"

CKM_RSA_PKCS_OAEP = PyKCS11.LowLevel.CKM_RSA_PKCS_OAEP
CKM["CKM_RSA_PKCS_OAEP"] = CKM_RSA_PKCS_OAEP
CKM[CKM_RSA_PKCS_OAEP] = "CKM_RSA_PKCS_OAEP"

CKM_RSA_X9_31_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_RSA_X9_31_KEY_PAIR_GEN
CKM["CKM_RSA_X9_31_KEY_PAIR_GEN"] = CKM_RSA_X9_31_KEY_PAIR_GEN
CKM[CKM_RSA_X9_31_KEY_PAIR_GEN] = "CKM_RSA_X9_31_KEY_PAIR_GEN"

CKM_RSA_X9_31 = PyKCS11.LowLevel.CKM_RSA_X9_31
CKM["CKM_RSA_X9_31"] = CKM_RSA_X9_31
CKM[CKM_RSA_X9_31] = "CKM_RSA_X9_31"

CKM_SHA1_RSA_X9_31 = PyKCS11.LowLevel.CKM_SHA1_RSA_X9_31
CKM["CKM_SHA1_RSA_X9_31"] = CKM_SHA1_RSA_X9_31
CKM[CKM_SHA1_RSA_X9_31] = "CKM_SHA1_RSA_X9_31"

CKM_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_RSA_PKCS_PSS
CKM["CKM_RSA_PKCS_PSS"] = CKM_RSA_PKCS_PSS
CKM[CKM_RSA_PKCS_PSS] = "CKM_RSA_PKCS_PSS"

CKM_SHA1_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA1_RSA_PKCS_PSS
CKM["CKM_SHA1_RSA_PKCS_PSS"] = CKM_SHA1_RSA_PKCS_PSS
CKM[CKM_SHA1_RSA_PKCS_PSS] = "CKM_SHA1_RSA_PKCS_PSS"

CKM_DSA_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_DSA_KEY_PAIR_GEN
CKM["CKM_DSA_KEY_PAIR_GEN"] = CKM_DSA_KEY_PAIR_GEN
CKM[CKM_DSA_KEY_PAIR_GEN] = "CKM_DSA_KEY_PAIR_GEN"

CKM_DSA = PyKCS11.LowLevel.CKM_DSA
CKM["CKM_DSA"] = CKM_DSA
CKM[CKM_DSA] = "CKM_DSA"

CKM_DSA_SHA1 = PyKCS11.LowLevel.CKM_DSA_SHA1
CKM["CKM_DSA_SHA1"] = CKM_DSA_SHA1
CKM[CKM_DSA_SHA1] = "CKM_DSA_SHA1"

CKM_DSA_SHA224 = PyKCS11.LowLevel.CKM_DSA_SHA224
CKM["CKM_DSA_SHA224"] = CKM_DSA_SHA224
CKM[CKM_DSA_SHA224] = "CKM_DSA_SHA224"

CKM_DSA_SHA256 = PyKCS11.LowLevel.CKM_DSA_SHA256
CKM["CKM_DSA_SHA256"] = CKM_DSA_SHA256
CKM[CKM_DSA_SHA256] = "CKM_DSA_SHA256"

CKM_DSA_SHA384 = PyKCS11.LowLevel.CKM_DSA_SHA384
CKM["CKM_DSA_SHA384"] = CKM_DSA_SHA384
CKM[CKM_DSA_SHA384] = "CKM_DSA_SHA384"

CKM_DSA_SHA512 = PyKCS11.LowLevel.CKM_DSA_SHA512
CKM["CKM_DSA_SHA512"] = CKM_DSA_SHA512
CKM[CKM_DSA_SHA512] = "CKM_DSA_SHA512"

CKM_DSA_SHA3_224 = PyKCS11.LowLevel.CKM_DSA_SHA3_224
CKM["CKM_DSA_SHA3_224"] = CKM_DSA_SHA3_224
CKM[CKM_DSA_SHA3_224] = "CKM_DSA_SHA3_224"

CKM_DSA_SHA3_256 = PyKCS11.LowLevel.CKM_DSA_SHA3_256
CKM["CKM_DSA_SHA3_256"] = CKM_DSA_SHA3_256
CKM[CKM_DSA_SHA3_256] = "CKM_DSA_SHA3_256"

CKM_DSA_SHA3_384 = PyKCS11.LowLevel.CKM_DSA_SHA3_384
CKM["CKM_DSA_SHA3_384"] = CKM_DSA_SHA3_384
CKM[CKM_DSA_SHA3_384] = "CKM_DSA_SHA3_384"

CKM_DSA_SHA3_512 = PyKCS11.LowLevel.CKM_DSA_SHA3_512
CKM["CKM_DSA_SHA3_512"] = CKM_DSA_SHA3_512
CKM[CKM_DSA_SHA3_512] = "CKM_DSA_SHA3_512"

CKM_DH_PKCS_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_DH_PKCS_KEY_PAIR_GEN
CKM["CKM_DH_PKCS_KEY_PAIR_GEN"] = CKM_DH_PKCS_KEY_PAIR_GEN
CKM[CKM_DH_PKCS_KEY_PAIR_GEN] = "CKM_DH_PKCS_KEY_PAIR_GEN"

CKM_DH_PKCS_DERIVE = PyKCS11.LowLevel.CKM_DH_PKCS_DERIVE
CKM["CKM_DH_PKCS_DERIVE"] = CKM_DH_PKCS_DERIVE
CKM[CKM_DH_PKCS_DERIVE] = "CKM_DH_PKCS_DERIVE"

CKM_X9_42_DH_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_X9_42_DH_KEY_PAIR_GEN
CKM["CKM_X9_42_DH_KEY_PAIR_GEN"] = CKM_X9_42_DH_KEY_PAIR_GEN
CKM[CKM_X9_42_DH_KEY_PAIR_GEN] = "CKM_X9_42_DH_KEY_PAIR_GEN"

CKM_X9_42_DH_DERIVE = PyKCS11.LowLevel.CKM_X9_42_DH_DERIVE
CKM["CKM_X9_42_DH_DERIVE"] = CKM_X9_42_DH_DERIVE
CKM[CKM_X9_42_DH_DERIVE] = "CKM_X9_42_DH_DERIVE"

CKM_X9_42_DH_HYBRID_DERIVE = PyKCS11.LowLevel.CKM_X9_42_DH_HYBRID_DERIVE
CKM["CKM_X9_42_DH_HYBRID_DERIVE"] = CKM_X9_42_DH_HYBRID_DERIVE
CKM[CKM_X9_42_DH_HYBRID_DERIVE] = "CKM_X9_42_DH_HYBRID_DERIVE"

CKM_X9_42_MQV_DERIVE = PyKCS11.LowLevel.CKM_X9_42_MQV_DERIVE
CKM["CKM_X9_42_MQV_DERIVE"] = CKM_X9_42_MQV_DERIVE
CKM[CKM_X9_42_MQV_DERIVE] = "CKM_X9_42_MQV_DERIVE"

CKM_SHA256_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA256_RSA_PKCS
CKM["CKM_SHA256_RSA_PKCS"] = CKM_SHA256_RSA_PKCS
CKM[CKM_SHA256_RSA_PKCS] = "CKM_SHA256_RSA_PKCS"

CKM_SHA384_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA384_RSA_PKCS
CKM["CKM_SHA384_RSA_PKCS"] = CKM_SHA384_RSA_PKCS
CKM[CKM_SHA384_RSA_PKCS] = "CKM_SHA384_RSA_PKCS"

CKM_SHA512_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA512_RSA_PKCS
CKM["CKM_SHA512_RSA_PKCS"] = CKM_SHA512_RSA_PKCS
CKM[CKM_SHA512_RSA_PKCS] = "CKM_SHA512_RSA_PKCS"

CKM_SHA256_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA256_RSA_PKCS_PSS
CKM["CKM_SHA256_RSA_PKCS_PSS"] = CKM_SHA256_RSA_PKCS_PSS
CKM[CKM_SHA256_RSA_PKCS_PSS] = "CKM_SHA256_RSA_PKCS_PSS"

CKM_SHA384_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA384_RSA_PKCS_PSS
CKM["CKM_SHA384_RSA_PKCS_PSS"] = CKM_SHA384_RSA_PKCS_PSS
CKM[CKM_SHA384_RSA_PKCS_PSS] = "CKM_SHA384_RSA_PKCS_PSS"

CKM_SHA512_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA512_RSA_PKCS_PSS
CKM["CKM_SHA512_RSA_PKCS_PSS"] = CKM_SHA512_RSA_PKCS_PSS
CKM[CKM_SHA512_RSA_PKCS_PSS] = "CKM_SHA512_RSA_PKCS_PSS"

CKM_SHA224_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA224_RSA_PKCS
CKM["CKM_SHA224_RSA_PKCS"] = CKM_SHA224_RSA_PKCS
CKM[CKM_SHA224_RSA_PKCS] = "CKM_SHA224_RSA_PKCS"

CKM_SHA224_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA224_RSA_PKCS_PSS
CKM["CKM_SHA224_RSA_PKCS_PSS"] = CKM_SHA224_RSA_PKCS_PSS
CKM[CKM_SHA224_RSA_PKCS_PSS] = "CKM_SHA224_RSA_PKCS_PSS"

CKM_SHA512_224 = PyKCS11.LowLevel.CKM_SHA512_224
CKM["CKM_SHA512_224"] = CKM_SHA512_224
CKM[CKM_SHA512_224] = "CKM_SHA512_224"

CKM_SHA512_224_HMAC = PyKCS11.LowLevel.CKM_SHA512_224_HMAC
CKM["CKM_SHA512_224_HMAC"] = CKM_SHA512_224_HMAC
CKM[CKM_SHA512_224_HMAC] = "CKM_SHA512_224_HMAC"

CKM_SHA512_224_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA512_224_HMAC_GENERAL
CKM["CKM_SHA512_224_HMAC_GENERAL"] = CKM_SHA512_224_HMAC_GENERAL
CKM[CKM_SHA512_224_HMAC_GENERAL] = "CKM_SHA512_224_HMAC_GENERAL"

CKM_SHA512_224_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA512_224_KEY_DERIVATION
CKM["CKM_SHA512_224_KEY_DERIVATION"] = CKM_SHA512_224_KEY_DERIVATION
CKM[CKM_SHA512_224_KEY_DERIVATION] = "CKM_SHA512_224_KEY_DERIVATION"

CKM_SHA512_256 = PyKCS11.LowLevel.CKM_SHA512_256
CKM["CKM_SHA512_256"] = CKM_SHA512_256
CKM[CKM_SHA512_256] = "CKM_SHA512_256"

CKM_SHA512_256_HMAC = PyKCS11.LowLevel.CKM_SHA512_256_HMAC
CKM["CKM_SHA512_256_HMAC"] = CKM_SHA512_256_HMAC
CKM[CKM_SHA512_256_HMAC] = "CKM_SHA512_256_HMAC"

CKM_SHA512_256_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA512_256_HMAC_GENERAL
CKM["CKM_SHA512_256_HMAC_GENERAL"] = CKM_SHA512_256_HMAC_GENERAL
CKM[CKM_SHA512_256_HMAC_GENERAL] = "CKM_SHA512_256_HMAC_GENERAL"

CKM_SHA512_256_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA512_256_KEY_DERIVATION
CKM["CKM_SHA512_256_KEY_DERIVATION"] = CKM_SHA512_256_KEY_DERIVATION
CKM[CKM_SHA512_256_KEY_DERIVATION] = "CKM_SHA512_256_KEY_DERIVATION"

CKM_SHA512_T = PyKCS11.LowLevel.CKM_SHA512_T
CKM["CKM_SHA512_T"] = CKM_SHA512_T
CKM[CKM_SHA512_T] = "CKM_SHA512_T"

CKM_SHA512_T_HMAC = PyKCS11.LowLevel.CKM_SHA512_T_HMAC
CKM["CKM_SHA512_T_HMAC"] = CKM_SHA512_T_HMAC
CKM[CKM_SHA512_T_HMAC] = "CKM_SHA512_T_HMAC"

CKM_SHA512_T_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA512_T_HMAC_GENERAL
CKM["CKM_SHA512_T_HMAC_GENERAL"] = CKM_SHA512_T_HMAC_GENERAL
CKM[CKM_SHA512_T_HMAC_GENERAL] = "CKM_SHA512_T_HMAC_GENERAL"

CKM_SHA512_T_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA512_T_KEY_DERIVATION
CKM["CKM_SHA512_T_KEY_DERIVATION"] = CKM_SHA512_T_KEY_DERIVATION
CKM[CKM_SHA512_T_KEY_DERIVATION] = "CKM_SHA512_T_KEY_DERIVATION"

CKM_SHA3_256_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA3_256_RSA_PKCS
CKM["CKM_SHA3_256_RSA_PKCS"] = CKM_SHA3_256_RSA_PKCS
CKM[CKM_SHA3_256_RSA_PKCS] = "CKM_SHA3_256_RSA_PKCS"

CKM_SHA3_384_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA3_384_RSA_PKCS
CKM["CKM_SHA3_384_RSA_PKCS"] = CKM_SHA3_384_RSA_PKCS
CKM[CKM_SHA3_384_RSA_PKCS] = "CKM_SHA3_384_RSA_PKCS"

CKM_SHA3_512_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA3_512_RSA_PKCS
CKM["CKM_SHA3_512_RSA_PKCS"] = CKM_SHA3_512_RSA_PKCS
CKM[CKM_SHA3_512_RSA_PKCS] = "CKM_SHA3_512_RSA_PKCS"

CKM_SHA3_256_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA3_256_RSA_PKCS_PSS
CKM["CKM_SHA3_256_RSA_PKCS_PSS"] = CKM_SHA3_256_RSA_PKCS_PSS
CKM[CKM_SHA3_256_RSA_PKCS_PSS] = "CKM_SHA3_256_RSA_PKCS_PSS"

CKM_SHA3_384_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA3_384_RSA_PKCS_PSS
CKM["CKM_SHA3_384_RSA_PKCS_PSS"] = CKM_SHA3_384_RSA_PKCS_PSS
CKM[CKM_SHA3_384_RSA_PKCS_PSS] = "CKM_SHA3_384_RSA_PKCS_PSS"

CKM_SHA3_512_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA3_512_RSA_PKCS_PSS
CKM["CKM_SHA3_512_RSA_PKCS_PSS"] = CKM_SHA3_512_RSA_PKCS_PSS
CKM[CKM_SHA3_512_RSA_PKCS_PSS] = "CKM_SHA3_512_RSA_PKCS_PSS"

CKM_SHA3_224_RSA_PKCS = PyKCS11.LowLevel.CKM_SHA3_224_RSA_PKCS
CKM["CKM_SHA3_224_RSA_PKCS"] = CKM_SHA3_224_RSA_PKCS
CKM[CKM_SHA3_224_RSA_PKCS] = "CKM_SHA3_224_RSA_PKCS"

CKM_SHA3_224_RSA_PKCS_PSS = PyKCS11.LowLevel.CKM_SHA3_224_RSA_PKCS_PSS
CKM["CKM_SHA3_224_RSA_PKCS_PSS"] = CKM_SHA3_224_RSA_PKCS_PSS
CKM[CKM_SHA3_224_RSA_PKCS_PSS] = "CKM_SHA3_224_RSA_PKCS_PSS"

CKM_RC2_KEY_GEN = PyKCS11.LowLevel.CKM_RC2_KEY_GEN
CKM["CKM_RC2_KEY_GEN"] = CKM_RC2_KEY_GEN
CKM[CKM_RC2_KEY_GEN] = "CKM_RC2_KEY_GEN"

CKM_RC2_ECB = PyKCS11.LowLevel.CKM_RC2_ECB
CKM["CKM_RC2_ECB"] = CKM_RC2_ECB
CKM[CKM_RC2_ECB] = "CKM_RC2_ECB"

CKM_RC2_CBC = PyKCS11.LowLevel.CKM_RC2_CBC
CKM["CKM_RC2_CBC"] = CKM_RC2_CBC
CKM[CKM_RC2_CBC] = "CKM_RC2_CBC"

CKM_RC2_MAC = PyKCS11.LowLevel.CKM_RC2_MAC
CKM["CKM_RC2_MAC"] = CKM_RC2_MAC
CKM[CKM_RC2_MAC] = "CKM_RC2_MAC"

CKM_RC2_MAC_GENERAL = PyKCS11.LowLevel.CKM_RC2_MAC_GENERAL
CKM["CKM_RC2_MAC_GENERAL"] = CKM_RC2_MAC_GENERAL
CKM[CKM_RC2_MAC_GENERAL] = "CKM_RC2_MAC_GENERAL"

CKM_RC2_CBC_PAD = PyKCS11.LowLevel.CKM_RC2_CBC_PAD
CKM["CKM_RC2_CBC_PAD"] = CKM_RC2_CBC_PAD
CKM[CKM_RC2_CBC_PAD] = "CKM_RC2_CBC_PAD"

CKM_RC4_KEY_GEN = PyKCS11.LowLevel.CKM_RC4_KEY_GEN
CKM["CKM_RC4_KEY_GEN"] = CKM_RC4_KEY_GEN
CKM[CKM_RC4_KEY_GEN] = "CKM_RC4_KEY_GEN"

CKM_RC4 = PyKCS11.LowLevel.CKM_RC4
CKM["CKM_RC4"] = CKM_RC4
CKM[CKM_RC4] = "CKM_RC4"

CKM_DES_KEY_GEN = PyKCS11.LowLevel.CKM_DES_KEY_GEN
CKM["CKM_DES_KEY_GEN"] = CKM_DES_KEY_GEN
CKM[CKM_DES_KEY_GEN] = "CKM_DES_KEY_GEN"

CKM_DES_ECB = PyKCS11.LowLevel.CKM_DES_ECB
CKM["CKM_DES_ECB"] = CKM_DES_ECB
CKM[CKM_DES_ECB] = "CKM_DES_ECB"

CKM_DES_CBC = PyKCS11.LowLevel.CKM_DES_CBC
CKM["CKM_DES_CBC"] = CKM_DES_CBC
CKM[CKM_DES_CBC] = "CKM_DES_CBC"

CKM_DES_MAC = PyKCS11.LowLevel.CKM_DES_MAC
CKM["CKM_DES_MAC"] = CKM_DES_MAC
CKM[CKM_DES_MAC] = "CKM_DES_MAC"

CKM_DES_MAC_GENERAL = PyKCS11.LowLevel.CKM_DES_MAC_GENERAL
CKM["CKM_DES_MAC_GENERAL"] = CKM_DES_MAC_GENERAL
CKM[CKM_DES_MAC_GENERAL] = "CKM_DES_MAC_GENERAL"

CKM_DES_CBC_PAD = PyKCS11.LowLevel.CKM_DES_CBC_PAD
CKM["CKM_DES_CBC_PAD"] = CKM_DES_CBC_PAD
CKM[CKM_DES_CBC_PAD] = "CKM_DES_CBC_PAD"

CKM_DES2_KEY_GEN = PyKCS11.LowLevel.CKM_DES2_KEY_GEN
CKM["CKM_DES2_KEY_GEN"] = CKM_DES2_KEY_GEN
CKM[CKM_DES2_KEY_GEN] = "CKM_DES2_KEY_GEN"

CKM_DES3_KEY_GEN = PyKCS11.LowLevel.CKM_DES3_KEY_GEN
CKM["CKM_DES3_KEY_GEN"] = CKM_DES3_KEY_GEN
CKM[CKM_DES3_KEY_GEN] = "CKM_DES3_KEY_GEN"

CKM_DES3_ECB = PyKCS11.LowLevel.CKM_DES3_ECB
CKM["CKM_DES3_ECB"] = CKM_DES3_ECB
CKM[CKM_DES3_ECB] = "CKM_DES3_ECB"

CKM_DES3_CBC = PyKCS11.LowLevel.CKM_DES3_CBC
CKM["CKM_DES3_CBC"] = CKM_DES3_CBC
CKM[CKM_DES3_CBC] = "CKM_DES3_CBC"

CKM_DES3_MAC = PyKCS11.LowLevel.CKM_DES3_MAC
CKM["CKM_DES3_MAC"] = CKM_DES3_MAC
CKM[CKM_DES3_MAC] = "CKM_DES3_MAC"

CKM_DES3_MAC_GENERAL = PyKCS11.LowLevel.CKM_DES3_MAC_GENERAL
CKM["CKM_DES3_MAC_GENERAL"] = CKM_DES3_MAC_GENERAL
CKM[CKM_DES3_MAC_GENERAL] = "CKM_DES3_MAC_GENERAL"

CKM_DES3_CBC_PAD = PyKCS11.LowLevel.CKM_DES3_CBC_PAD
CKM["CKM_DES3_CBC_PAD"] = CKM_DES3_CBC_PAD
CKM[CKM_DES3_CBC_PAD] = "CKM_DES3_CBC_PAD"

CKM_DES3_CMAC_GENERAL = PyKCS11.LowLevel.CKM_DES3_CMAC_GENERAL
CKM["CKM_DES3_CMAC_GENERAL"] = CKM_DES3_CMAC_GENERAL
CKM[CKM_DES3_CMAC_GENERAL] = "CKM_DES3_CMAC_GENERAL"

CKM_DES3_CMAC = PyKCS11.LowLevel.CKM_DES3_CMAC
CKM["CKM_DES3_CMAC"] = CKM_DES3_CMAC
CKM[CKM_DES3_CMAC] = "CKM_DES3_CMAC"

CKM_CDMF_KEY_GEN = PyKCS11.LowLevel.CKM_CDMF_KEY_GEN
CKM["CKM_CDMF_KEY_GEN"] = CKM_CDMF_KEY_GEN
CKM[CKM_CDMF_KEY_GEN] = "CKM_CDMF_KEY_GEN"

CKM_CDMF_ECB = PyKCS11.LowLevel.CKM_CDMF_ECB
CKM["CKM_CDMF_ECB"] = CKM_CDMF_ECB
CKM[CKM_CDMF_ECB] = "CKM_CDMF_ECB"

CKM_CDMF_CBC = PyKCS11.LowLevel.CKM_CDMF_CBC
CKM["CKM_CDMF_CBC"] = CKM_CDMF_CBC
CKM[CKM_CDMF_CBC] = "CKM_CDMF_CBC"

CKM_CDMF_MAC = PyKCS11.LowLevel.CKM_CDMF_MAC
CKM["CKM_CDMF_MAC"] = CKM_CDMF_MAC
CKM[CKM_CDMF_MAC] = "CKM_CDMF_MAC"

CKM_CDMF_MAC_GENERAL = PyKCS11.LowLevel.CKM_CDMF_MAC_GENERAL
CKM["CKM_CDMF_MAC_GENERAL"] = CKM_CDMF_MAC_GENERAL
CKM[CKM_CDMF_MAC_GENERAL] = "CKM_CDMF_MAC_GENERAL"

CKM_CDMF_CBC_PAD = PyKCS11.LowLevel.CKM_CDMF_CBC_PAD
CKM["CKM_CDMF_CBC_PAD"] = CKM_CDMF_CBC_PAD
CKM[CKM_CDMF_CBC_PAD] = "CKM_CDMF_CBC_PAD"

CKM_DES_OFB64 = PyKCS11.LowLevel.CKM_DES_OFB64
CKM["CKM_DES_OFB64"] = CKM_DES_OFB64
CKM[CKM_DES_OFB64] = "CKM_DES_OFB64"

CKM_DES_OFB8 = PyKCS11.LowLevel.CKM_DES_OFB8
CKM["CKM_DES_OFB8"] = CKM_DES_OFB8
CKM[CKM_DES_OFB8] = "CKM_DES_OFB8"

CKM_DES_CFB64 = PyKCS11.LowLevel.CKM_DES_CFB64
CKM["CKM_DES_CFB64"] = CKM_DES_CFB64
CKM[CKM_DES_CFB64] = "CKM_DES_CFB64"

CKM_DES_CFB8 = PyKCS11.LowLevel.CKM_DES_CFB8
CKM["CKM_DES_CFB8"] = CKM_DES_CFB8
CKM[CKM_DES_CFB8] = "CKM_DES_CFB8"

CKM_MD2 = PyKCS11.LowLevel.CKM_MD2
CKM["CKM_MD2"] = CKM_MD2
CKM[CKM_MD2] = "CKM_MD2"

CKM_MD2_HMAC = PyKCS11.LowLevel.CKM_MD2_HMAC
CKM["CKM_MD2_HMAC"] = CKM_MD2_HMAC
CKM[CKM_MD2_HMAC] = "CKM_MD2_HMAC"

CKM_MD2_HMAC_GENERAL = PyKCS11.LowLevel.CKM_MD2_HMAC_GENERAL
CKM["CKM_MD2_HMAC_GENERAL"] = CKM_MD2_HMAC_GENERAL
CKM[CKM_MD2_HMAC_GENERAL] = "CKM_MD2_HMAC_GENERAL"

CKM_MD5 = PyKCS11.LowLevel.CKM_MD5
CKM["CKM_MD5"] = CKM_MD5
CKM[CKM_MD5] = "CKM_MD5"

CKM_MD5_HMAC = PyKCS11.LowLevel.CKM_MD5_HMAC
CKM["CKM_MD5_HMAC"] = CKM_MD5_HMAC
CKM[CKM_MD5_HMAC] = "CKM_MD5_HMAC"

CKM_MD5_HMAC_GENERAL = PyKCS11.LowLevel.CKM_MD5_HMAC_GENERAL
CKM["CKM_MD5_HMAC_GENERAL"] = CKM_MD5_HMAC_GENERAL
CKM[CKM_MD5_HMAC_GENERAL] = "CKM_MD5_HMAC_GENERAL"

CKM_SHA_1 = PyKCS11.LowLevel.CKM_SHA_1
CKM["CKM_SHA_1"] = CKM_SHA_1
CKM[CKM_SHA_1] = "CKM_SHA_1"

CKM_SHA_1_HMAC = PyKCS11.LowLevel.CKM_SHA_1_HMAC
CKM["CKM_SHA_1_HMAC"] = CKM_SHA_1_HMAC
CKM[CKM_SHA_1_HMAC] = "CKM_SHA_1_HMAC"

CKM_SHA_1_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA_1_HMAC_GENERAL
CKM["CKM_SHA_1_HMAC_GENERAL"] = CKM_SHA_1_HMAC_GENERAL
CKM[CKM_SHA_1_HMAC_GENERAL] = "CKM_SHA_1_HMAC_GENERAL"

CKM_RIPEMD128 = PyKCS11.LowLevel.CKM_RIPEMD128
CKM["CKM_RIPEMD128"] = CKM_RIPEMD128
CKM[CKM_RIPEMD128] = "CKM_RIPEMD128"

CKM_RIPEMD128_HMAC = PyKCS11.LowLevel.CKM_RIPEMD128_HMAC
CKM["CKM_RIPEMD128_HMAC"] = CKM_RIPEMD128_HMAC
CKM[CKM_RIPEMD128_HMAC] = "CKM_RIPEMD128_HMAC"

CKM_RIPEMD128_HMAC_GENERAL = PyKCS11.LowLevel.CKM_RIPEMD128_HMAC_GENERAL
CKM["CKM_RIPEMD128_HMAC_GENERAL"] = CKM_RIPEMD128_HMAC_GENERAL
CKM[CKM_RIPEMD128_HMAC_GENERAL] = "CKM_RIPEMD128_HMAC_GENERAL"

CKM_RIPEMD160 = PyKCS11.LowLevel.CKM_RIPEMD160
CKM["CKM_RIPEMD160"] = CKM_RIPEMD160
CKM[CKM_RIPEMD160] = "CKM_RIPEMD160"

CKM_RIPEMD160_HMAC = PyKCS11.LowLevel.CKM_RIPEMD160_HMAC
CKM["CKM_RIPEMD160_HMAC"] = CKM_RIPEMD160_HMAC
CKM[CKM_RIPEMD160_HMAC] = "CKM_RIPEMD160_HMAC"

CKM_RIPEMD160_HMAC_GENERAL = PyKCS11.LowLevel.CKM_RIPEMD160_HMAC_GENERAL
CKM["CKM_RIPEMD160_HMAC_GENERAL"] = CKM_RIPEMD160_HMAC_GENERAL
CKM[CKM_RIPEMD160_HMAC_GENERAL] = "CKM_RIPEMD160_HMAC_GENERAL"

CKM_SHA256 = PyKCS11.LowLevel.CKM_SHA256
CKM["CKM_SHA256"] = CKM_SHA256
CKM[CKM_SHA256] = "CKM_SHA256"

CKM_SHA256_HMAC = PyKCS11.LowLevel.CKM_SHA256_HMAC
CKM["CKM_SHA256_HMAC"] = CKM_SHA256_HMAC
CKM[CKM_SHA256_HMAC] = "CKM_SHA256_HMAC"

CKM_SHA256_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA256_HMAC_GENERAL
CKM["CKM_SHA256_HMAC_GENERAL"] = CKM_SHA256_HMAC_GENERAL
CKM[CKM_SHA256_HMAC_GENERAL] = "CKM_SHA256_HMAC_GENERAL"

CKM_SHA224 = PyKCS11.LowLevel.CKM_SHA224
CKM["CKM_SHA224"] = CKM_SHA224
CKM[CKM_SHA224] = "CKM_SHA224"

CKM_SHA224_HMAC = PyKCS11.LowLevel.CKM_SHA224_HMAC
CKM["CKM_SHA224_HMAC"] = CKM_SHA224_HMAC
CKM[CKM_SHA224_HMAC] = "CKM_SHA224_HMAC"

CKM_SHA224_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA224_HMAC_GENERAL
CKM["CKM_SHA224_HMAC_GENERAL"] = CKM_SHA224_HMAC_GENERAL
CKM[CKM_SHA224_HMAC_GENERAL] = "CKM_SHA224_HMAC_GENERAL"

CKM_SHA384 = PyKCS11.LowLevel.CKM_SHA384
CKM["CKM_SHA384"] = CKM_SHA384
CKM[CKM_SHA384] = "CKM_SHA384"

CKM_SHA384_HMAC = PyKCS11.LowLevel.CKM_SHA384_HMAC
CKM["CKM_SHA384_HMAC"] = CKM_SHA384_HMAC
CKM[CKM_SHA384_HMAC] = "CKM_SHA384_HMAC"

CKM_SHA384_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA384_HMAC_GENERAL
CKM["CKM_SHA384_HMAC_GENERAL"] = CKM_SHA384_HMAC_GENERAL
CKM[CKM_SHA384_HMAC_GENERAL] = "CKM_SHA384_HMAC_GENERAL"

CKM_SHA512 = PyKCS11.LowLevel.CKM_SHA512
CKM["CKM_SHA512"] = CKM_SHA512
CKM[CKM_SHA512] = "CKM_SHA512"

CKM_SHA512_HMAC = PyKCS11.LowLevel.CKM_SHA512_HMAC
CKM["CKM_SHA512_HMAC"] = CKM_SHA512_HMAC
CKM[CKM_SHA512_HMAC] = "CKM_SHA512_HMAC"

CKM_SHA512_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA512_HMAC_GENERAL
CKM["CKM_SHA512_HMAC_GENERAL"] = CKM_SHA512_HMAC_GENERAL
CKM[CKM_SHA512_HMAC_GENERAL] = "CKM_SHA512_HMAC_GENERAL"

CKM_SECURID_KEY_GEN = PyKCS11.LowLevel.CKM_SECURID_KEY_GEN
CKM["CKM_SECURID_KEY_GEN"] = CKM_SECURID_KEY_GEN
CKM[CKM_SECURID_KEY_GEN] = "CKM_SECURID_KEY_GEN"

CKM_SECURID = PyKCS11.LowLevel.CKM_SECURID
CKM["CKM_SECURID"] = CKM_SECURID
CKM[CKM_SECURID] = "CKM_SECURID"

CKM_HOTP_KEY_GEN = PyKCS11.LowLevel.CKM_HOTP_KEY_GEN
CKM["CKM_HOTP_KEY_GEN"] = CKM_HOTP_KEY_GEN
CKM[CKM_HOTP_KEY_GEN] = "CKM_HOTP_KEY_GEN"

CKM_HOTP = PyKCS11.LowLevel.CKM_HOTP
CKM["CKM_HOTP"] = CKM_HOTP
CKM[CKM_HOTP] = "CKM_HOTP"

CKM_ACTI = PyKCS11.LowLevel.CKM_ACTI
CKM["CKM_ACTI"] = CKM_ACTI
CKM[CKM_ACTI] = "CKM_ACTI"

CKM_ACTI_KEY_GEN = PyKCS11.LowLevel.CKM_ACTI_KEY_GEN
CKM["CKM_ACTI_KEY_GEN"] = CKM_ACTI_KEY_GEN
CKM[CKM_ACTI_KEY_GEN] = "CKM_ACTI_KEY_GEN"

CKM_SHA3_256 = PyKCS11.LowLevel.CKM_SHA3_256
CKM["CKM_SHA3_256"] = CKM_SHA3_256
CKM[CKM_SHA3_256] = "CKM_SHA3_256"

CKM_SHA3_256_HMAC = PyKCS11.LowLevel.CKM_SHA3_256_HMAC
CKM["CKM_SHA3_256_HMAC"] = CKM_SHA3_256_HMAC
CKM[CKM_SHA3_256_HMAC] = "CKM_SHA3_256_HMAC"

CKM_SHA3_256_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA3_256_HMAC_GENERAL
CKM["CKM_SHA3_256_HMAC_GENERAL"] = CKM_SHA3_256_HMAC_GENERAL
CKM[CKM_SHA3_256_HMAC_GENERAL] = "CKM_SHA3_256_HMAC_GENERAL"

CKM_SHA3_256_KEY_GEN = PyKCS11.LowLevel.CKM_SHA3_256_KEY_GEN
CKM["CKM_SHA3_256_KEY_GEN"] = CKM_SHA3_256_KEY_GEN
CKM[CKM_SHA3_256_KEY_GEN] = "CKM_SHA3_256_KEY_GEN"

CKM_SHA3_224 = PyKCS11.LowLevel.CKM_SHA3_224
CKM["CKM_SHA3_224"] = CKM_SHA3_224
CKM[CKM_SHA3_224] = "CKM_SHA3_224"

CKM_SHA3_224_HMAC = PyKCS11.LowLevel.CKM_SHA3_224_HMAC
CKM["CKM_SHA3_224_HMAC"] = CKM_SHA3_224_HMAC
CKM[CKM_SHA3_224_HMAC] = "CKM_SHA3_224_HMAC"

CKM_SHA3_224_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA3_224_HMAC_GENERAL
CKM["CKM_SHA3_224_HMAC_GENERAL"] = CKM_SHA3_224_HMAC_GENERAL
CKM[CKM_SHA3_224_HMAC_GENERAL] = "CKM_SHA3_224_HMAC_GENERAL"

CKM_SHA3_224_KEY_GEN = PyKCS11.LowLevel.CKM_SHA3_224_KEY_GEN
CKM["CKM_SHA3_224_KEY_GEN"] = CKM_SHA3_224_KEY_GEN
CKM[CKM_SHA3_224_KEY_GEN] = "CKM_SHA3_224_KEY_GEN"

CKM_SHA3_384 = PyKCS11.LowLevel.CKM_SHA3_384
CKM["CKM_SHA3_384"] = CKM_SHA3_384
CKM[CKM_SHA3_384] = "CKM_SHA3_384"

CKM_SHA3_384_HMAC = PyKCS11.LowLevel.CKM_SHA3_384_HMAC
CKM["CKM_SHA3_384_HMAC"] = CKM_SHA3_384_HMAC
CKM[CKM_SHA3_384_HMAC] = "CKM_SHA3_384_HMAC"

CKM_SHA3_384_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA3_384_HMAC_GENERAL
CKM["CKM_SHA3_384_HMAC_GENERAL"] = CKM_SHA3_384_HMAC_GENERAL
CKM[CKM_SHA3_384_HMAC_GENERAL] = "CKM_SHA3_384_HMAC_GENERAL"

CKM_SHA3_384_KEY_GEN = PyKCS11.LowLevel.CKM_SHA3_384_KEY_GEN
CKM["CKM_SHA3_384_KEY_GEN"] = CKM_SHA3_384_KEY_GEN
CKM[CKM_SHA3_384_KEY_GEN] = "CKM_SHA3_384_KEY_GEN"

CKM_SHA3_512 = PyKCS11.LowLevel.CKM_SHA3_512
CKM["CKM_SHA3_512"] = CKM_SHA3_512
CKM[CKM_SHA3_512] = "CKM_SHA3_512"

CKM_SHA3_512_HMAC = PyKCS11.LowLevel.CKM_SHA3_512_HMAC
CKM["CKM_SHA3_512_HMAC"] = CKM_SHA3_512_HMAC
CKM[CKM_SHA3_512_HMAC] = "CKM_SHA3_512_HMAC"

CKM_SHA3_512_HMAC_GENERAL = PyKCS11.LowLevel.CKM_SHA3_512_HMAC_GENERAL
CKM["CKM_SHA3_512_HMAC_GENERAL"] = CKM_SHA3_512_HMAC_GENERAL
CKM[CKM_SHA3_512_HMAC_GENERAL] = "CKM_SHA3_512_HMAC_GENERAL"

CKM_SHA3_512_KEY_GEN = PyKCS11.LowLevel.CKM_SHA3_512_KEY_GEN
CKM["CKM_SHA3_512_KEY_GEN"] = CKM_SHA3_512_KEY_GEN
CKM[CKM_SHA3_512_KEY_GEN] = "CKM_SHA3_512_KEY_GEN"

CKM_CAST_KEY_GEN = PyKCS11.LowLevel.CKM_CAST_KEY_GEN
CKM["CKM_CAST_KEY_GEN"] = CKM_CAST_KEY_GEN
CKM[CKM_CAST_KEY_GEN] = "CKM_CAST_KEY_GEN"

CKM_CAST_ECB = PyKCS11.LowLevel.CKM_CAST_ECB
CKM["CKM_CAST_ECB"] = CKM_CAST_ECB
CKM[CKM_CAST_ECB] = "CKM_CAST_ECB"

CKM_CAST_CBC = PyKCS11.LowLevel.CKM_CAST_CBC
CKM["CKM_CAST_CBC"] = CKM_CAST_CBC
CKM[CKM_CAST_CBC] = "CKM_CAST_CBC"

CKM_CAST_MAC = PyKCS11.LowLevel.CKM_CAST_MAC
CKM["CKM_CAST_MAC"] = CKM_CAST_MAC
CKM[CKM_CAST_MAC] = "CKM_CAST_MAC"

CKM_CAST_MAC_GENERAL = PyKCS11.LowLevel.CKM_CAST_MAC_GENERAL
CKM["CKM_CAST_MAC_GENERAL"] = CKM_CAST_MAC_GENERAL
CKM[CKM_CAST_MAC_GENERAL] = "CKM_CAST_MAC_GENERAL"

CKM_CAST_CBC_PAD = PyKCS11.LowLevel.CKM_CAST_CBC_PAD
CKM["CKM_CAST_CBC_PAD"] = CKM_CAST_CBC_PAD
CKM[CKM_CAST_CBC_PAD] = "CKM_CAST_CBC_PAD"

CKM_CAST3_KEY_GEN = PyKCS11.LowLevel.CKM_CAST3_KEY_GEN
CKM["CKM_CAST3_KEY_GEN"] = CKM_CAST3_KEY_GEN
CKM[CKM_CAST3_KEY_GEN] = "CKM_CAST3_KEY_GEN"

CKM_CAST3_ECB = PyKCS11.LowLevel.CKM_CAST3_ECB
CKM["CKM_CAST3_ECB"] = CKM_CAST3_ECB
CKM[CKM_CAST3_ECB] = "CKM_CAST3_ECB"

CKM_CAST3_CBC = PyKCS11.LowLevel.CKM_CAST3_CBC
CKM["CKM_CAST3_CBC"] = CKM_CAST3_CBC
CKM[CKM_CAST3_CBC] = "CKM_CAST3_CBC"

CKM_CAST3_MAC = PyKCS11.LowLevel.CKM_CAST3_MAC
CKM["CKM_CAST3_MAC"] = CKM_CAST3_MAC
CKM[CKM_CAST3_MAC] = "CKM_CAST3_MAC"

CKM_CAST3_MAC_GENERAL = PyKCS11.LowLevel.CKM_CAST3_MAC_GENERAL
CKM["CKM_CAST3_MAC_GENERAL"] = CKM_CAST3_MAC_GENERAL
CKM[CKM_CAST3_MAC_GENERAL] = "CKM_CAST3_MAC_GENERAL"

CKM_CAST3_CBC_PAD = PyKCS11.LowLevel.CKM_CAST3_CBC_PAD
CKM["CKM_CAST3_CBC_PAD"] = CKM_CAST3_CBC_PAD
CKM[CKM_CAST3_CBC_PAD] = "CKM_CAST3_CBC_PAD"

CKM_CAST5_KEY_GEN = PyKCS11.LowLevel.CKM_CAST5_KEY_GEN
CKM["CKM_CAST5_KEY_GEN"] = CKM_CAST5_KEY_GEN
CKM[CKM_CAST5_KEY_GEN] = "CKM_CAST5_KEY_GEN"

CKM_CAST128_KEY_GEN = PyKCS11.LowLevel.CKM_CAST128_KEY_GEN
CKM["CKM_CAST128_KEY_GEN"] = CKM_CAST128_KEY_GEN
CKM[CKM_CAST128_KEY_GEN] = "CKM_CAST128_KEY_GEN"

CKM_CAST5_ECB = PyKCS11.LowLevel.CKM_CAST5_ECB
CKM["CKM_CAST5_ECB"] = CKM_CAST5_ECB
CKM[CKM_CAST5_ECB] = "CKM_CAST5_ECB"

CKM_CAST128_ECB = PyKCS11.LowLevel.CKM_CAST128_ECB
CKM["CKM_CAST128_ECB"] = CKM_CAST128_ECB
CKM[CKM_CAST128_ECB] = "CKM_CAST128_ECB"

CKM_CAST5_CBC = PyKCS11.LowLevel.CKM_CAST5_CBC
CKM["CKM_CAST5_CBC"] = CKM_CAST5_CBC
CKM[CKM_CAST5_CBC] = "CKM_CAST5_CBC"

CKM_CAST128_CBC = PyKCS11.LowLevel.CKM_CAST128_CBC
CKM["CKM_CAST128_CBC"] = CKM_CAST128_CBC
CKM[CKM_CAST128_CBC] = "CKM_CAST128_CBC"

CKM_CAST5_MAC = PyKCS11.LowLevel.CKM_CAST5_MAC
CKM["CKM_CAST5_MAC"] = CKM_CAST5_MAC
CKM[CKM_CAST5_MAC] = "CKM_CAST5_MAC"

CKM_CAST128_MAC = PyKCS11.LowLevel.CKM_CAST128_MAC
CKM["CKM_CAST128_MAC"] = CKM_CAST128_MAC
CKM[CKM_CAST128_MAC] = "CKM_CAST128_MAC"

CKM_CAST5_MAC_GENERAL = PyKCS11.LowLevel.CKM_CAST5_MAC_GENERAL
CKM["CKM_CAST5_MAC_GENERAL"] = CKM_CAST5_MAC_GENERAL
CKM[CKM_CAST5_MAC_GENERAL] = "CKM_CAST5_MAC_GENERAL"

CKM_CAST128_MAC_GENERAL = PyKCS11.LowLevel.CKM_CAST128_MAC_GENERAL
CKM["CKM_CAST128_MAC_GENERAL"] = CKM_CAST128_MAC_GENERAL
CKM[CKM_CAST128_MAC_GENERAL] = "CKM_CAST128_MAC_GENERAL"

CKM_CAST5_CBC_PAD = PyKCS11.LowLevel.CKM_CAST5_CBC_PAD
CKM["CKM_CAST5_CBC_PAD"] = CKM_CAST5_CBC_PAD
CKM[CKM_CAST5_CBC_PAD] = "CKM_CAST5_CBC_PAD"

CKM_CAST128_CBC_PAD = PyKCS11.LowLevel.CKM_CAST128_CBC_PAD
CKM["CKM_CAST128_CBC_PAD"] = CKM_CAST128_CBC_PAD
CKM[CKM_CAST128_CBC_PAD] = "CKM_CAST128_CBC_PAD"

CKM_RC5_KEY_GEN = PyKCS11.LowLevel.CKM_RC5_KEY_GEN
CKM["CKM_RC5_KEY_GEN"] = CKM_RC5_KEY_GEN
CKM[CKM_RC5_KEY_GEN] = "CKM_RC5_KEY_GEN"

CKM_RC5_ECB = PyKCS11.LowLevel.CKM_RC5_ECB
CKM["CKM_RC5_ECB"] = CKM_RC5_ECB
CKM[CKM_RC5_ECB] = "CKM_RC5_ECB"

CKM_RC5_CBC = PyKCS11.LowLevel.CKM_RC5_CBC
CKM["CKM_RC5_CBC"] = CKM_RC5_CBC
CKM[CKM_RC5_CBC] = "CKM_RC5_CBC"

CKM_RC5_MAC = PyKCS11.LowLevel.CKM_RC5_MAC
CKM["CKM_RC5_MAC"] = CKM_RC5_MAC
CKM[CKM_RC5_MAC] = "CKM_RC5_MAC"

CKM_RC5_MAC_GENERAL = PyKCS11.LowLevel.CKM_RC5_MAC_GENERAL
CKM["CKM_RC5_MAC_GENERAL"] = CKM_RC5_MAC_GENERAL
CKM[CKM_RC5_MAC_GENERAL] = "CKM_RC5_MAC_GENERAL"

CKM_RC5_CBC_PAD = PyKCS11.LowLevel.CKM_RC5_CBC_PAD
CKM["CKM_RC5_CBC_PAD"] = CKM_RC5_CBC_PAD
CKM[CKM_RC5_CBC_PAD] = "CKM_RC5_CBC_PAD"

CKM_IDEA_KEY_GEN = PyKCS11.LowLevel.CKM_IDEA_KEY_GEN
CKM["CKM_IDEA_KEY_GEN"] = CKM_IDEA_KEY_GEN
CKM[CKM_IDEA_KEY_GEN] = "CKM_IDEA_KEY_GEN"

CKM_IDEA_ECB = PyKCS11.LowLevel.CKM_IDEA_ECB
CKM["CKM_IDEA_ECB"] = CKM_IDEA_ECB
CKM[CKM_IDEA_ECB] = "CKM_IDEA_ECB"

CKM_IDEA_CBC = PyKCS11.LowLevel.CKM_IDEA_CBC
CKM["CKM_IDEA_CBC"] = CKM_IDEA_CBC
CKM[CKM_IDEA_CBC] = "CKM_IDEA_CBC"

CKM_IDEA_MAC = PyKCS11.LowLevel.CKM_IDEA_MAC
CKM["CKM_IDEA_MAC"] = CKM_IDEA_MAC
CKM[CKM_IDEA_MAC] = "CKM_IDEA_MAC"

CKM_IDEA_MAC_GENERAL = PyKCS11.LowLevel.CKM_IDEA_MAC_GENERAL
CKM["CKM_IDEA_MAC_GENERAL"] = CKM_IDEA_MAC_GENERAL
CKM[CKM_IDEA_MAC_GENERAL] = "CKM_IDEA_MAC_GENERAL"

CKM_IDEA_CBC_PAD = PyKCS11.LowLevel.CKM_IDEA_CBC_PAD
CKM["CKM_IDEA_CBC_PAD"] = CKM_IDEA_CBC_PAD
CKM[CKM_IDEA_CBC_PAD] = "CKM_IDEA_CBC_PAD"

CKM_GENERIC_SECRET_KEY_GEN = PyKCS11.LowLevel.CKM_GENERIC_SECRET_KEY_GEN
CKM["CKM_GENERIC_SECRET_KEY_GEN"] = CKM_GENERIC_SECRET_KEY_GEN
CKM[CKM_GENERIC_SECRET_KEY_GEN] = "CKM_GENERIC_SECRET_KEY_GEN"

CKM_CONCATENATE_BASE_AND_KEY = PyKCS11.LowLevel.CKM_CONCATENATE_BASE_AND_KEY
CKM["CKM_CONCATENATE_BASE_AND_KEY"] = CKM_CONCATENATE_BASE_AND_KEY
CKM[CKM_CONCATENATE_BASE_AND_KEY] = "CKM_CONCATENATE_BASE_AND_KEY"

CKM_CONCATENATE_BASE_AND_DATA = PyKCS11.LowLevel.CKM_CONCATENATE_BASE_AND_DATA
CKM["CKM_CONCATENATE_BASE_AND_DATA"] = CKM_CONCATENATE_BASE_AND_DATA
CKM[CKM_CONCATENATE_BASE_AND_DATA] = "CKM_CONCATENATE_BASE_AND_DATA"

CKM_CONCATENATE_DATA_AND_BASE = PyKCS11.LowLevel.CKM_CONCATENATE_DATA_AND_BASE
CKM["CKM_CONCATENATE_DATA_AND_BASE"] = CKM_CONCATENATE_DATA_AND_BASE
CKM[CKM_CONCATENATE_DATA_AND_BASE] = "CKM_CONCATENATE_DATA_AND_BASE"

CKM_XOR_BASE_AND_DATA = PyKCS11.LowLevel.CKM_XOR_BASE_AND_DATA
CKM["CKM_XOR_BASE_AND_DATA"] = CKM_XOR_BASE_AND_DATA
CKM[CKM_XOR_BASE_AND_DATA] = "CKM_XOR_BASE_AND_DATA"

CKM_EXTRACT_KEY_FROM_KEY = PyKCS11.LowLevel.CKM_EXTRACT_KEY_FROM_KEY
CKM["CKM_EXTRACT_KEY_FROM_KEY"] = CKM_EXTRACT_KEY_FROM_KEY
CKM[CKM_EXTRACT_KEY_FROM_KEY] = "CKM_EXTRACT_KEY_FROM_KEY"

CKM_SSL3_PRE_MASTER_KEY_GEN = PyKCS11.LowLevel.CKM_SSL3_PRE_MASTER_KEY_GEN
CKM["CKM_SSL3_PRE_MASTER_KEY_GEN"] = CKM_SSL3_PRE_MASTER_KEY_GEN
CKM[CKM_SSL3_PRE_MASTER_KEY_GEN] = "CKM_SSL3_PRE_MASTER_KEY_GEN"

CKM_SSL3_MASTER_KEY_DERIVE = PyKCS11.LowLevel.CKM_SSL3_MASTER_KEY_DERIVE
CKM["CKM_SSL3_MASTER_KEY_DERIVE"] = CKM_SSL3_MASTER_KEY_DERIVE
CKM[CKM_SSL3_MASTER_KEY_DERIVE] = "CKM_SSL3_MASTER_KEY_DERIVE"

CKM_SSL3_KEY_AND_MAC_DERIVE = PyKCS11.LowLevel.CKM_SSL3_KEY_AND_MAC_DERIVE
CKM["CKM_SSL3_KEY_AND_MAC_DERIVE"] = CKM_SSL3_KEY_AND_MAC_DERIVE
CKM[CKM_SSL3_KEY_AND_MAC_DERIVE] = "CKM_SSL3_KEY_AND_MAC_DERIVE"

CKM_SSL3_MASTER_KEY_DERIVE_DH = PyKCS11.LowLevel.CKM_SSL3_MASTER_KEY_DERIVE_DH
CKM["CKM_SSL3_MASTER_KEY_DERIVE_DH"] = CKM_SSL3_MASTER_KEY_DERIVE_DH
CKM[CKM_SSL3_MASTER_KEY_DERIVE_DH] = "CKM_SSL3_MASTER_KEY_DERIVE_DH"

CKM_TLS_PRE_MASTER_KEY_GEN = PyKCS11.LowLevel.CKM_TLS_PRE_MASTER_KEY_GEN
CKM["CKM_TLS_PRE_MASTER_KEY_GEN"] = CKM_TLS_PRE_MASTER_KEY_GEN
CKM[CKM_TLS_PRE_MASTER_KEY_GEN] = "CKM_TLS_PRE_MASTER_KEY_GEN"

CKM_TLS_MASTER_KEY_DERIVE = PyKCS11.LowLevel.CKM_TLS_MASTER_KEY_DERIVE
CKM["CKM_TLS_MASTER_KEY_DERIVE"] = CKM_TLS_MASTER_KEY_DERIVE
CKM[CKM_TLS_MASTER_KEY_DERIVE] = "CKM_TLS_MASTER_KEY_DERIVE"

CKM_TLS_KEY_AND_MAC_DERIVE = PyKCS11.LowLevel.CKM_TLS_KEY_AND_MAC_DERIVE
CKM["CKM_TLS_KEY_AND_MAC_DERIVE"] = CKM_TLS_KEY_AND_MAC_DERIVE
CKM[CKM_TLS_KEY_AND_MAC_DERIVE] = "CKM_TLS_KEY_AND_MAC_DERIVE"

CKM_TLS_MASTER_KEY_DERIVE_DH = PyKCS11.LowLevel.CKM_TLS_MASTER_KEY_DERIVE_DH
CKM["CKM_TLS_MASTER_KEY_DERIVE_DH"] = CKM_TLS_MASTER_KEY_DERIVE_DH
CKM[CKM_TLS_MASTER_KEY_DERIVE_DH] = "CKM_TLS_MASTER_KEY_DERIVE_DH"

CKM_TLS_PRF = PyKCS11.LowLevel.CKM_TLS_PRF
CKM["CKM_TLS_PRF"] = CKM_TLS_PRF
CKM[CKM_TLS_PRF] = "CKM_TLS_PRF"

CKM_SSL3_MD5_MAC = PyKCS11.LowLevel.CKM_SSL3_MD5_MAC
CKM["CKM_SSL3_MD5_MAC"] = CKM_SSL3_MD5_MAC
CKM[CKM_SSL3_MD5_MAC] = "CKM_SSL3_MD5_MAC"

CKM_SSL3_SHA1_MAC = PyKCS11.LowLevel.CKM_SSL3_SHA1_MAC
CKM["CKM_SSL3_SHA1_MAC"] = CKM_SSL3_SHA1_MAC
CKM[CKM_SSL3_SHA1_MAC] = "CKM_SSL3_SHA1_MAC"

CKM_MD5_KEY_DERIVATION = PyKCS11.LowLevel.CKM_MD5_KEY_DERIVATION
CKM["CKM_MD5_KEY_DERIVATION"] = CKM_MD5_KEY_DERIVATION
CKM[CKM_MD5_KEY_DERIVATION] = "CKM_MD5_KEY_DERIVATION"

CKM_MD2_KEY_DERIVATION = PyKCS11.LowLevel.CKM_MD2_KEY_DERIVATION
CKM["CKM_MD2_KEY_DERIVATION"] = CKM_MD2_KEY_DERIVATION
CKM[CKM_MD2_KEY_DERIVATION] = "CKM_MD2_KEY_DERIVATION"

CKM_SHA1_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA1_KEY_DERIVATION
CKM["CKM_SHA1_KEY_DERIVATION"] = CKM_SHA1_KEY_DERIVATION
CKM[CKM_SHA1_KEY_DERIVATION] = "CKM_SHA1_KEY_DERIVATION"

CKM_SHA256_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA256_KEY_DERIVATION
CKM["CKM_SHA256_KEY_DERIVATION"] = CKM_SHA256_KEY_DERIVATION
CKM[CKM_SHA256_KEY_DERIVATION] = "CKM_SHA256_KEY_DERIVATION"

CKM_SHA384_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA384_KEY_DERIVATION
CKM["CKM_SHA384_KEY_DERIVATION"] = CKM_SHA384_KEY_DERIVATION
CKM[CKM_SHA384_KEY_DERIVATION] = "CKM_SHA384_KEY_DERIVATION"

CKM_SHA512_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA512_KEY_DERIVATION
CKM["CKM_SHA512_KEY_DERIVATION"] = CKM_SHA512_KEY_DERIVATION
CKM[CKM_SHA512_KEY_DERIVATION] = "CKM_SHA512_KEY_DERIVATION"

CKM_SHA224_KEY_DERIVATION = PyKCS11.LowLevel.CKM_SHA224_KEY_DERIVATION
CKM["CKM_SHA224_KEY_DERIVATION"] = CKM_SHA224_KEY_DERIVATION
CKM[CKM_SHA224_KEY_DERIVATION] = "CKM_SHA224_KEY_DERIVATION"

CKM_SHA3_256_KEY_DERIVE = PyKCS11.LowLevel.CKM_SHA3_256_KEY_DERIVE
CKM["CKM_SHA3_256_KEY_DERIVE"] = CKM_SHA3_256_KEY_DERIVE
CKM[CKM_SHA3_256_KEY_DERIVE] = "CKM_SHA3_256_KEY_DERIVE"

CKM_SHA3_224_KEY_DERIVE = PyKCS11.LowLevel.CKM_SHA3_224_KEY_DERIVE
CKM["CKM_SHA3_224_KEY_DERIVE"] = CKM_SHA3_224_KEY_DERIVE
CKM[CKM_SHA3_224_KEY_DERIVE] = "CKM_SHA3_224_KEY_DERIVE"

CKM_SHA3_384_KEY_DERIVE = PyKCS11.LowLevel.CKM_SHA3_384_KEY_DERIVE
CKM["CKM_SHA3_384_KEY_DERIVE"] = CKM_SHA3_384_KEY_DERIVE
CKM[CKM_SHA3_384_KEY_DERIVE] = "CKM_SHA3_384_KEY_DERIVE"

CKM_SHA3_512_KEY_DERIVE = PyKCS11.LowLevel.CKM_SHA3_512_KEY_DERIVE
CKM["CKM_SHA3_512_KEY_DERIVE"] = CKM_SHA3_512_KEY_DERIVE
CKM[CKM_SHA3_512_KEY_DERIVE] = "CKM_SHA3_512_KEY_DERIVE"

CKM_SHAKE_128_KEY_DERIVE = PyKCS11.LowLevel.CKM_SHAKE_128_KEY_DERIVE
CKM["CKM_SHAKE_128_KEY_DERIVE"] = CKM_SHAKE_128_KEY_DERIVE
CKM[CKM_SHAKE_128_KEY_DERIVE] = "CKM_SHAKE_128_KEY_DERIVE"

CKM_SHAKE_256_KEY_DERIVE = PyKCS11.LowLevel.CKM_SHAKE_256_KEY_DERIVE
CKM["CKM_SHAKE_256_KEY_DERIVE"] = CKM_SHAKE_256_KEY_DERIVE
CKM[CKM_SHAKE_256_KEY_DERIVE] = "CKM_SHAKE_256_KEY_DERIVE"

CKM_PBE_MD2_DES_CBC = PyKCS11.LowLevel.CKM_PBE_MD2_DES_CBC
CKM["CKM_PBE_MD2_DES_CBC"] = CKM_PBE_MD2_DES_CBC
CKM[CKM_PBE_MD2_DES_CBC] = "CKM_PBE_MD2_DES_CBC"

CKM_PBE_MD5_DES_CBC = PyKCS11.LowLevel.CKM_PBE_MD5_DES_CBC
CKM["CKM_PBE_MD5_DES_CBC"] = CKM_PBE_MD5_DES_CBC
CKM[CKM_PBE_MD5_DES_CBC] = "CKM_PBE_MD5_DES_CBC"

CKM_PBE_MD5_CAST_CBC = PyKCS11.LowLevel.CKM_PBE_MD5_CAST_CBC
CKM["CKM_PBE_MD5_CAST_CBC"] = CKM_PBE_MD5_CAST_CBC
CKM[CKM_PBE_MD5_CAST_CBC] = "CKM_PBE_MD5_CAST_CBC"

CKM_PBE_MD5_CAST3_CBC = PyKCS11.LowLevel.CKM_PBE_MD5_CAST3_CBC
CKM["CKM_PBE_MD5_CAST3_CBC"] = CKM_PBE_MD5_CAST3_CBC
CKM[CKM_PBE_MD5_CAST3_CBC] = "CKM_PBE_MD5_CAST3_CBC"

CKM_PBE_MD5_CAST5_CBC = PyKCS11.LowLevel.CKM_PBE_MD5_CAST5_CBC
CKM["CKM_PBE_MD5_CAST5_CBC"] = CKM_PBE_MD5_CAST5_CBC
CKM[CKM_PBE_MD5_CAST5_CBC] = "CKM_PBE_MD5_CAST5_CBC"

CKM_PBE_MD5_CAST128_CBC = PyKCS11.LowLevel.CKM_PBE_MD5_CAST128_CBC
CKM["CKM_PBE_MD5_CAST128_CBC"] = CKM_PBE_MD5_CAST128_CBC
CKM[CKM_PBE_MD5_CAST128_CBC] = "CKM_PBE_MD5_CAST128_CBC"

CKM_PBE_SHA1_CAST5_CBC = PyKCS11.LowLevel.CKM_PBE_SHA1_CAST5_CBC
CKM["CKM_PBE_SHA1_CAST5_CBC"] = CKM_PBE_SHA1_CAST5_CBC
CKM[CKM_PBE_SHA1_CAST5_CBC] = "CKM_PBE_SHA1_CAST5_CBC"

CKM_PBE_SHA1_CAST128_CBC = PyKCS11.LowLevel.CKM_PBE_SHA1_CAST128_CBC
CKM["CKM_PBE_SHA1_CAST128_CBC"] = CKM_PBE_SHA1_CAST128_CBC
CKM[CKM_PBE_SHA1_CAST128_CBC] = "CKM_PBE_SHA1_CAST128_CBC"

CKM_PBE_SHA1_RC4_128 = PyKCS11.LowLevel.CKM_PBE_SHA1_RC4_128
CKM["CKM_PBE_SHA1_RC4_128"] = CKM_PBE_SHA1_RC4_128
CKM[CKM_PBE_SHA1_RC4_128] = "CKM_PBE_SHA1_RC4_128"

CKM_PBE_SHA1_RC4_40 = PyKCS11.LowLevel.CKM_PBE_SHA1_RC4_40
CKM["CKM_PBE_SHA1_RC4_40"] = CKM_PBE_SHA1_RC4_40
CKM[CKM_PBE_SHA1_RC4_40] = "CKM_PBE_SHA1_RC4_40"

CKM_PBE_SHA1_DES3_EDE_CBC = PyKCS11.LowLevel.CKM_PBE_SHA1_DES3_EDE_CBC
CKM["CKM_PBE_SHA1_DES3_EDE_CBC"] = CKM_PBE_SHA1_DES3_EDE_CBC
CKM[CKM_PBE_SHA1_DES3_EDE_CBC] = "CKM_PBE_SHA1_DES3_EDE_CBC"

CKM_PBE_SHA1_DES2_EDE_CBC = PyKCS11.LowLevel.CKM_PBE_SHA1_DES2_EDE_CBC
CKM["CKM_PBE_SHA1_DES2_EDE_CBC"] = CKM_PBE_SHA1_DES2_EDE_CBC
CKM[CKM_PBE_SHA1_DES2_EDE_CBC] = "CKM_PBE_SHA1_DES2_EDE_CBC"

CKM_PBE_SHA1_RC2_128_CBC = PyKCS11.LowLevel.CKM_PBE_SHA1_RC2_128_CBC
CKM["CKM_PBE_SHA1_RC2_128_CBC"] = CKM_PBE_SHA1_RC2_128_CBC
CKM[CKM_PBE_SHA1_RC2_128_CBC] = "CKM_PBE_SHA1_RC2_128_CBC"

CKM_PBE_SHA1_RC2_40_CBC = PyKCS11.LowLevel.CKM_PBE_SHA1_RC2_40_CBC
CKM["CKM_PBE_SHA1_RC2_40_CBC"] = CKM_PBE_SHA1_RC2_40_CBC
CKM[CKM_PBE_SHA1_RC2_40_CBC] = "CKM_PBE_SHA1_RC2_40_CBC"

CKM_SP800_108_COUNTER_KDF = PyKCS11.LowLevel.CKM_SP800_108_COUNTER_KDF
CKM["CKM_SP800_108_COUNTER_KDF"] = CKM_SP800_108_COUNTER_KDF
CKM[CKM_SP800_108_COUNTER_KDF] = "CKM_SP800_108_COUNTER_KDF"

CKM_SP800_108_FEEDBACK_KDF = PyKCS11.LowLevel.CKM_SP800_108_FEEDBACK_KDF
CKM["CKM_SP800_108_FEEDBACK_KDF"] = CKM_SP800_108_FEEDBACK_KDF
CKM[CKM_SP800_108_FEEDBACK_KDF] = "CKM_SP800_108_FEEDBACK_KDF"

CKM_SP800_108_DOUBLE_PIPELINE_KDF = PyKCS11.LowLevel.CKM_SP800_108_DOUBLE_PIPELINE_KDF
CKM["CKM_SP800_108_DOUBLE_PIPELINE_KDF"] = CKM_SP800_108_DOUBLE_PIPELINE_KDF
CKM[CKM_SP800_108_DOUBLE_PIPELINE_KDF] = "CKM_SP800_108_DOUBLE_PIPELINE_KDF"

CKM_PKCS5_PBKD2 = PyKCS11.LowLevel.CKM_PKCS5_PBKD2
CKM["CKM_PKCS5_PBKD2"] = CKM_PKCS5_PBKD2
CKM[CKM_PKCS5_PBKD2] = "CKM_PKCS5_PBKD2"

CKM_PBA_SHA1_WITH_SHA1_HMAC = PyKCS11.LowLevel.CKM_PBA_SHA1_WITH_SHA1_HMAC
CKM["CKM_PBA_SHA1_WITH_SHA1_HMAC"] = CKM_PBA_SHA1_WITH_SHA1_HMAC
CKM[CKM_PBA_SHA1_WITH_SHA1_HMAC] = "CKM_PBA_SHA1_WITH_SHA1_HMAC"

CKM_WTLS_PRE_MASTER_KEY_GEN = PyKCS11.LowLevel.CKM_WTLS_PRE_MASTER_KEY_GEN
CKM["CKM_WTLS_PRE_MASTER_KEY_GEN"] = CKM_WTLS_PRE_MASTER_KEY_GEN
CKM[CKM_WTLS_PRE_MASTER_KEY_GEN] = "CKM_WTLS_PRE_MASTER_KEY_GEN"

CKM_WTLS_MASTER_KEY_DERIVE = PyKCS11.LowLevel.CKM_WTLS_MASTER_KEY_DERIVE
CKM["CKM_WTLS_MASTER_KEY_DERIVE"] = CKM_WTLS_MASTER_KEY_DERIVE
CKM[CKM_WTLS_MASTER_KEY_DERIVE] = "CKM_WTLS_MASTER_KEY_DERIVE"

CKM_WTLS_MASTER_KEY_DERIVE_DH_ECC = PyKCS11.LowLevel.CKM_WTLS_MASTER_KEY_DERIVE_DH_ECC
CKM["CKM_WTLS_MASTER_KEY_DERIVE_DH_ECC"] = CKM_WTLS_MASTER_KEY_DERIVE_DH_ECC
CKM[CKM_WTLS_MASTER_KEY_DERIVE_DH_ECC] = "CKM_WTLS_MASTER_KEY_DERIVE_DH_ECC"

CKM_WTLS_PRF = PyKCS11.LowLevel.CKM_WTLS_PRF
CKM["CKM_WTLS_PRF"] = CKM_WTLS_PRF
CKM[CKM_WTLS_PRF] = "CKM_WTLS_PRF"

CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE = PyKCS11.LowLevel.CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE
CKM["CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE"] = CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE
CKM[CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE] = "CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE"

CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE = PyKCS11.LowLevel.CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE
CKM["CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE"] = CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE
CKM[CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE] = "CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE"

CKM_TLS10_MAC_SERVER = PyKCS11.LowLevel.CKM_TLS10_MAC_SERVER
CKM["CKM_TLS10_MAC_SERVER"] = CKM_TLS10_MAC_SERVER
CKM[CKM_TLS10_MAC_SERVER] = "CKM_TLS10_MAC_SERVER"

CKM_TLS10_MAC_CLIENT = PyKCS11.LowLevel.CKM_TLS10_MAC_CLIENT
CKM["CKM_TLS10_MAC_CLIENT"] = CKM_TLS10_MAC_CLIENT
CKM[CKM_TLS10_MAC_CLIENT] = "CKM_TLS10_MAC_CLIENT"

CKM_TLS12_MAC = PyKCS11.LowLevel.CKM_TLS12_MAC
CKM["CKM_TLS12_MAC"] = CKM_TLS12_MAC
CKM[CKM_TLS12_MAC] = "CKM_TLS12_MAC"

CKM_TLS12_KDF = PyKCS11.LowLevel.CKM_TLS12_KDF
CKM["CKM_TLS12_KDF"] = CKM_TLS12_KDF
CKM[CKM_TLS12_KDF] = "CKM_TLS12_KDF"

CKM_TLS12_MASTER_KEY_DERIVE = PyKCS11.LowLevel.CKM_TLS12_MASTER_KEY_DERIVE
CKM["CKM_TLS12_MASTER_KEY_DERIVE"] = CKM_TLS12_MASTER_KEY_DERIVE
CKM[CKM_TLS12_MASTER_KEY_DERIVE] = "CKM_TLS12_MASTER_KEY_DERIVE"

CKM_TLS12_KEY_AND_MAC_DERIVE = PyKCS11.LowLevel.CKM_TLS12_KEY_AND_MAC_DERIVE
CKM["CKM_TLS12_KEY_AND_MAC_DERIVE"] = CKM_TLS12_KEY_AND_MAC_DERIVE
CKM[CKM_TLS12_KEY_AND_MAC_DERIVE] = "CKM_TLS12_KEY_AND_MAC_DERIVE"

CKM_TLS12_MASTER_KEY_DERIVE_DH = PyKCS11.LowLevel.CKM_TLS12_MASTER_KEY_DERIVE_DH
CKM["CKM_TLS12_MASTER_KEY_DERIVE_DH"] = CKM_TLS12_MASTER_KEY_DERIVE_DH
CKM[CKM_TLS12_MASTER_KEY_DERIVE_DH] = "CKM_TLS12_MASTER_KEY_DERIVE_DH"

CKM_TLS12_KEY_SAFE_DERIVE = PyKCS11.LowLevel.CKM_TLS12_KEY_SAFE_DERIVE
CKM["CKM_TLS12_KEY_SAFE_DERIVE"] = CKM_TLS12_KEY_SAFE_DERIVE
CKM[CKM_TLS12_KEY_SAFE_DERIVE] = "CKM_TLS12_KEY_SAFE_DERIVE"

CKM_TLS_MAC = PyKCS11.LowLevel.CKM_TLS_MAC
CKM["CKM_TLS_MAC"] = CKM_TLS_MAC
CKM[CKM_TLS_MAC] = "CKM_TLS_MAC"

CKM_TLS_KDF = PyKCS11.LowLevel.CKM_TLS_KDF
CKM["CKM_TLS_KDF"] = CKM_TLS_KDF
CKM[CKM_TLS_KDF] = "CKM_TLS_KDF"

CKM_KEY_WRAP_LYNKS = PyKCS11.LowLevel.CKM_KEY_WRAP_LYNKS
CKM["CKM_KEY_WRAP_LYNKS"] = CKM_KEY_WRAP_LYNKS
CKM[CKM_KEY_WRAP_LYNKS] = "CKM_KEY_WRAP_LYNKS"

CKM_KEY_WRAP_SET_OAEP = PyKCS11.LowLevel.CKM_KEY_WRAP_SET_OAEP
CKM["CKM_KEY_WRAP_SET_OAEP"] = CKM_KEY_WRAP_SET_OAEP
CKM[CKM_KEY_WRAP_SET_OAEP] = "CKM_KEY_WRAP_SET_OAEP"

CKM_CMS_SIG = PyKCS11.LowLevel.CKM_CMS_SIG
CKM["CKM_CMS_SIG"] = CKM_CMS_SIG
CKM[CKM_CMS_SIG] = "CKM_CMS_SIG"

CKM_KIP_DERIVE = PyKCS11.LowLevel.CKM_KIP_DERIVE
CKM["CKM_KIP_DERIVE"] = CKM_KIP_DERIVE
CKM[CKM_KIP_DERIVE] = "CKM_KIP_DERIVE"

CKM_KIP_WRAP = PyKCS11.LowLevel.CKM_KIP_WRAP
CKM["CKM_KIP_WRAP"] = CKM_KIP_WRAP
CKM[CKM_KIP_WRAP] = "CKM_KIP_WRAP"

CKM_KIP_MAC = PyKCS11.LowLevel.CKM_KIP_MAC
CKM["CKM_KIP_MAC"] = CKM_KIP_MAC
CKM[CKM_KIP_MAC] = "CKM_KIP_MAC"

CKM_CAMELLIA_KEY_GEN = PyKCS11.LowLevel.CKM_CAMELLIA_KEY_GEN
CKM["CKM_CAMELLIA_KEY_GEN"] = CKM_CAMELLIA_KEY_GEN
CKM[CKM_CAMELLIA_KEY_GEN] = "CKM_CAMELLIA_KEY_GEN"

CKM_CAMELLIA_ECB = PyKCS11.LowLevel.CKM_CAMELLIA_ECB
CKM["CKM_CAMELLIA_ECB"] = CKM_CAMELLIA_ECB
CKM[CKM_CAMELLIA_ECB] = "CKM_CAMELLIA_ECB"

CKM_CAMELLIA_CBC = PyKCS11.LowLevel.CKM_CAMELLIA_CBC
CKM["CKM_CAMELLIA_CBC"] = CKM_CAMELLIA_CBC
CKM[CKM_CAMELLIA_CBC] = "CKM_CAMELLIA_CBC"

CKM_CAMELLIA_MAC = PyKCS11.LowLevel.CKM_CAMELLIA_MAC
CKM["CKM_CAMELLIA_MAC"] = CKM_CAMELLIA_MAC
CKM[CKM_CAMELLIA_MAC] = "CKM_CAMELLIA_MAC"

CKM_CAMELLIA_MAC_GENERAL = PyKCS11.LowLevel.CKM_CAMELLIA_MAC_GENERAL
CKM["CKM_CAMELLIA_MAC_GENERAL"] = CKM_CAMELLIA_MAC_GENERAL
CKM[CKM_CAMELLIA_MAC_GENERAL] = "CKM_CAMELLIA_MAC_GENERAL"

CKM_CAMELLIA_CBC_PAD = PyKCS11.LowLevel.CKM_CAMELLIA_CBC_PAD
CKM["CKM_CAMELLIA_CBC_PAD"] = CKM_CAMELLIA_CBC_PAD
CKM[CKM_CAMELLIA_CBC_PAD] = "CKM_CAMELLIA_CBC_PAD"

CKM_CAMELLIA_ECB_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_CAMELLIA_ECB_ENCRYPT_DATA
CKM["CKM_CAMELLIA_ECB_ENCRYPT_DATA"] = CKM_CAMELLIA_ECB_ENCRYPT_DATA
CKM[CKM_CAMELLIA_ECB_ENCRYPT_DATA] = "CKM_CAMELLIA_ECB_ENCRYPT_DATA"

CKM_CAMELLIA_CBC_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_CAMELLIA_CBC_ENCRYPT_DATA
CKM["CKM_CAMELLIA_CBC_ENCRYPT_DATA"] = CKM_CAMELLIA_CBC_ENCRYPT_DATA
CKM[CKM_CAMELLIA_CBC_ENCRYPT_DATA] = "CKM_CAMELLIA_CBC_ENCRYPT_DATA"

CKM_CAMELLIA_CTR = PyKCS11.LowLevel.CKM_CAMELLIA_CTR
CKM["CKM_CAMELLIA_CTR"] = CKM_CAMELLIA_CTR
CKM[CKM_CAMELLIA_CTR] = "CKM_CAMELLIA_CTR"

CKM_ARIA_KEY_GEN = PyKCS11.LowLevel.CKM_ARIA_KEY_GEN
CKM["CKM_ARIA_KEY_GEN"] = CKM_ARIA_KEY_GEN
CKM[CKM_ARIA_KEY_GEN] = "CKM_ARIA_KEY_GEN"

CKM_ARIA_ECB = PyKCS11.LowLevel.CKM_ARIA_ECB
CKM["CKM_ARIA_ECB"] = CKM_ARIA_ECB
CKM[CKM_ARIA_ECB] = "CKM_ARIA_ECB"

CKM_ARIA_CBC = PyKCS11.LowLevel.CKM_ARIA_CBC
CKM["CKM_ARIA_CBC"] = CKM_ARIA_CBC
CKM[CKM_ARIA_CBC] = "CKM_ARIA_CBC"

CKM_ARIA_MAC = PyKCS11.LowLevel.CKM_ARIA_MAC
CKM["CKM_ARIA_MAC"] = CKM_ARIA_MAC
CKM[CKM_ARIA_MAC] = "CKM_ARIA_MAC"

CKM_ARIA_MAC_GENERAL = PyKCS11.LowLevel.CKM_ARIA_MAC_GENERAL
CKM["CKM_ARIA_MAC_GENERAL"] = CKM_ARIA_MAC_GENERAL
CKM[CKM_ARIA_MAC_GENERAL] = "CKM_ARIA_MAC_GENERAL"

CKM_ARIA_CBC_PAD = PyKCS11.LowLevel.CKM_ARIA_CBC_PAD
CKM["CKM_ARIA_CBC_PAD"] = CKM_ARIA_CBC_PAD
CKM[CKM_ARIA_CBC_PAD] = "CKM_ARIA_CBC_PAD"

CKM_ARIA_ECB_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_ARIA_ECB_ENCRYPT_DATA
CKM["CKM_ARIA_ECB_ENCRYPT_DATA"] = CKM_ARIA_ECB_ENCRYPT_DATA
CKM[CKM_ARIA_ECB_ENCRYPT_DATA] = "CKM_ARIA_ECB_ENCRYPT_DATA"

CKM_ARIA_CBC_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_ARIA_CBC_ENCRYPT_DATA
CKM["CKM_ARIA_CBC_ENCRYPT_DATA"] = CKM_ARIA_CBC_ENCRYPT_DATA
CKM[CKM_ARIA_CBC_ENCRYPT_DATA] = "CKM_ARIA_CBC_ENCRYPT_DATA"

CKM_SEED_KEY_GEN = PyKCS11.LowLevel.CKM_SEED_KEY_GEN
CKM["CKM_SEED_KEY_GEN"] = CKM_SEED_KEY_GEN
CKM[CKM_SEED_KEY_GEN] = "CKM_SEED_KEY_GEN"

CKM_SEED_ECB = PyKCS11.LowLevel.CKM_SEED_ECB
CKM["CKM_SEED_ECB"] = CKM_SEED_ECB
CKM[CKM_SEED_ECB] = "CKM_SEED_ECB"

CKM_SEED_CBC = PyKCS11.LowLevel.CKM_SEED_CBC
CKM["CKM_SEED_CBC"] = CKM_SEED_CBC
CKM[CKM_SEED_CBC] = "CKM_SEED_CBC"

CKM_SEED_MAC = PyKCS11.LowLevel.CKM_SEED_MAC
CKM["CKM_SEED_MAC"] = CKM_SEED_MAC
CKM[CKM_SEED_MAC] = "CKM_SEED_MAC"

CKM_SEED_MAC_GENERAL = PyKCS11.LowLevel.CKM_SEED_MAC_GENERAL
CKM["CKM_SEED_MAC_GENERAL"] = CKM_SEED_MAC_GENERAL
CKM[CKM_SEED_MAC_GENERAL] = "CKM_SEED_MAC_GENERAL"

CKM_SEED_CBC_PAD = PyKCS11.LowLevel.CKM_SEED_CBC_PAD
CKM["CKM_SEED_CBC_PAD"] = CKM_SEED_CBC_PAD
CKM[CKM_SEED_CBC_PAD] = "CKM_SEED_CBC_PAD"

CKM_SEED_ECB_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_SEED_ECB_ENCRYPT_DATA
CKM["CKM_SEED_ECB_ENCRYPT_DATA"] = CKM_SEED_ECB_ENCRYPT_DATA
CKM[CKM_SEED_ECB_ENCRYPT_DATA] = "CKM_SEED_ECB_ENCRYPT_DATA"

CKM_SEED_CBC_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_SEED_CBC_ENCRYPT_DATA
CKM["CKM_SEED_CBC_ENCRYPT_DATA"] = CKM_SEED_CBC_ENCRYPT_DATA
CKM[CKM_SEED_CBC_ENCRYPT_DATA] = "CKM_SEED_CBC_ENCRYPT_DATA"

CKM_SKIPJACK_KEY_GEN = PyKCS11.LowLevel.CKM_SKIPJACK_KEY_GEN
CKM["CKM_SKIPJACK_KEY_GEN"] = CKM_SKIPJACK_KEY_GEN
CKM[CKM_SKIPJACK_KEY_GEN] = "CKM_SKIPJACK_KEY_GEN"

CKM_SKIPJACK_ECB64 = PyKCS11.LowLevel.CKM_SKIPJACK_ECB64
CKM["CKM_SKIPJACK_ECB64"] = CKM_SKIPJACK_ECB64
CKM[CKM_SKIPJACK_ECB64] = "CKM_SKIPJACK_ECB64"

CKM_SKIPJACK_CBC64 = PyKCS11.LowLevel.CKM_SKIPJACK_CBC64
CKM["CKM_SKIPJACK_CBC64"] = CKM_SKIPJACK_CBC64
CKM[CKM_SKIPJACK_CBC64] = "CKM_SKIPJACK_CBC64"

CKM_SKIPJACK_OFB64 = PyKCS11.LowLevel.CKM_SKIPJACK_OFB64
CKM["CKM_SKIPJACK_OFB64"] = CKM_SKIPJACK_OFB64
CKM[CKM_SKIPJACK_OFB64] = "CKM_SKIPJACK_OFB64"

CKM_SKIPJACK_CFB64 = PyKCS11.LowLevel.CKM_SKIPJACK_CFB64
CKM["CKM_SKIPJACK_CFB64"] = CKM_SKIPJACK_CFB64
CKM[CKM_SKIPJACK_CFB64] = "CKM_SKIPJACK_CFB64"

CKM_SKIPJACK_CFB32 = PyKCS11.LowLevel.CKM_SKIPJACK_CFB32
CKM["CKM_SKIPJACK_CFB32"] = CKM_SKIPJACK_CFB32
CKM[CKM_SKIPJACK_CFB32] = "CKM_SKIPJACK_CFB32"

CKM_SKIPJACK_CFB16 = PyKCS11.LowLevel.CKM_SKIPJACK_CFB16
CKM["CKM_SKIPJACK_CFB16"] = CKM_SKIPJACK_CFB16
CKM[CKM_SKIPJACK_CFB16] = "CKM_SKIPJACK_CFB16"

CKM_SKIPJACK_CFB8 = PyKCS11.LowLevel.CKM_SKIPJACK_CFB8
CKM["CKM_SKIPJACK_CFB8"] = CKM_SKIPJACK_CFB8
CKM[CKM_SKIPJACK_CFB8] = "CKM_SKIPJACK_CFB8"

CKM_SKIPJACK_WRAP = PyKCS11.LowLevel.CKM_SKIPJACK_WRAP
CKM["CKM_SKIPJACK_WRAP"] = CKM_SKIPJACK_WRAP
CKM[CKM_SKIPJACK_WRAP] = "CKM_SKIPJACK_WRAP"

CKM_SKIPJACK_PRIVATE_WRAP = PyKCS11.LowLevel.CKM_SKIPJACK_PRIVATE_WRAP
CKM["CKM_SKIPJACK_PRIVATE_WRAP"] = CKM_SKIPJACK_PRIVATE_WRAP
CKM[CKM_SKIPJACK_PRIVATE_WRAP] = "CKM_SKIPJACK_PRIVATE_WRAP"

CKM_SKIPJACK_RELAYX = PyKCS11.LowLevel.CKM_SKIPJACK_RELAYX
CKM["CKM_SKIPJACK_RELAYX"] = CKM_SKIPJACK_RELAYX
CKM[CKM_SKIPJACK_RELAYX] = "CKM_SKIPJACK_RELAYX"

CKM_KEA_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_KEA_KEY_PAIR_GEN
CKM["CKM_KEA_KEY_PAIR_GEN"] = CKM_KEA_KEY_PAIR_GEN
CKM[CKM_KEA_KEY_PAIR_GEN] = "CKM_KEA_KEY_PAIR_GEN"

CKM_KEA_KEY_DERIVE = PyKCS11.LowLevel.CKM_KEA_KEY_DERIVE
CKM["CKM_KEA_KEY_DERIVE"] = CKM_KEA_KEY_DERIVE
CKM[CKM_KEA_KEY_DERIVE] = "CKM_KEA_KEY_DERIVE"

CKM_KEA_DERIVE = PyKCS11.LowLevel.CKM_KEA_DERIVE
CKM["CKM_KEA_DERIVE"] = CKM_KEA_DERIVE
CKM[CKM_KEA_DERIVE] = "CKM_KEA_DERIVE"

CKM_FORTEZZA_TIMESTAMP = PyKCS11.LowLevel.CKM_FORTEZZA_TIMESTAMP
CKM["CKM_FORTEZZA_TIMESTAMP"] = CKM_FORTEZZA_TIMESTAMP
CKM[CKM_FORTEZZA_TIMESTAMP] = "CKM_FORTEZZA_TIMESTAMP"

CKM_BATON_KEY_GEN = PyKCS11.LowLevel.CKM_BATON_KEY_GEN
CKM["CKM_BATON_KEY_GEN"] = CKM_BATON_KEY_GEN
CKM[CKM_BATON_KEY_GEN] = "CKM_BATON_KEY_GEN"

CKM_BATON_ECB128 = PyKCS11.LowLevel.CKM_BATON_ECB128
CKM["CKM_BATON_ECB128"] = CKM_BATON_ECB128
CKM[CKM_BATON_ECB128] = "CKM_BATON_ECB128"

CKM_BATON_ECB96 = PyKCS11.LowLevel.CKM_BATON_ECB96
CKM["CKM_BATON_ECB96"] = CKM_BATON_ECB96
CKM[CKM_BATON_ECB96] = "CKM_BATON_ECB96"

CKM_BATON_CBC128 = PyKCS11.LowLevel.CKM_BATON_CBC128
CKM["CKM_BATON_CBC128"] = CKM_BATON_CBC128
CKM[CKM_BATON_CBC128] = "CKM_BATON_CBC128"

CKM_BATON_COUNTER = PyKCS11.LowLevel.CKM_BATON_COUNTER
CKM["CKM_BATON_COUNTER"] = CKM_BATON_COUNTER
CKM[CKM_BATON_COUNTER] = "CKM_BATON_COUNTER"

CKM_BATON_SHUFFLE = PyKCS11.LowLevel.CKM_BATON_SHUFFLE
CKM["CKM_BATON_SHUFFLE"] = CKM_BATON_SHUFFLE
CKM[CKM_BATON_SHUFFLE] = "CKM_BATON_SHUFFLE"

CKM_BATON_WRAP = PyKCS11.LowLevel.CKM_BATON_WRAP
CKM["CKM_BATON_WRAP"] = CKM_BATON_WRAP
CKM[CKM_BATON_WRAP] = "CKM_BATON_WRAP"

CKM_ECDSA_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_ECDSA_KEY_PAIR_GEN
CKM["CKM_ECDSA_KEY_PAIR_GEN"] = CKM_ECDSA_KEY_PAIR_GEN
CKM[CKM_ECDSA_KEY_PAIR_GEN] = "CKM_ECDSA_KEY_PAIR_GEN"

CKM_EC_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_EC_KEY_PAIR_GEN
CKM["CKM_EC_KEY_PAIR_GEN"] = CKM_EC_KEY_PAIR_GEN
CKM[CKM_EC_KEY_PAIR_GEN] = "CKM_EC_KEY_PAIR_GEN"

CKM_ECDSA = PyKCS11.LowLevel.CKM_ECDSA
CKM["CKM_ECDSA"] = CKM_ECDSA
CKM[CKM_ECDSA] = "CKM_ECDSA"

CKM_ECDSA_SHA1 = PyKCS11.LowLevel.CKM_ECDSA_SHA1
CKM["CKM_ECDSA_SHA1"] = CKM_ECDSA_SHA1
CKM[CKM_ECDSA_SHA1] = "CKM_ECDSA_SHA1"

CKM_ECDSA_SHA224 = PyKCS11.LowLevel.CKM_ECDSA_SHA224
CKM["CKM_ECDSA_SHA224"] = CKM_ECDSA_SHA224
CKM[CKM_ECDSA_SHA224] = "CKM_ECDSA_SHA224"

CKM_ECDSA_SHA256 = PyKCS11.LowLevel.CKM_ECDSA_SHA256
CKM["CKM_ECDSA_SHA256"] = CKM_ECDSA_SHA256
CKM[CKM_ECDSA_SHA256] = "CKM_ECDSA_SHA256"

CKM_ECDSA_SHA384 = PyKCS11.LowLevel.CKM_ECDSA_SHA384
CKM["CKM_ECDSA_SHA384"] = CKM_ECDSA_SHA384
CKM[CKM_ECDSA_SHA384] = "CKM_ECDSA_SHA384"

CKM_ECDSA_SHA512 = PyKCS11.LowLevel.CKM_ECDSA_SHA512
CKM["CKM_ECDSA_SHA512"] = CKM_ECDSA_SHA512
CKM[CKM_ECDSA_SHA512] = "CKM_ECDSA_SHA512"

CKM_ECDSA_SHA3_224 = PyKCS11.LowLevel.CKM_ECDSA_SHA3_224
CKM["CKM_ECDSA_SHA3_224"] = CKM_ECDSA_SHA3_224
CKM[CKM_ECDSA_SHA3_224] = "CKM_ECDSA_SHA3_224"

CKM_ECDSA_SHA3_256 = PyKCS11.LowLevel.CKM_ECDSA_SHA3_256
CKM["CKM_ECDSA_SHA3_256"] = CKM_ECDSA_SHA3_256
CKM[CKM_ECDSA_SHA3_256] = "CKM_ECDSA_SHA3_256"

CKM_ECDSA_SHA3_384 = PyKCS11.LowLevel.CKM_ECDSA_SHA3_384
CKM["CKM_ECDSA_SHA3_384"] = CKM_ECDSA_SHA3_384
CKM[CKM_ECDSA_SHA3_384] = "CKM_ECDSA_SHA3_384"

CKM_ECDSA_SHA3_512 = PyKCS11.LowLevel.CKM_ECDSA_SHA3_512
CKM["CKM_ECDSA_SHA3_512"] = CKM_ECDSA_SHA3_512
CKM[CKM_ECDSA_SHA3_512] = "CKM_ECDSA_SHA3_512"

CKM_ECDH1_DERIVE = PyKCS11.LowLevel.CKM_ECDH1_DERIVE
CKM["CKM_ECDH1_DERIVE"] = CKM_ECDH1_DERIVE
CKM[CKM_ECDH1_DERIVE] = "CKM_ECDH1_DERIVE"

CKM_ECDH1_COFACTOR_DERIVE = PyKCS11.LowLevel.CKM_ECDH1_COFACTOR_DERIVE
CKM["CKM_ECDH1_COFACTOR_DERIVE"] = CKM_ECDH1_COFACTOR_DERIVE
CKM[CKM_ECDH1_COFACTOR_DERIVE] = "CKM_ECDH1_COFACTOR_DERIVE"

CKM_ECMQV_DERIVE = PyKCS11.LowLevel.CKM_ECMQV_DERIVE
CKM["CKM_ECMQV_DERIVE"] = CKM_ECMQV_DERIVE
CKM[CKM_ECMQV_DERIVE] = "CKM_ECMQV_DERIVE"

CKM_ECDH_AES_KEY_WRAP = PyKCS11.LowLevel.CKM_ECDH_AES_KEY_WRAP
CKM["CKM_ECDH_AES_KEY_WRAP"] = CKM_ECDH_AES_KEY_WRAP
CKM[CKM_ECDH_AES_KEY_WRAP] = "CKM_ECDH_AES_KEY_WRAP"

CKM_RSA_AES_KEY_WRAP = PyKCS11.LowLevel.CKM_RSA_AES_KEY_WRAP
CKM["CKM_RSA_AES_KEY_WRAP"] = CKM_RSA_AES_KEY_WRAP
CKM[CKM_RSA_AES_KEY_WRAP] = "CKM_RSA_AES_KEY_WRAP"

CKM_EC_EDWARDS_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_EC_EDWARDS_KEY_PAIR_GEN
CKM["CKM_EC_EDWARDS_KEY_PAIR_GEN"] = CKM_EC_EDWARDS_KEY_PAIR_GEN
CKM[CKM_EC_EDWARDS_KEY_PAIR_GEN] = "CKM_EC_EDWARDS_KEY_PAIR_GEN"

CKM_EC_MONTGOMERY_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_EC_MONTGOMERY_KEY_PAIR_GEN
CKM["CKM_EC_MONTGOMERY_KEY_PAIR_GEN"] = CKM_EC_MONTGOMERY_KEY_PAIR_GEN
CKM[CKM_EC_MONTGOMERY_KEY_PAIR_GEN] = "CKM_EC_MONTGOMERY_KEY_PAIR_GEN"

CKM_EDDSA = PyKCS11.LowLevel.CKM_EDDSA
CKM["CKM_EDDSA"] = CKM_EDDSA
CKM[CKM_EDDSA] = "CKM_EDDSA"

CKM_JUNIPER_KEY_GEN = PyKCS11.LowLevel.CKM_JUNIPER_KEY_GEN
CKM["CKM_JUNIPER_KEY_GEN"] = CKM_JUNIPER_KEY_GEN
CKM[CKM_JUNIPER_KEY_GEN] = "CKM_JUNIPER_KEY_GEN"

CKM_JUNIPER_ECB128 = PyKCS11.LowLevel.CKM_JUNIPER_ECB128
CKM["CKM_JUNIPER_ECB128"] = CKM_JUNIPER_ECB128
CKM[CKM_JUNIPER_ECB128] = "CKM_JUNIPER_ECB128"

CKM_JUNIPER_CBC128 = PyKCS11.LowLevel.CKM_JUNIPER_CBC128
CKM["CKM_JUNIPER_CBC128"] = CKM_JUNIPER_CBC128
CKM[CKM_JUNIPER_CBC128] = "CKM_JUNIPER_CBC128"

CKM_JUNIPER_COUNTER = PyKCS11.LowLevel.CKM_JUNIPER_COUNTER
CKM["CKM_JUNIPER_COUNTER"] = CKM_JUNIPER_COUNTER
CKM[CKM_JUNIPER_COUNTER] = "CKM_JUNIPER_COUNTER"

CKM_JUNIPER_SHUFFLE = PyKCS11.LowLevel.CKM_JUNIPER_SHUFFLE
CKM["CKM_JUNIPER_SHUFFLE"] = CKM_JUNIPER_SHUFFLE
CKM[CKM_JUNIPER_SHUFFLE] = "CKM_JUNIPER_SHUFFLE"

CKM_JUNIPER_WRAP = PyKCS11.LowLevel.CKM_JUNIPER_WRAP
CKM["CKM_JUNIPER_WRAP"] = CKM_JUNIPER_WRAP
CKM[CKM_JUNIPER_WRAP] = "CKM_JUNIPER_WRAP"

CKM_FASTHASH = PyKCS11.LowLevel.CKM_FASTHASH
CKM["CKM_FASTHASH"] = CKM_FASTHASH
CKM[CKM_FASTHASH] = "CKM_FASTHASH"

CKM_AES_XTS = PyKCS11.LowLevel.CKM_AES_XTS
CKM["CKM_AES_XTS"] = CKM_AES_XTS
CKM[CKM_AES_XTS] = "CKM_AES_XTS"

CKM_AES_XTS_KEY_GEN = PyKCS11.LowLevel.CKM_AES_XTS_KEY_GEN
CKM["CKM_AES_XTS_KEY_GEN"] = CKM_AES_XTS_KEY_GEN
CKM[CKM_AES_XTS_KEY_GEN] = "CKM_AES_XTS_KEY_GEN"

CKM_AES_KEY_GEN = PyKCS11.LowLevel.CKM_AES_KEY_GEN
CKM["CKM_AES_KEY_GEN"] = CKM_AES_KEY_GEN
CKM[CKM_AES_KEY_GEN] = "CKM_AES_KEY_GEN"

CKM_AES_ECB = PyKCS11.LowLevel.CKM_AES_ECB
CKM["CKM_AES_ECB"] = CKM_AES_ECB
CKM[CKM_AES_ECB] = "CKM_AES_ECB"

CKM_AES_CBC = PyKCS11.LowLevel.CKM_AES_CBC
CKM["CKM_AES_CBC"] = CKM_AES_CBC
CKM[CKM_AES_CBC] = "CKM_AES_CBC"

CKM_AES_MAC = PyKCS11.LowLevel.CKM_AES_MAC
CKM["CKM_AES_MAC"] = CKM_AES_MAC
CKM[CKM_AES_MAC] = "CKM_AES_MAC"

CKM_AES_MAC_GENERAL = PyKCS11.LowLevel.CKM_AES_MAC_GENERAL
CKM["CKM_AES_MAC_GENERAL"] = CKM_AES_MAC_GENERAL
CKM[CKM_AES_MAC_GENERAL] = "CKM_AES_MAC_GENERAL"

CKM_AES_CBC_PAD = PyKCS11.LowLevel.CKM_AES_CBC_PAD
CKM["CKM_AES_CBC_PAD"] = CKM_AES_CBC_PAD
CKM[CKM_AES_CBC_PAD] = "CKM_AES_CBC_PAD"

CKM_AES_CTR = PyKCS11.LowLevel.CKM_AES_CTR
CKM["CKM_AES_CTR"] = CKM_AES_CTR
CKM[CKM_AES_CTR] = "CKM_AES_CTR"

CKM_AES_GCM = PyKCS11.LowLevel.CKM_AES_GCM
CKM["CKM_AES_GCM"] = CKM_AES_GCM
CKM[CKM_AES_GCM] = "CKM_AES_GCM"

CKM_AES_CCM = PyKCS11.LowLevel.CKM_AES_CCM
CKM["CKM_AES_CCM"] = CKM_AES_CCM
CKM[CKM_AES_CCM] = "CKM_AES_CCM"

CKM_AES_CTS = PyKCS11.LowLevel.CKM_AES_CTS
CKM["CKM_AES_CTS"] = CKM_AES_CTS
CKM[CKM_AES_CTS] = "CKM_AES_CTS"

CKM_AES_CMAC = PyKCS11.LowLevel.CKM_AES_CMAC
CKM["CKM_AES_CMAC"] = CKM_AES_CMAC
CKM[CKM_AES_CMAC] = "CKM_AES_CMAC"

CKM_AES_CMAC_GENERAL = PyKCS11.LowLevel.CKM_AES_CMAC_GENERAL
CKM["CKM_AES_CMAC_GENERAL"] = CKM_AES_CMAC_GENERAL
CKM[CKM_AES_CMAC_GENERAL] = "CKM_AES_CMAC_GENERAL"

CKM_AES_XCBC_MAC = PyKCS11.LowLevel.CKM_AES_XCBC_MAC
CKM["CKM_AES_XCBC_MAC"] = CKM_AES_XCBC_MAC
CKM[CKM_AES_XCBC_MAC] = "CKM_AES_XCBC_MAC"

CKM_AES_XCBC_MAC_96 = PyKCS11.LowLevel.CKM_AES_XCBC_MAC_96
CKM["CKM_AES_XCBC_MAC_96"] = CKM_AES_XCBC_MAC_96
CKM[CKM_AES_XCBC_MAC_96] = "CKM_AES_XCBC_MAC_96"

CKM_AES_GMAC = PyKCS11.LowLevel.CKM_AES_GMAC
CKM["CKM_AES_GMAC"] = CKM_AES_GMAC
CKM[CKM_AES_GMAC] = "CKM_AES_GMAC"

CKM_BLOWFISH_KEY_GEN = PyKCS11.LowLevel.CKM_BLOWFISH_KEY_GEN
CKM["CKM_BLOWFISH_KEY_GEN"] = CKM_BLOWFISH_KEY_GEN
CKM[CKM_BLOWFISH_KEY_GEN] = "CKM_BLOWFISH_KEY_GEN"

CKM_BLOWFISH_CBC = PyKCS11.LowLevel.CKM_BLOWFISH_CBC
CKM["CKM_BLOWFISH_CBC"] = CKM_BLOWFISH_CBC
CKM[CKM_BLOWFISH_CBC] = "CKM_BLOWFISH_CBC"

CKM_TWOFISH_KEY_GEN = PyKCS11.LowLevel.CKM_TWOFISH_KEY_GEN
CKM["CKM_TWOFISH_KEY_GEN"] = CKM_TWOFISH_KEY_GEN
CKM[CKM_TWOFISH_KEY_GEN] = "CKM_TWOFISH_KEY_GEN"

CKM_TWOFISH_CBC = PyKCS11.LowLevel.CKM_TWOFISH_CBC
CKM["CKM_TWOFISH_CBC"] = CKM_TWOFISH_CBC
CKM[CKM_TWOFISH_CBC] = "CKM_TWOFISH_CBC"

CKM_BLOWFISH_CBC_PAD = PyKCS11.LowLevel.CKM_BLOWFISH_CBC_PAD
CKM["CKM_BLOWFISH_CBC_PAD"] = CKM_BLOWFISH_CBC_PAD
CKM[CKM_BLOWFISH_CBC_PAD] = "CKM_BLOWFISH_CBC_PAD"

CKM_TWOFISH_CBC_PAD = PyKCS11.LowLevel.CKM_TWOFISH_CBC_PAD
CKM["CKM_TWOFISH_CBC_PAD"] = CKM_TWOFISH_CBC_PAD
CKM[CKM_TWOFISH_CBC_PAD] = "CKM_TWOFISH_CBC_PAD"

CKM_DES_ECB_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_DES_ECB_ENCRYPT_DATA
CKM["CKM_DES_ECB_ENCRYPT_DATA"] = CKM_DES_ECB_ENCRYPT_DATA
CKM[CKM_DES_ECB_ENCRYPT_DATA] = "CKM_DES_ECB_ENCRYPT_DATA"

CKM_DES_CBC_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_DES_CBC_ENCRYPT_DATA
CKM["CKM_DES_CBC_ENCRYPT_DATA"] = CKM_DES_CBC_ENCRYPT_DATA
CKM[CKM_DES_CBC_ENCRYPT_DATA] = "CKM_DES_CBC_ENCRYPT_DATA"

CKM_DES3_ECB_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_DES3_ECB_ENCRYPT_DATA
CKM["CKM_DES3_ECB_ENCRYPT_DATA"] = CKM_DES3_ECB_ENCRYPT_DATA
CKM[CKM_DES3_ECB_ENCRYPT_DATA] = "CKM_DES3_ECB_ENCRYPT_DATA"

CKM_DES3_CBC_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_DES3_CBC_ENCRYPT_DATA
CKM["CKM_DES3_CBC_ENCRYPT_DATA"] = CKM_DES3_CBC_ENCRYPT_DATA
CKM[CKM_DES3_CBC_ENCRYPT_DATA] = "CKM_DES3_CBC_ENCRYPT_DATA"

CKM_AES_ECB_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_AES_ECB_ENCRYPT_DATA
CKM["CKM_AES_ECB_ENCRYPT_DATA"] = CKM_AES_ECB_ENCRYPT_DATA
CKM[CKM_AES_ECB_ENCRYPT_DATA] = "CKM_AES_ECB_ENCRYPT_DATA"

CKM_AES_CBC_ENCRYPT_DATA = PyKCS11.LowLevel.CKM_AES_CBC_ENCRYPT_DATA
CKM["CKM_AES_CBC_ENCRYPT_DATA"] = CKM_AES_CBC_ENCRYPT_DATA
CKM[CKM_AES_CBC_ENCRYPT_DATA] = "CKM_AES_CBC_ENCRYPT_DATA"

CKM_GOSTR3410_KEY_PAIR_GEN = PyKCS11.LowLevel.CKM_GOSTR3410_KEY_PAIR_GEN
CKM["CKM_GOSTR3410_KEY_PAIR_GEN"] = CKM_GOSTR3410_KEY_PAIR_GEN
CKM[CKM_GOSTR3410_KEY_PAIR_GEN] = "CKM_GOSTR3410_KEY_PAIR_GEN"

CKM_GOSTR3410 = PyKCS11.LowLevel.CKM_GOSTR3410
CKM["CKM_GOSTR3410"] = CKM_GOSTR3410
CKM[CKM_GOSTR3410] = "CKM_GOSTR3410"

CKM_GOSTR3410_WITH_GOSTR3411 = PyKCS11.LowLevel.CKM_GOSTR3410_WITH_GOSTR3411
CKM["CKM_GOSTR3410_WITH_GOSTR3411"] = CKM_GOSTR3410_WITH_GOSTR3411
CKM[CKM_GOSTR3410_WITH_GOSTR3411] = "CKM_GOSTR3410_WITH_GOSTR3411"

CKM_GOSTR3410_KEY_WRAP = PyKCS11.LowLevel.CKM_GOSTR3410_KEY_WRAP
CKM["CKM_GOSTR3410_KEY_WRAP"] = CKM_GOSTR3410_KEY_WRAP
CKM[CKM_GOSTR3410_KEY_WRAP] = "CKM_GOSTR3410_KEY_WRAP"

CKM_GOSTR3410_DERIVE = PyKCS11.LowLevel.CKM_GOSTR3410_DERIVE
CKM["CKM_GOSTR3410_DERIVE"] = CKM_GOSTR3410_DERIVE
CKM[CKM_GOSTR3410_DERIVE] = "CKM_GOSTR3410_DERIVE"

CKM_GOSTR3411 = PyKCS11.LowLevel.CKM_GOSTR3411
CKM["CKM_GOSTR3411"] = CKM_GOSTR3411
CKM[CKM_GOSTR3411] = "CKM_GOSTR3411"

CKM_GOSTR3411_HMAC = PyKCS11.LowLevel.CKM_GOSTR3411_HMAC
CKM["CKM_GOSTR3411_HMAC"] = CKM_GOSTR3411_HMAC
CKM[CKM_GOSTR3411_HMAC] = "CKM_GOSTR3411_HMAC"

CKM_GOST28147_KEY_GEN = PyKCS11.LowLevel.CKM_GOST28147_KEY_GEN
CKM["CKM_GOST28147_KEY_GEN"] = CKM_GOST28147_KEY_GEN
CKM[CKM_GOST28147_KEY_GEN] = "CKM_GOST28147_KEY_GEN"

CKM_GOST28147_ECB = PyKCS11.LowLevel.CKM_GOST28147_ECB
CKM["CKM_GOST28147_ECB"] = CKM_GOST28147_ECB
CKM[CKM_GOST28147_ECB] = "CKM_GOST28147_ECB"

CKM_GOST28147 = PyKCS11.LowLevel.CKM_GOST28147
CKM["CKM_GOST28147"] = CKM_GOST28147
CKM[CKM_GOST28147] = "CKM_GOST28147"

CKM_GOST28147_MAC = PyKCS11.LowLevel.CKM_GOST28147_MAC
CKM["CKM_GOST28147_MAC"] = CKM_GOST28147_MAC
CKM[CKM_GOST28147_MAC] = "CKM_GOST28147_MAC"

CKM_GOST28147_KEY_WRAP = PyKCS11.LowLevel.CKM_GOST28147_KEY_WRAP
CKM["CKM_GOST28147_KEY_WRAP"] = CKM_GOST28147_KEY_WRAP
CKM[CKM_GOST28147_KEY_WRAP] = "CKM_GOST28147_KEY_WRAP"

CKM_CHACHA20_KEY_GEN = PyKCS11.LowLevel.CKM_CHACHA20_KEY_GEN
CKM["CKM_CHACHA20_KEY_GEN"] = CKM_CHACHA20_KEY_GEN
CKM[CKM_CHACHA20_KEY_GEN] = "CKM_CHACHA20_KEY_GEN"

CKM_CHACHA20 = PyKCS11.LowLevel.CKM_CHACHA20
CKM["CKM_CHACHA20"] = CKM_CHACHA20
CKM[CKM_CHACHA20] = "CKM_CHACHA20"

CKM_POLY1305_KEY_GEN = PyKCS11.LowLevel.CKM_POLY1305_KEY_GEN
CKM["CKM_POLY1305_KEY_GEN"] = CKM_POLY1305_KEY_GEN
CKM[CKM_POLY1305_KEY_GEN] = "CKM_POLY1305_KEY_GEN"

CKM_POLY1305 = PyKCS11.LowLevel.CKM_POLY1305
CKM["CKM_POLY1305"] = CKM_POLY1305
CKM[CKM_POLY1305] = "CKM_POLY1305"

CKM_DSA_PARAMETER_GEN = PyKCS11.LowLevel.CKM_DSA_PARAMETER_GEN
CKM["CKM_DSA_PARAMETER_GEN"] = CKM_DSA_PARAMETER_GEN
CKM[CKM_DSA_PARAMETER_GEN] = "CKM_DSA_PARAMETER_GEN"

CKM_DH_PKCS_PARAMETER_GEN = PyKCS11.LowLevel.CKM_DH_PKCS_PARAMETER_GEN
CKM["CKM_DH_PKCS_PARAMETER_GEN"] = CKM_DH_PKCS_PARAMETER_GEN
CKM[CKM_DH_PKCS_PARAMETER_GEN] = "CKM_DH_PKCS_PARAMETER_GEN"

CKM_X9_42_DH_PARAMETER_GEN = PyKCS11.LowLevel.CKM_X9_42_DH_PARAMETER_GEN
CKM["CKM_X9_42_DH_PARAMETER_GEN"] = CKM_X9_42_DH_PARAMETER_GEN
CKM[CKM_X9_42_DH_PARAMETER_GEN] = "CKM_X9_42_DH_PARAMETER_GEN"

CKM_DSA_PROBABLISTIC_PARAMETER_GEN = PyKCS11.LowLevel.CKM_DSA_PROBABLISTIC_PARAMETER_GEN
CKM["CKM_DSA_PROBABLISTIC_PARAMETER_GEN"] = CKM_DSA_PROBABLISTIC_PARAMETER_GEN
CKM[CKM_DSA_PROBABLISTIC_PARAMETER_GEN] = "CKM_DSA_PROBABLISTIC_PARAMETER_GEN"

CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN = PyKCS11.LowLevel.CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN
CKM["CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN"] = CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN
CKM[CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN] = "CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN"

CKM_AES_OFB = PyKCS11.LowLevel.CKM_AES_OFB
CKM["CKM_AES_OFB"] = CKM_AES_OFB
CKM[CKM_AES_OFB] = "CKM_AES_OFB"

CKM_AES_CFB64 = PyKCS11.LowLevel.CKM_AES_CFB64
CKM["CKM_AES_CFB64"] = CKM_AES_CFB64
CKM[CKM_AES_CFB64] = "CKM_AES_CFB64"

CKM_AES_CFB8 = PyKCS11.LowLevel.CKM_AES_CFB8
CKM["CKM_AES_CFB8"] = CKM_AES_CFB8
CKM[CKM_AES_CFB8] = "CKM_AES_CFB8"

CKM_AES_CFB128 = PyKCS11.LowLevel.CKM_AES_CFB128
CKM["CKM_AES_CFB128"] = CKM_AES_CFB128
CKM[CKM_AES_CFB128] = "CKM_AES_CFB128"

CKM_AES_CFB1 = PyKCS11.LowLevel.CKM_AES_CFB1
CKM["CKM_AES_CFB1"] = CKM_AES_CFB1
CKM[CKM_AES_CFB1] = "CKM_AES_CFB1"

CKM_AES_KEY_WRAP = PyKCS11.LowLevel.CKM_AES_KEY_WRAP
CKM["CKM_AES_KEY_WRAP"] = CKM_AES_KEY_WRAP
CKM[CKM_AES_KEY_WRAP] = "CKM_AES_KEY_WRAP"

CKM_AES_KEY_WRAP_PAD = PyKCS11.LowLevel.CKM_AES_KEY_WRAP_PAD
CKM["CKM_AES_KEY_WRAP_PAD"] = CKM_AES_KEY_WRAP_PAD
CKM[CKM_AES_KEY_WRAP_PAD] = "CKM_AES_KEY_WRAP_PAD"

CKM_AES_KEY_WRAP_KWP = PyKCS11.LowLevel.CKM_AES_KEY_WRAP_KWP
CKM["CKM_AES_KEY_WRAP_KWP"] = CKM_AES_KEY_WRAP_KWP
CKM[CKM_AES_KEY_WRAP_KWP] = "CKM_AES_KEY_WRAP_KWP"

CKM_RSA_PKCS_TPM_1_1 = PyKCS11.LowLevel.CKM_RSA_PKCS_TPM_1_1
CKM["CKM_RSA_PKCS_TPM_1_1"] = CKM_RSA_PKCS_TPM_1_1
CKM[CKM_RSA_PKCS_TPM_1_1] = "CKM_RSA_PKCS_TPM_1_1"

CKM_RSA_PKCS_OAEP_TPM_1_1 = PyKCS11.LowLevel.CKM_RSA_PKCS_OAEP_TPM_1_1
CKM["CKM_RSA_PKCS_OAEP_TPM_1_1"] = CKM_RSA_PKCS_OAEP_TPM_1_1
CKM[CKM_RSA_PKCS_OAEP_TPM_1_1] = "CKM_RSA_PKCS_OAEP_TPM_1_1"

CKM_SHA_1_KEY_GEN = PyKCS11.LowLevel.CKM_SHA_1_KEY_GEN
CKM["CKM_SHA_1_KEY_GEN"] = CKM_SHA_1_KEY_GEN
CKM[CKM_SHA_1_KEY_GEN] = "CKM_SHA_1_KEY_GEN"

CKM_SHA224_KEY_GEN = PyKCS11.LowLevel.CKM_SHA224_KEY_GEN
CKM["CKM_SHA224_KEY_GEN"] = CKM_SHA224_KEY_GEN
CKM[CKM_SHA224_KEY_GEN] = "CKM_SHA224_KEY_GEN"

CKM_SHA256_KEY_GEN = PyKCS11.LowLevel.CKM_SHA256_KEY_GEN
CKM["CKM_SHA256_KEY_GEN"] = CKM_SHA256_KEY_GEN
CKM[CKM_SHA256_KEY_GEN] = "CKM_SHA256_KEY_GEN"

CKM_SHA384_KEY_GEN = PyKCS11.LowLevel.CKM_SHA384_KEY_GEN
CKM["CKM_SHA384_KEY_GEN"] = CKM_SHA384_KEY_GEN
CKM[CKM_SHA384_KEY_GEN] = "CKM_SHA384_KEY_GEN"

CKM_SHA512_KEY_GEN = PyKCS11.LowLevel.CKM_SHA512_KEY_GEN
CKM["CKM_SHA512_KEY_GEN"] = CKM_SHA512_KEY_GEN
CKM[CKM_SHA512_KEY_GEN] = "CKM_SHA512_KEY_GEN"

CKM_SHA512_224_KEY_GEN = PyKCS11.LowLevel.CKM_SHA512_224_KEY_GEN
CKM["CKM_SHA512_224_KEY_GEN"] = CKM_SHA512_224_KEY_GEN
CKM[CKM_SHA512_224_KEY_GEN] = "CKM_SHA512_224_KEY_GEN"

CKM_SHA512_256_KEY_GEN = PyKCS11.LowLevel.CKM_SHA512_256_KEY_GEN
CKM["CKM_SHA512_256_KEY_GEN"] = CKM_SHA512_256_KEY_GEN
CKM[CKM_SHA512_256_KEY_GEN] = "CKM_SHA512_256_KEY_GEN"

CKM_SHA512_T_KEY_GEN = PyKCS11.LowLevel.CKM_SHA512_T_KEY_GEN
CKM["CKM_SHA512_T_KEY_GEN"] = CKM_SHA512_T_KEY_GEN
CKM[CKM_SHA512_T_KEY_GEN] = "CKM_SHA512_T_KEY_GEN"

CKM_NULL = PyKCS11.LowLevel.CKM_NULL
CKM["CKM_NULL"] = CKM_NULL
CKM[CKM_NULL] = "CKM_NULL"

CKM_BLAKE2B_160 = PyKCS11.LowLevel.CKM_BLAKE2B_160
CKM["CKM_BLAKE2B_160"] = CKM_BLAKE2B_160
CKM[CKM_BLAKE2B_160] = "CKM_BLAKE2B_160"

CKM_BLAKE2B_160_HMAC = PyKCS11.LowLevel.CKM_BLAKE2B_160_HMAC
CKM["CKM_BLAKE2B_160_HMAC"] = CKM_BLAKE2B_160_HMAC
CKM[CKM_BLAKE2B_160_HMAC] = "CKM_BLAKE2B_160_HMAC"

CKM_BLAKE2B_160_HMAC_GENERAL = PyKCS11.LowLevel.CKM_BLAKE2B_160_HMAC_GENERAL
CKM["CKM_BLAKE2B_160_HMAC_GENERAL"] = CKM_BLAKE2B_160_HMAC_GENERAL
CKM[CKM_BLAKE2B_160_HMAC_GENERAL] = "CKM_BLAKE2B_160_HMAC_GENERAL"

CKM_BLAKE2B_160_KEY_DERIVE = PyKCS11.LowLevel.CKM_BLAKE2B_160_KEY_DERIVE
CKM["CKM_BLAKE2B_160_KEY_DERIVE"] = CKM_BLAKE2B_160_KEY_DERIVE
CKM[CKM_BLAKE2B_160_KEY_DERIVE] = "CKM_BLAKE2B_160_KEY_DERIVE"

CKM_BLAKE2B_160_KEY_GEN = PyKCS11.LowLevel.CKM_BLAKE2B_160_KEY_GEN
CKM["CKM_BLAKE2B_160_KEY_GEN"] = CKM_BLAKE2B_160_KEY_GEN
CKM[CKM_BLAKE2B_160_KEY_GEN] = "CKM_BLAKE2B_160_KEY_GEN"

CKM_BLAKE2B_256 = PyKCS11.LowLevel.CKM_BLAKE2B_256
CKM["CKM_BLAKE2B_256"] = CKM_BLAKE2B_256
CKM[CKM_BLAKE2B_256] = "CKM_BLAKE2B_256"

CKM_BLAKE2B_256_HMAC = PyKCS11.LowLevel.CKM_BLAKE2B_256_HMAC
CKM["CKM_BLAKE2B_256_HMAC"] = CKM_BLAKE2B_256_HMAC
CKM[CKM_BLAKE2B_256_HMAC] = "CKM_BLAKE2B_256_HMAC"

CKM_BLAKE2B_256_HMAC_GENERAL = PyKCS11.LowLevel.CKM_BLAKE2B_256_HMAC_GENERAL
CKM["CKM_BLAKE2B_256_HMAC_GENERAL"] = CKM_BLAKE2B_256_HMAC_GENERAL
CKM[CKM_BLAKE2B_256_HMAC_GENERAL] = "CKM_BLAKE2B_256_HMAC_GENERAL"

CKM_BLAKE2B_256_KEY_DERIVE = PyKCS11.LowLevel.CKM_BLAKE2B_256_KEY_DERIVE
CKM["CKM_BLAKE2B_256_KEY_DERIVE"] = CKM_BLAKE2B_256_KEY_DERIVE
CKM[CKM_BLAKE2B_256_KEY_DERIVE] = "CKM_BLAKE2B_256_KEY_DERIVE"

CKM_BLAKE2B_256_KEY_GEN = PyKCS11.LowLevel.CKM_BLAKE2B_256_KEY_GEN
CKM["CKM_BLAKE2B_256_KEY_GEN"] = CKM_BLAKE2B_256_KEY_GEN
CKM[CKM_BLAKE2B_256_KEY_GEN] = "CKM_BLAKE2B_256_KEY_GEN"

CKM_BLAKE2B_384 = PyKCS11.LowLevel.CKM_BLAKE2B_384
CKM["CKM_BLAKE2B_384"] = CKM_BLAKE2B_384
CKM[CKM_BLAKE2B_384] = "CKM_BLAKE2B_384"

CKM_BLAKE2B_384_HMAC = PyKCS11.LowLevel.CKM_BLAKE2B_384_HMAC
CKM["CKM_BLAKE2B_384_HMAC"] = CKM_BLAKE2B_384_HMAC
CKM[CKM_BLAKE2B_384_HMAC] = "CKM_BLAKE2B_384_HMAC"

CKM_BLAKE2B_384_HMAC_GENERAL = PyKCS11.LowLevel.CKM_BLAKE2B_384_HMAC_GENERAL
CKM["CKM_BLAKE2B_384_HMAC_GENERAL"] = CKM_BLAKE2B_384_HMAC_GENERAL
CKM[CKM_BLAKE2B_384_HMAC_GENERAL] = "CKM_BLAKE2B_384_HMAC_GENERAL"

CKM_BLAKE2B_384_KEY_DERIVE = PyKCS11.LowLevel.CKM_BLAKE2B_384_KEY_DERIVE
CKM["CKM_BLAKE2B_384_KEY_DERIVE"] = CKM_BLAKE2B_384_KEY_DERIVE
CKM[CKM_BLAKE2B_384_KEY_DERIVE] = "CKM_BLAKE2B_384_KEY_DERIVE"

CKM_BLAKE2B_384_KEY_GEN = PyKCS11.LowLevel.CKM_BLAKE2B_384_KEY_GEN
CKM["CKM_BLAKE2B_384_KEY_GEN"] = CKM_BLAKE2B_384_KEY_GEN
CKM[CKM_BLAKE2B_384_KEY_GEN] = "CKM_BLAKE2B_384_KEY_GEN"

CKM_BLAKE2B_512 = PyKCS11.LowLevel.CKM_BLAKE2B_512
CKM["CKM_BLAKE2B_512"] = CKM_BLAKE2B_512
CKM[CKM_BLAKE2B_512] = "CKM_BLAKE2B_512"

CKM_BLAKE2B_512_HMAC = PyKCS11.LowLevel.CKM_BLAKE2B_512_HMAC
CKM["CKM_BLAKE2B_512_HMAC"] = CKM_BLAKE2B_512_HMAC
CKM[CKM_BLAKE2B_512_HMAC] = "CKM_BLAKE2B_512_HMAC"

CKM_BLAKE2B_512_HMAC_GENERAL = PyKCS11.LowLevel.CKM_BLAKE2B_512_HMAC_GENERAL
CKM["CKM_BLAKE2B_512_HMAC_GENERAL"] = CKM_BLAKE2B_512_HMAC_GENERAL
CKM[CKM_BLAKE2B_512_HMAC_GENERAL] = "CKM_BLAKE2B_512_HMAC_GENERAL"

CKM_BLAKE2B_512_KEY_DERIVE = PyKCS11.LowLevel.CKM_BLAKE2B_512_KEY_DERIVE
CKM["CKM_BLAKE2B_512_KEY_DERIVE"] = CKM_BLAKE2B_512_KEY_DERIVE
CKM[CKM_BLAKE2B_512_KEY_DERIVE] = "CKM_BLAKE2B_512_KEY_DERIVE"

CKM_BLAKE2B_512_KEY_GEN = PyKCS11.LowLevel.CKM_BLAKE2B_512_KEY_GEN
CKM["CKM_BLAKE2B_512_KEY_GEN"] = CKM_BLAKE2B_512_KEY_GEN
CKM[CKM_BLAKE2B_512_KEY_GEN] = "CKM_BLAKE2B_512_KEY_GEN"

CKM_SALSA20 = PyKCS11.LowLevel.CKM_SALSA20
CKM["CKM_SALSA20"] = CKM_SALSA20
CKM[CKM_SALSA20] = "CKM_SALSA20"

CKM_CHACHA20_POLY1305 = PyKCS11.LowLevel.CKM_CHACHA20_POLY1305
CKM["CKM_CHACHA20_POLY1305"] = CKM_CHACHA20_POLY1305
CKM[CKM_CHACHA20_POLY1305] = "CKM_CHACHA20_POLY1305"

CKM_SALSA20_POLY1305 = PyKCS11.LowLevel.CKM_SALSA20_POLY1305
CKM["CKM_SALSA20_POLY1305"] = CKM_SALSA20_POLY1305
CKM[CKM_SALSA20_POLY1305] = "CKM_SALSA20_POLY1305"

CKM_X3DH_INITIALIZE = PyKCS11.LowLevel.CKM_X3DH_INITIALIZE
CKM["CKM_X3DH_INITIALIZE"] = CKM_X3DH_INITIALIZE
CKM[CKM_X3DH_INITIALIZE] = "CKM_X3DH_INITIALIZE"

CKM_X3DH_RESPOND = PyKCS11.LowLevel.CKM_X3DH_RESPOND
CKM["CKM_X3DH_RESPOND"] = CKM_X3DH_RESPOND
CKM[CKM_X3DH_RESPOND] = "CKM_X3DH_RESPOND"

CKM_X2RATCHET_INITIALIZE = PyKCS11.LowLevel.CKM_X2RATCHET_INITIALIZE
CKM["CKM_X2RATCHET_INITIALIZE"] = CKM_X2RATCHET_INITIALIZE
CKM[CKM_X2RATCHET_INITIALIZE] = "CKM_X2RATCHET_INITIALIZE"

CKM_X2RATCHET_RESPOND = PyKCS11.LowLevel.CKM_X2RATCHET_RESPOND
CKM["CKM_X2RATCHET_RESPOND"] = CKM_X2RATCHET_RESPOND
CKM[CKM_X2RATCHET_RESPOND] = "CKM_X2RATCHET_RESPOND"

CKM_X2RATCHET_ENCRYPT = PyKCS11.LowLevel.CKM_X2RATCHET_ENCRYPT
CKM["CKM_X2RATCHET_ENCRYPT"] = CKM_X2RATCHET_ENCRYPT
CKM[CKM_X2RATCHET_ENCRYPT] = "CKM_X2RATCHET_ENCRYPT"

CKM_X2RATCHET_DECRYPT = PyKCS11.LowLevel.CKM_X2RATCHET_DECRYPT
CKM["CKM_X2RATCHET_DECRYPT"] = CKM_X2RATCHET_DECRYPT
CKM[CKM_X2RATCHET_DECRYPT] = "CKM_X2RATCHET_DECRYPT"

CKM_XEDDSA = PyKCS11.LowLevel.CKM_XEDDSA
CKM["CKM_XEDDSA"] = CKM_XEDDSA
CKM[CKM_XEDDSA] = "CKM_XEDDSA"

CKM_HKDF_DERIVE = PyKCS11.LowLevel.CKM_HKDF_DERIVE
CKM["CKM_HKDF_DERIVE"] = CKM_HKDF_DERIVE
CKM[CKM_HKDF_DERIVE] = "CKM_HKDF_DERIVE"

CKM_HKDF_DATA = PyKCS11.LowLevel.CKM_HKDF_DATA
CKM["CKM_HKDF_DATA"] = CKM_HKDF_DATA
CKM[CKM_HKDF_DATA] = "CKM_HKDF_DATA"

CKM_HKDF_KEY_GEN = PyKCS11.LowLevel.CKM_HKDF_KEY_GEN
CKM["CKM_HKDF_KEY_GEN"] = CKM_HKDF_KEY_GEN
CKM[CKM_HKDF_KEY_GEN] = "CKM_HKDF_KEY_GEN"

CKM_VENDOR_DEFINED = PyKCS11.LowLevel.CKM_VENDOR_DEFINED

# CKG constants
CKG = {}
CKG_MGF1_SHA1 = PyKCS11.LowLevel.CKG_MGF1_SHA1
CKG["CKG_MGF1_SHA1"] = CKG_MGF1_SHA1
CKG[CKG_MGF1_SHA1] = "CKG_MGF1_SHA1"

CKG_MGF1_SHA256 = PyKCS11.LowLevel.CKG_MGF1_SHA256
CKG["CKG_MGF1_SHA256"] = CKG_MGF1_SHA256
CKG[CKG_MGF1_SHA256] = "CKG_MGF1_SHA256"

CKG_MGF1_SHA384 = PyKCS11.LowLevel.CKG_MGF1_SHA384
CKG["CKG_MGF1_SHA384"] = CKG_MGF1_SHA384
CKG[CKG_MGF1_SHA384] = "CKG_MGF1_SHA384"

CKG_MGF1_SHA512 = PyKCS11.LowLevel.CKG_MGF1_SHA512
CKG["CKG_MGF1_SHA512"] = CKG_MGF1_SHA512
CKG[CKG_MGF1_SHA512] = "CKG_MGF1_SHA512"


# CKF constants
CKF = {}
CKF_HW = PyKCS11.LowLevel.CKF_HW
CKF["CKF_HW"] = CKF_HW
CKF[CKF_HW] = "CKF_HW"

CKF_MESSAGE_ENCRYPT = PyKCS11.LowLevel.CKF_MESSAGE_ENCRYPT
CKF["CKF_MESSAGE_ENCRYPT"] = CKF_MESSAGE_ENCRYPT
CKF[CKF_MESSAGE_ENCRYPT] = "CKF_MESSAGE_ENCRYPT"

CKF_MESSAGE_DECRYPT = PyKCS11.LowLevel.CKF_MESSAGE_DECRYPT
CKF["CKF_MESSAGE_DECRYPT"] = CKF_MESSAGE_DECRYPT
CKF[CKF_MESSAGE_DECRYPT] = "CKF_MESSAGE_DECRYPT"

CKF_MESSAGE_SIGN = PyKCS11.LowLevel.CKF_MESSAGE_SIGN
CKF["CKF_MESSAGE_SIGN"] = CKF_MESSAGE_SIGN
CKF[CKF_MESSAGE_SIGN] = "CKF_MESSAGE_SIGN"

CKF_MESSAGE_VERIFY = PyKCS11.LowLevel.CKF_MESSAGE_VERIFY
CKF["CKF_MESSAGE_VERIFY"] = CKF_MESSAGE_VERIFY
CKF[CKF_MESSAGE_VERIFY] = "CKF_MESSAGE_VERIFY"

CKF_MULTI_MESSGE = PyKCS11.LowLevel.CKF_MULTI_MESSGE
CKF["CKF_MULTI_MESSGE"] = CKF_MULTI_MESSGE
CKF[CKF_MULTI_MESSGE] = "CKF_MULTI_MESSGE"

CKF_FIND_OBJECTS = PyKCS11.LowLevel.CKF_FIND_OBJECTS
CKF["CKF_FIND_OBJECTS"] = CKF_FIND_OBJECTS
CKF[CKF_FIND_OBJECTS] = "CKF_FIND_OBJECTS"

CKF_ENCRYPT = PyKCS11.LowLevel.CKF_ENCRYPT
CKF["CKF_ENCRYPT"] = CKF_ENCRYPT
CKF[CKF_ENCRYPT] = "CKF_ENCRYPT"

CKF_DECRYPT = PyKCS11.LowLevel.CKF_DECRYPT
CKF["CKF_DECRYPT"] = CKF_DECRYPT
CKF[CKF_DECRYPT] = "CKF_DECRYPT"

CKF_DIGEST = PyKCS11.LowLevel.CKF_DIGEST
CKF["CKF_DIGEST"] = CKF_DIGEST
CKF[CKF_DIGEST] = "CKF_DIGEST"

CKF_SIGN = PyKCS11.LowLevel.CKF_SIGN
CKF["CKF_SIGN"] = CKF_SIGN
CKF[CKF_SIGN] = "CKF_SIGN"

CKF_SIGN_RECOVER = PyKCS11.LowLevel.CKF_SIGN_RECOVER
CKF["CKF_SIGN_RECOVER"] = CKF_SIGN_RECOVER
CKF[CKF_SIGN_RECOVER] = "CKF_SIGN_RECOVER"

CKF_VERIFY = PyKCS11.LowLevel.CKF_VERIFY
CKF["CKF_VERIFY"] = CKF_VERIFY
CKF[CKF_VERIFY] = "CKF_VERIFY"

CKF_VERIFY_RECOVER = PyKCS11.LowLevel.CKF_VERIFY_RECOVER
CKF["CKF_VERIFY_RECOVER"] = CKF_VERIFY_RECOVER
CKF[CKF_VERIFY_RECOVER] = "CKF_VERIFY_RECOVER"

CKF_GENERATE = PyKCS11.LowLevel.CKF_GENERATE
CKF["CKF_GENERATE"] = CKF_GENERATE
CKF[CKF_GENERATE] = "CKF_GENERATE"

CKF_GENERATE_KEY_PAIR = PyKCS11.LowLevel.CKF_GENERATE_KEY_PAIR
CKF["CKF_GENERATE_KEY_PAIR"] = CKF_GENERATE_KEY_PAIR
CKF[CKF_GENERATE_KEY_PAIR] = "CKF_GENERATE_KEY_PAIR"

CKF_WRAP = PyKCS11.LowLevel.CKF_WRAP
CKF["CKF_WRAP"] = CKF_WRAP
CKF[CKF_WRAP] = "CKF_WRAP"

CKF_UNWRAP = PyKCS11.LowLevel.CKF_UNWRAP
CKF["CKF_UNWRAP"] = CKF_UNWRAP
CKF[CKF_UNWRAP] = "CKF_UNWRAP"

CKF_DERIVE = PyKCS11.LowLevel.CKF_DERIVE
CKF["CKF_DERIVE"] = CKF_DERIVE
CKF[CKF_DERIVE] = "CKF_DERIVE"

CKF_EC_F_P = PyKCS11.LowLevel.CKF_EC_F_P
CKF["CKF_EC_F_P"] = CKF_EC_F_P
CKF[CKF_EC_F_P] = "CKF_EC_F_P"

CKF_EC_F_2M = PyKCS11.LowLevel.CKF_EC_F_2M
CKF["CKF_EC_F_2M"] = CKF_EC_F_2M
CKF[CKF_EC_F_2M] = "CKF_EC_F_2M"

CKF_EC_ECPARAMETERS = PyKCS11.LowLevel.CKF_EC_ECPARAMETERS
CKF["CKF_EC_ECPARAMETERS"] = CKF_EC_ECPARAMETERS
CKF[CKF_EC_ECPARAMETERS] = "CKF_EC_ECPARAMETERS"

CKF_EC_NAMEDCURVE = PyKCS11.LowLevel.CKF_EC_NAMEDCURVE
CKF["CKF_EC_NAMEDCURVE"] = CKF_EC_NAMEDCURVE
CKF[CKF_EC_NAMEDCURVE] = "CKF_EC_NAMEDCURVE"

CKF_EC_UNCOMPRESS = PyKCS11.LowLevel.CKF_EC_UNCOMPRESS
CKF["CKF_EC_UNCOMPRESS"] = CKF_EC_UNCOMPRESS
CKF[CKF_EC_UNCOMPRESS] = "CKF_EC_UNCOMPRESS"

CKF_EC_COMPRESS = PyKCS11.LowLevel.CKF_EC_COMPRESS
CKF["CKF_EC_COMPRESS"] = CKF_EC_COMPRESS
CKF[CKF_EC_COMPRESS] = "CKF_EC_COMPRESS"

CKF_EC_CURVENAME = PyKCS11.LowLevel.CKF_EC_CURVENAME
CKF["CKF_EC_CURVENAME"] = CKF_EC_CURVENAME
CKF[CKF_EC_CURVENAME] = "CKF_EC_CURVENAME"

CKF_EXTENSION = PyKCS11.LowLevel.CKF_EXTENSION
CKF["CKF_EXTENSION"] = CKF_EXTENSION
CKF[CKF_EXTENSION] = "CKF_EXTENSION"


# CKR constants
CKR = {}
CKR_OK = PyKCS11.LowLevel.CKR_OK
CKR["CKR_OK"] = CKR_OK
CKR[CKR_OK] = "CKR_OK"

CKR_CANCEL = PyKCS11.LowLevel.CKR_CANCEL
CKR["CKR_CANCEL"] = CKR_CANCEL
CKR[CKR_CANCEL] = "CKR_CANCEL"

CKR_HOST_MEMORY = PyKCS11.LowLevel.CKR_HOST_MEMORY
CKR["CKR_HOST_MEMORY"] = CKR_HOST_MEMORY
CKR[CKR_HOST_MEMORY] = "CKR_HOST_MEMORY"

CKR_SLOT_ID_INVALID = PyKCS11.LowLevel.CKR_SLOT_ID_INVALID
CKR["CKR_SLOT_ID_INVALID"] = CKR_SLOT_ID_INVALID
CKR[CKR_SLOT_ID_INVALID] = "CKR_SLOT_ID_INVALID"

CKR_GENERAL_ERROR = PyKCS11.LowLevel.CKR_GENERAL_ERROR
CKR["CKR_GENERAL_ERROR"] = CKR_GENERAL_ERROR
CKR[CKR_GENERAL_ERROR] = "CKR_GENERAL_ERROR"

CKR_FUNCTION_FAILED = PyKCS11.LowLevel.CKR_FUNCTION_FAILED
CKR["CKR_FUNCTION_FAILED"] = CKR_FUNCTION_FAILED
CKR[CKR_FUNCTION_FAILED] = "CKR_FUNCTION_FAILED"

CKR_ARGUMENTS_BAD = PyKCS11.LowLevel.CKR_ARGUMENTS_BAD
CKR["CKR_ARGUMENTS_BAD"] = CKR_ARGUMENTS_BAD
CKR[CKR_ARGUMENTS_BAD] = "CKR_ARGUMENTS_BAD"

CKR_NO_EVENT = PyKCS11.LowLevel.CKR_NO_EVENT
CKR["CKR_NO_EVENT"] = CKR_NO_EVENT
CKR[CKR_NO_EVENT] = "CKR_NO_EVENT"

CKR_NEED_TO_CREATE_THREADS = PyKCS11.LowLevel.CKR_NEED_TO_CREATE_THREADS
CKR["CKR_NEED_TO_CREATE_THREADS"] = CKR_NEED_TO_CREATE_THREADS
CKR[CKR_NEED_TO_CREATE_THREADS] = "CKR_NEED_TO_CREATE_THREADS"

CKR_CANT_LOCK = PyKCS11.LowLevel.CKR_CANT_LOCK
CKR["CKR_CANT_LOCK"] = CKR_CANT_LOCK
CKR[CKR_CANT_LOCK] = "CKR_CANT_LOCK"

CKR_ATTRIBUTE_READ_ONLY = PyKCS11.LowLevel.CKR_ATTRIBUTE_READ_ONLY
CKR["CKR_ATTRIBUTE_READ_ONLY"] = CKR_ATTRIBUTE_READ_ONLY
CKR[CKR_ATTRIBUTE_READ_ONLY] = "CKR_ATTRIBUTE_READ_ONLY"

CKR_ATTRIBUTE_SENSITIVE = PyKCS11.LowLevel.CKR_ATTRIBUTE_SENSITIVE
CKR["CKR_ATTRIBUTE_SENSITIVE"] = CKR_ATTRIBUTE_SENSITIVE
CKR[CKR_ATTRIBUTE_SENSITIVE] = "CKR_ATTRIBUTE_SENSITIVE"

CKR_ATTRIBUTE_TYPE_INVALID = PyKCS11.LowLevel.CKR_ATTRIBUTE_TYPE_INVALID
CKR["CKR_ATTRIBUTE_TYPE_INVALID"] = CKR_ATTRIBUTE_TYPE_INVALID
CKR[CKR_ATTRIBUTE_TYPE_INVALID] = "CKR_ATTRIBUTE_TYPE_INVALID"

CKR_ATTRIBUTE_VALUE_INVALID = PyKCS11.LowLevel.CKR_ATTRIBUTE_VALUE_INVALID
CKR["CKR_ATTRIBUTE_VALUE_INVALID"] = CKR_ATTRIBUTE_VALUE_INVALID
CKR[CKR_ATTRIBUTE_VALUE_INVALID] = "CKR_ATTRIBUTE_VALUE_INVALID"

CKR_DATA_INVALID = PyKCS11.LowLevel.CKR_DATA_INVALID
CKR["CKR_DATA_INVALID"] = CKR_DATA_INVALID
CKR[CKR_DATA_INVALID] = "CKR_DATA_INVALID"

CKR_DATA_LEN_RANGE = PyKCS11.LowLevel.CKR_DATA_LEN_RANGE
CKR["CKR_DATA_LEN_RANGE"] = CKR_DATA_LEN_RANGE
CKR[CKR_DATA_LEN_RANGE] = "CKR_DATA_LEN_RANGE"

CKR_DEVICE_ERROR = PyKCS11.LowLevel.CKR_DEVICE_ERROR
CKR["CKR_DEVICE_ERROR"] = CKR_DEVICE_ERROR
CKR[CKR_DEVICE_ERROR] = "CKR_DEVICE_ERROR"

CKR_DEVICE_MEMORY = PyKCS11.LowLevel.CKR_DEVICE_MEMORY
CKR["CKR_DEVICE_MEMORY"] = CKR_DEVICE_MEMORY
CKR[CKR_DEVICE_MEMORY] = "CKR_DEVICE_MEMORY"

CKR_DEVICE_REMOVED = PyKCS11.LowLevel.CKR_DEVICE_REMOVED
CKR["CKR_DEVICE_REMOVED"] = CKR_DEVICE_REMOVED
CKR[CKR_DEVICE_REMOVED] = "CKR_DEVICE_REMOVED"

CKR_ENCRYPTED_DATA_INVALID = PyKCS11.LowLevel.CKR_ENCRYPTED_DATA_INVALID
CKR["CKR_ENCRYPTED_DATA_INVALID"] = CKR_ENCRYPTED_DATA_INVALID
CKR[CKR_ENCRYPTED_DATA_INVALID] = "CKR_ENCRYPTED_DATA_INVALID"

CKR_ENCRYPTED_DATA_LEN_RANGE = PyKCS11.LowLevel.CKR_ENCRYPTED_DATA_LEN_RANGE
CKR["CKR_ENCRYPTED_DATA_LEN_RANGE"] = CKR_ENCRYPTED_DATA_LEN_RANGE
CKR[CKR_ENCRYPTED_DATA_LEN_RANGE] = "CKR_ENCRYPTED_DATA_LEN_RANGE"

CKR_FUNCTION_CANCELED = PyKCS11.LowLevel.CKR_FUNCTION_CANCELED
CKR["CKR_FUNCTION_CANCELED"] = CKR_FUNCTION_CANCELED
CKR[CKR_FUNCTION_CANCELED] = "CKR_FUNCTION_CANCELED"

CKR_FUNCTION_NOT_PARALLEL = PyKCS11.LowLevel.CKR_FUNCTION_NOT_PARALLEL
CKR["CKR_FUNCTION_NOT_PARALLEL"] = CKR_FUNCTION_NOT_PARALLEL
CKR[CKR_FUNCTION_NOT_PARALLEL] = "CKR_FUNCTION_NOT_PARALLEL"

CKR_FUNCTION_NOT_SUPPORTED = PyKCS11.LowLevel.CKR_FUNCTION_NOT_SUPPORTED
CKR["CKR_FUNCTION_NOT_SUPPORTED"] = CKR_FUNCTION_NOT_SUPPORTED
CKR[CKR_FUNCTION_NOT_SUPPORTED] = "CKR_FUNCTION_NOT_SUPPORTED"

CKR_KEY_HANDLE_INVALID = PyKCS11.LowLevel.CKR_KEY_HANDLE_INVALID
CKR["CKR_KEY_HANDLE_INVALID"] = CKR_KEY_HANDLE_INVALID
CKR[CKR_KEY_HANDLE_INVALID] = "CKR_KEY_HANDLE_INVALID"

CKR_KEY_SIZE_RANGE = PyKCS11.LowLevel.CKR_KEY_SIZE_RANGE
CKR["CKR_KEY_SIZE_RANGE"] = CKR_KEY_SIZE_RANGE
CKR[CKR_KEY_SIZE_RANGE] = "CKR_KEY_SIZE_RANGE"

CKR_KEY_TYPE_INCONSISTENT = PyKCS11.LowLevel.CKR_KEY_TYPE_INCONSISTENT
CKR["CKR_KEY_TYPE_INCONSISTENT"] = CKR_KEY_TYPE_INCONSISTENT
CKR[CKR_KEY_TYPE_INCONSISTENT] = "CKR_KEY_TYPE_INCONSISTENT"

CKR_KEY_NOT_NEEDED = PyKCS11.LowLevel.CKR_KEY_NOT_NEEDED
CKR["CKR_KEY_NOT_NEEDED"] = CKR_KEY_NOT_NEEDED
CKR[CKR_KEY_NOT_NEEDED] = "CKR_KEY_NOT_NEEDED"

CKR_KEY_CHANGED = PyKCS11.LowLevel.CKR_KEY_CHANGED
CKR["CKR_KEY_CHANGED"] = CKR_KEY_CHANGED
CKR[CKR_KEY_CHANGED] = "CKR_KEY_CHANGED"

CKR_KEY_NEEDED = PyKCS11.LowLevel.CKR_KEY_NEEDED
CKR["CKR_KEY_NEEDED"] = CKR_KEY_NEEDED
CKR[CKR_KEY_NEEDED] = "CKR_KEY_NEEDED"

CKR_KEY_INDIGESTIBLE = PyKCS11.LowLevel.CKR_KEY_INDIGESTIBLE
CKR["CKR_KEY_INDIGESTIBLE"] = CKR_KEY_INDIGESTIBLE
CKR[CKR_KEY_INDIGESTIBLE] = "CKR_KEY_INDIGESTIBLE"

CKR_KEY_FUNCTION_NOT_PERMITTED = PyKCS11.LowLevel.CKR_KEY_FUNCTION_NOT_PERMITTED
CKR["CKR_KEY_FUNCTION_NOT_PERMITTED"] = CKR_KEY_FUNCTION_NOT_PERMITTED
CKR[CKR_KEY_FUNCTION_NOT_PERMITTED] = "CKR_KEY_FUNCTION_NOT_PERMITTED"

CKR_KEY_NOT_WRAPPABLE = PyKCS11.LowLevel.CKR_KEY_NOT_WRAPPABLE
CKR["CKR_KEY_NOT_WRAPPABLE"] = CKR_KEY_NOT_WRAPPABLE
CKR[CKR_KEY_NOT_WRAPPABLE] = "CKR_KEY_NOT_WRAPPABLE"

CKR_KEY_UNEXTRACTABLE = PyKCS11.LowLevel.CKR_KEY_UNEXTRACTABLE
CKR["CKR_KEY_UNEXTRACTABLE"] = CKR_KEY_UNEXTRACTABLE
CKR[CKR_KEY_UNEXTRACTABLE] = "CKR_KEY_UNEXTRACTABLE"

CKR_MECHANISM_INVALID = PyKCS11.LowLevel.CKR_MECHANISM_INVALID
CKR["CKR_MECHANISM_INVALID"] = CKR_MECHANISM_INVALID
CKR[CKR_MECHANISM_INVALID] = "CKR_MECHANISM_INVALID"

CKR_MECHANISM_PARAM_INVALID = PyKCS11.LowLevel.CKR_MECHANISM_PARAM_INVALID
CKR["CKR_MECHANISM_PARAM_INVALID"] = CKR_MECHANISM_PARAM_INVALID
CKR[CKR_MECHANISM_PARAM_INVALID] = "CKR_MECHANISM_PARAM_INVALID"

CKR_OBJECT_HANDLE_INVALID = PyKCS11.LowLevel.CKR_OBJECT_HANDLE_INVALID
CKR["CKR_OBJECT_HANDLE_INVALID"] = CKR_OBJECT_HANDLE_INVALID
CKR[CKR_OBJECT_HANDLE_INVALID] = "CKR_OBJECT_HANDLE_INVALID"

CKR_OPERATION_ACTIVE = PyKCS11.LowLevel.CKR_OPERATION_ACTIVE
CKR["CKR_OPERATION_ACTIVE"] = CKR_OPERATION_ACTIVE
CKR[CKR_OPERATION_ACTIVE] = "CKR_OPERATION_ACTIVE"

CKR_OPERATION_NOT_INITIALIZED = PyKCS11.LowLevel.CKR_OPERATION_NOT_INITIALIZED
CKR["CKR_OPERATION_NOT_INITIALIZED"] = CKR_OPERATION_NOT_INITIALIZED
CKR[CKR_OPERATION_NOT_INITIALIZED] = "CKR_OPERATION_NOT_INITIALIZED"

CKR_PIN_INCORRECT = PyKCS11.LowLevel.CKR_PIN_INCORRECT
CKR["CKR_PIN_INCORRECT"] = CKR_PIN_INCORRECT
CKR[CKR_PIN_INCORRECT] = "CKR_PIN_INCORRECT"

CKR_PIN_INVALID = PyKCS11.LowLevel.CKR_PIN_INVALID
CKR["CKR_PIN_INVALID"] = CKR_PIN_INVALID
CKR[CKR_PIN_INVALID] = "CKR_PIN_INVALID"

CKR_PIN_LEN_RANGE = PyKCS11.LowLevel.CKR_PIN_LEN_RANGE
CKR["CKR_PIN_LEN_RANGE"] = CKR_PIN_LEN_RANGE
CKR[CKR_PIN_LEN_RANGE] = "CKR_PIN_LEN_RANGE"

CKR_PIN_EXPIRED = PyKCS11.LowLevel.CKR_PIN_EXPIRED
CKR["CKR_PIN_EXPIRED"] = CKR_PIN_EXPIRED
CKR[CKR_PIN_EXPIRED] = "CKR_PIN_EXPIRED"

CKR_PIN_LOCKED = PyKCS11.LowLevel.CKR_PIN_LOCKED
CKR["CKR_PIN_LOCKED"] = CKR_PIN_LOCKED
CKR[CKR_PIN_LOCKED] = "CKR_PIN_LOCKED"

CKR_SESSION_CLOSED = PyKCS11.LowLevel.CKR_SESSION_CLOSED
CKR["CKR_SESSION_CLOSED"] = CKR_SESSION_CLOSED
CKR[CKR_SESSION_CLOSED] = "CKR_SESSION_CLOSED"

CKR_SESSION_COUNT = PyKCS11.LowLevel.CKR_SESSION_COUNT
CKR["CKR_SESSION_COUNT"] = CKR_SESSION_COUNT
CKR[CKR_SESSION_COUNT] = "CKR_SESSION_COUNT"

CKR_SESSION_HANDLE_INVALID = PyKCS11.LowLevel.CKR_SESSION_HANDLE_INVALID
CKR["CKR_SESSION_HANDLE_INVALID"] = CKR_SESSION_HANDLE_INVALID
CKR[CKR_SESSION_HANDLE_INVALID] = "CKR_SESSION_HANDLE_INVALID"

CKR_SESSION_PARALLEL_NOT_SUPPORTED = PyKCS11.LowLevel.CKR_SESSION_PARALLEL_NOT_SUPPORTED
CKR["CKR_SESSION_PARALLEL_NOT_SUPPORTED"] = CKR_SESSION_PARALLEL_NOT_SUPPORTED
CKR[CKR_SESSION_PARALLEL_NOT_SUPPORTED] = "CKR_SESSION_PARALLEL_NOT_SUPPORTED"

CKR_SESSION_READ_ONLY = PyKCS11.LowLevel.CKR_SESSION_READ_ONLY
CKR["CKR_SESSION_READ_ONLY"] = CKR_SESSION_READ_ONLY
CKR[CKR_SESSION_READ_ONLY] = "CKR_SESSION_READ_ONLY"

CKR_SESSION_EXISTS = PyKCS11.LowLevel.CKR_SESSION_EXISTS
CKR["CKR_SESSION_EXISTS"] = CKR_SESSION_EXISTS
CKR[CKR_SESSION_EXISTS] = "CKR_SESSION_EXISTS"

CKR_SESSION_READ_ONLY_EXISTS = PyKCS11.LowLevel.CKR_SESSION_READ_ONLY_EXISTS
CKR["CKR_SESSION_READ_ONLY_EXISTS"] = CKR_SESSION_READ_ONLY_EXISTS
CKR[CKR_SESSION_READ_ONLY_EXISTS] = "CKR_SESSION_READ_ONLY_EXISTS"

CKR_SESSION_READ_WRITE_SO_EXISTS = PyKCS11.LowLevel.CKR_SESSION_READ_WRITE_SO_EXISTS
CKR["CKR_SESSION_READ_WRITE_SO_EXISTS"] = CKR_SESSION_READ_WRITE_SO_EXISTS
CKR[CKR_SESSION_READ_WRITE_SO_EXISTS] = "CKR_SESSION_READ_WRITE_SO_EXISTS"

CKR_SIGNATURE_INVALID = PyKCS11.LowLevel.CKR_SIGNATURE_INVALID
CKR["CKR_SIGNATURE_INVALID"] = CKR_SIGNATURE_INVALID
CKR[CKR_SIGNATURE_INVALID] = "CKR_SIGNATURE_INVALID"

CKR_SIGNATURE_LEN_RANGE = PyKCS11.LowLevel.CKR_SIGNATURE_LEN_RANGE
CKR["CKR_SIGNATURE_LEN_RANGE"] = CKR_SIGNATURE_LEN_RANGE
CKR[CKR_SIGNATURE_LEN_RANGE] = "CKR_SIGNATURE_LEN_RANGE"

CKR_TEMPLATE_INCOMPLETE = PyKCS11.LowLevel.CKR_TEMPLATE_INCOMPLETE
CKR["CKR_TEMPLATE_INCOMPLETE"] = CKR_TEMPLATE_INCOMPLETE
CKR[CKR_TEMPLATE_INCOMPLETE] = "CKR_TEMPLATE_INCOMPLETE"

CKR_TEMPLATE_INCONSISTENT = PyKCS11.LowLevel.CKR_TEMPLATE_INCONSISTENT
CKR["CKR_TEMPLATE_INCONSISTENT"] = CKR_TEMPLATE_INCONSISTENT
CKR[CKR_TEMPLATE_INCONSISTENT] = "CKR_TEMPLATE_INCONSISTENT"

CKR_TOKEN_NOT_PRESENT = PyKCS11.LowLevel.CKR_TOKEN_NOT_PRESENT
CKR["CKR_TOKEN_NOT_PRESENT"] = CKR_TOKEN_NOT_PRESENT
CKR[CKR_TOKEN_NOT_PRESENT] = "CKR_TOKEN_NOT_PRESENT"

CKR_TOKEN_NOT_RECOGNIZED = PyKCS11.LowLevel.CKR_TOKEN_NOT_RECOGNIZED
CKR["CKR_TOKEN_NOT_RECOGNIZED"] = CKR_TOKEN_NOT_RECOGNIZED
CKR[CKR_TOKEN_NOT_RECOGNIZED] = "CKR_TOKEN_NOT_RECOGNIZED"

CKR_TOKEN_WRITE_PROTECTED = PyKCS11.LowLevel.CKR_TOKEN_WRITE_PROTECTED
CKR["CKR_TOKEN_WRITE_PROTECTED"] = CKR_TOKEN_WRITE_PROTECTED
CKR[CKR_TOKEN_WRITE_PROTECTED] = "CKR_TOKEN_WRITE_PROTECTED"

CKR_UNWRAPPING_KEY_HANDLE_INVALID = PyKCS11.LowLevel.CKR_UNWRAPPING_KEY_HANDLE_INVALID
CKR["CKR_UNWRAPPING_KEY_HANDLE_INVALID"] = CKR_UNWRAPPING_KEY_HANDLE_INVALID
CKR[CKR_UNWRAPPING_KEY_HANDLE_INVALID] = "CKR_UNWRAPPING_KEY_HANDLE_INVALID"

CKR_UNWRAPPING_KEY_SIZE_RANGE = PyKCS11.LowLevel.CKR_UNWRAPPING_KEY_SIZE_RANGE
CKR["CKR_UNWRAPPING_KEY_SIZE_RANGE"] = CKR_UNWRAPPING_KEY_SIZE_RANGE
CKR[CKR_UNWRAPPING_KEY_SIZE_RANGE] = "CKR_UNWRAPPING_KEY_SIZE_RANGE"

CKR_UNWRAPPING_KEY_TYPE_INCONSISTENT = (
    PyKCS11.LowLevel.CKR_UNWRAPPING_KEY_TYPE_INCONSISTENT
)
CKR["CKR_UNWRAPPING_KEY_TYPE_INCONSISTENT"] = CKR_UNWRAPPING_KEY_TYPE_INCONSISTENT
CKR[CKR_UNWRAPPING_KEY_TYPE_INCONSISTENT] = "CKR_UNWRAPPING_KEY_TYPE_INCONSISTENT"

CKR_USER_ALREADY_LOGGED_IN = PyKCS11.LowLevel.CKR_USER_ALREADY_LOGGED_IN
CKR["CKR_USER_ALREADY_LOGGED_IN"] = CKR_USER_ALREADY_LOGGED_IN
CKR[CKR_USER_ALREADY_LOGGED_IN] = "CKR_USER_ALREADY_LOGGED_IN"

CKR_USER_NOT_LOGGED_IN = PyKCS11.LowLevel.CKR_USER_NOT_LOGGED_IN
CKR["CKR_USER_NOT_LOGGED_IN"] = CKR_USER_NOT_LOGGED_IN
CKR[CKR_USER_NOT_LOGGED_IN] = "CKR_USER_NOT_LOGGED_IN"

CKR_USER_PIN_NOT_INITIALIZED = PyKCS11.LowLevel.CKR_USER_PIN_NOT_INITIALIZED
CKR["CKR_USER_PIN_NOT_INITIALIZED"] = CKR_USER_PIN_NOT_INITIALIZED
CKR[CKR_USER_PIN_NOT_INITIALIZED] = "CKR_USER_PIN_NOT_INITIALIZED"

CKR_USER_TYPE_INVALID = PyKCS11.LowLevel.CKR_USER_TYPE_INVALID
CKR["CKR_USER_TYPE_INVALID"] = CKR_USER_TYPE_INVALID
CKR[CKR_USER_TYPE_INVALID] = "CKR_USER_TYPE_INVALID"

CKR_USER_ANOTHER_ALREADY_LOGGED_IN = PyKCS11.LowLevel.CKR_USER_ANOTHER_ALREADY_LOGGED_IN
CKR["CKR_USER_ANOTHER_ALREADY_LOGGED_IN"] = CKR_USER_ANOTHER_ALREADY_LOGGED_IN
CKR[CKR_USER_ANOTHER_ALREADY_LOGGED_IN] = "CKR_USER_ANOTHER_ALREADY_LOGGED_IN"

CKR_USER_TOO_MANY_TYPES = PyKCS11.LowLevel.CKR_USER_TOO_MANY_TYPES
CKR["CKR_USER_TOO_MANY_TYPES"] = CKR_USER_TOO_MANY_TYPES
CKR[CKR_USER_TOO_MANY_TYPES] = "CKR_USER_TOO_MANY_TYPES"

CKR_WRAPPED_KEY_INVALID = PyKCS11.LowLevel.CKR_WRAPPED_KEY_INVALID
CKR["CKR_WRAPPED_KEY_INVALID"] = CKR_WRAPPED_KEY_INVALID
CKR[CKR_WRAPPED_KEY_INVALID] = "CKR_WRAPPED_KEY_INVALID"

CKR_WRAPPED_KEY_LEN_RANGE = PyKCS11.LowLevel.CKR_WRAPPED_KEY_LEN_RANGE
CKR["CKR_WRAPPED_KEY_LEN_RANGE"] = CKR_WRAPPED_KEY_LEN_RANGE
CKR[CKR_WRAPPED_KEY_LEN_RANGE] = "CKR_WRAPPED_KEY_LEN_RANGE"

CKR_WRAPPING_KEY_HANDLE_INVALID = PyKCS11.LowLevel.CKR_WRAPPING_KEY_HANDLE_INVALID
CKR["CKR_WRAPPING_KEY_HANDLE_INVALID"] = CKR_WRAPPING_KEY_HANDLE_INVALID
CKR[CKR_WRAPPING_KEY_HANDLE_INVALID] = "CKR_WRAPPING_KEY_HANDLE_INVALID"

CKR_WRAPPING_KEY_SIZE_RANGE = PyKCS11.LowLevel.CKR_WRAPPING_KEY_SIZE_RANGE
CKR["CKR_WRAPPING_KEY_SIZE_RANGE"] = CKR_WRAPPING_KEY_SIZE_RANGE
CKR[CKR_WRAPPING_KEY_SIZE_RANGE] = "CKR_WRAPPING_KEY_SIZE_RANGE"

CKR_WRAPPING_KEY_TYPE_INCONSISTENT = PyKCS11.LowLevel.CKR_WRAPPING_KEY_TYPE_INCONSISTENT
CKR["CKR_WRAPPING_KEY_TYPE_INCONSISTENT"] = CKR_WRAPPING_KEY_TYPE_INCONSISTENT
CKR[CKR_WRAPPING_KEY_TYPE_INCONSISTENT] = "CKR_WRAPPING_KEY_TYPE_INCONSISTENT"

CKR_RANDOM_SEED_NOT_SUPPORTED = PyKCS11.LowLevel.CKR_RANDOM_SEED_NOT_SUPPORTED
CKR["CKR_RANDOM_SEED_NOT_SUPPORTED"] = CKR_RANDOM_SEED_NOT_SUPPORTED
CKR[CKR_RANDOM_SEED_NOT_SUPPORTED] = "CKR_RANDOM_SEED_NOT_SUPPORTED"

CKR_RANDOM_NO_RNG = PyKCS11.LowLevel.CKR_RANDOM_NO_RNG
CKR["CKR_RANDOM_NO_RNG"] = CKR_RANDOM_NO_RNG
CKR[CKR_RANDOM_NO_RNG] = "CKR_RANDOM_NO_RNG"

CKR_DOMAIN_PARAMS_INVALID = PyKCS11.LowLevel.CKR_DOMAIN_PARAMS_INVALID
CKR["CKR_DOMAIN_PARAMS_INVALID"] = CKR_DOMAIN_PARAMS_INVALID
CKR[CKR_DOMAIN_PARAMS_INVALID] = "CKR_DOMAIN_PARAMS_INVALID"

CKR_CURVE_NOT_SUPPORTED = PyKCS11.LowLevel.CKR_CURVE_NOT_SUPPORTED
CKR["CKR_CURVE_NOT_SUPPORTED"] = CKR_CURVE_NOT_SUPPORTED
CKR[CKR_CURVE_NOT_SUPPORTED] = "CKR_CURVE_NOT_SUPPORTED"

CKR_BUFFER_TOO_SMALL = PyKCS11.LowLevel.CKR_BUFFER_TOO_SMALL
CKR["CKR_BUFFER_TOO_SMALL"] = CKR_BUFFER_TOO_SMALL
CKR[CKR_BUFFER_TOO_SMALL] = "CKR_BUFFER_TOO_SMALL"

CKR_SAVED_STATE_INVALID = PyKCS11.LowLevel.CKR_SAVED_STATE_INVALID
CKR["CKR_SAVED_STATE_INVALID"] = CKR_SAVED_STATE_INVALID
CKR[CKR_SAVED_STATE_INVALID] = "CKR_SAVED_STATE_INVALID"

CKR_INFORMATION_SENSITIVE = PyKCS11.LowLevel.CKR_INFORMATION_SENSITIVE
CKR["CKR_INFORMATION_SENSITIVE"] = CKR_INFORMATION_SENSITIVE
CKR[CKR_INFORMATION_SENSITIVE] = "CKR_INFORMATION_SENSITIVE"

CKR_STATE_UNSAVEABLE = PyKCS11.LowLevel.CKR_STATE_UNSAVEABLE
CKR["CKR_STATE_UNSAVEABLE"] = CKR_STATE_UNSAVEABLE
CKR[CKR_STATE_UNSAVEABLE] = "CKR_STATE_UNSAVEABLE"

CKR_CRYPTOKI_NOT_INITIALIZED = PyKCS11.LowLevel.CKR_CRYPTOKI_NOT_INITIALIZED
CKR["CKR_CRYPTOKI_NOT_INITIALIZED"] = CKR_CRYPTOKI_NOT_INITIALIZED
CKR[CKR_CRYPTOKI_NOT_INITIALIZED] = "CKR_CRYPTOKI_NOT_INITIALIZED"

CKR_CRYPTOKI_ALREADY_INITIALIZED = PyKCS11.LowLevel.CKR_CRYPTOKI_ALREADY_INITIALIZED
CKR["CKR_CRYPTOKI_ALREADY_INITIALIZED"] = CKR_CRYPTOKI_ALREADY_INITIALIZED
CKR[CKR_CRYPTOKI_ALREADY_INITIALIZED] = "CKR_CRYPTOKI_ALREADY_INITIALIZED"

CKR_MUTEX_BAD = PyKCS11.LowLevel.CKR_MUTEX_BAD
CKR["CKR_MUTEX_BAD"] = CKR_MUTEX_BAD
CKR[CKR_MUTEX_BAD] = "CKR_MUTEX_BAD"

CKR_MUTEX_NOT_LOCKED = PyKCS11.LowLevel.CKR_MUTEX_NOT_LOCKED
CKR["CKR_MUTEX_NOT_LOCKED"] = CKR_MUTEX_NOT_LOCKED
CKR[CKR_MUTEX_NOT_LOCKED] = "CKR_MUTEX_NOT_LOCKED"

CKR_NEW_PIN_MODE = PyKCS11.LowLevel.CKR_NEW_PIN_MODE
CKR["CKR_NEW_PIN_MODE"] = CKR_NEW_PIN_MODE
CKR[CKR_NEW_PIN_MODE] = "CKR_NEW_PIN_MODE"

CKR_NEXT_OTP = PyKCS11.LowLevel.CKR_NEXT_OTP
CKR["CKR_NEXT_OTP"] = CKR_NEXT_OTP
CKR[CKR_NEXT_OTP] = "CKR_NEXT_OTP"

CKR_EXCEEDED_MAX_ITERATIONS = PyKCS11.LowLevel.CKR_EXCEEDED_MAX_ITERATIONS
CKR["CKR_EXCEEDED_MAX_ITERATIONS"] = CKR_EXCEEDED_MAX_ITERATIONS
CKR[CKR_EXCEEDED_MAX_ITERATIONS] = "CKR_EXCEEDED_MAX_ITERATIONS"

CKR_FIPS_SELF_TEST_FAILED = PyKCS11.LowLevel.CKR_FIPS_SELF_TEST_FAILED
CKR["CKR_FIPS_SELF_TEST_FAILED"] = CKR_FIPS_SELF_TEST_FAILED
CKR[CKR_FIPS_SELF_TEST_FAILED] = "CKR_FIPS_SELF_TEST_FAILED"

CKR_LIBRARY_LOAD_FAILED = PyKCS11.LowLevel.CKR_LIBRARY_LOAD_FAILED
CKR["CKR_LIBRARY_LOAD_FAILED"] = CKR_LIBRARY_LOAD_FAILED
CKR[CKR_LIBRARY_LOAD_FAILED] = "CKR_LIBRARY_LOAD_FAILED"

CKR_PIN_TOO_WEAK = PyKCS11.LowLevel.CKR_PIN_TOO_WEAK
CKR["CKR_PIN_TOO_WEAK"] = CKR_PIN_TOO_WEAK
CKR[CKR_PIN_TOO_WEAK] = "CKR_PIN_TOO_WEAK"

CKR_PUBLIC_KEY_INVALID = PyKCS11.LowLevel.CKR_PUBLIC_KEY_INVALID
CKR["CKR_PUBLIC_KEY_INVALID"] = CKR_PUBLIC_KEY_INVALID
CKR[CKR_PUBLIC_KEY_INVALID] = "CKR_PUBLIC_KEY_INVALID"

CKR_FUNCTION_REJECTED = PyKCS11.LowLevel.CKR_FUNCTION_REJECTED
CKR["CKR_FUNCTION_REJECTED"] = CKR_FUNCTION_REJECTED
CKR[CKR_FUNCTION_REJECTED] = "CKR_FUNCTION_REJECTED"

CKR_VENDOR_DEFINED = PyKCS11.LowLevel.CKR_VENDOR_DEFINED

# CKF constants
CKF = {}
CKF_LIBRARY_CANT_CREATE_OS_THREADS = PyKCS11.LowLevel.CKF_LIBRARY_CANT_CREATE_OS_THREADS
CKF["CKF_LIBRARY_CANT_CREATE_OS_THREADS"] = CKF_LIBRARY_CANT_CREATE_OS_THREADS
CKF[CKF_LIBRARY_CANT_CREATE_OS_THREADS] = "CKF_LIBRARY_CANT_CREATE_OS_THREADS"

CKF_OS_LOCKING_OK = PyKCS11.LowLevel.CKF_OS_LOCKING_OK
CKF["CKF_OS_LOCKING_OK"] = CKF_OS_LOCKING_OK
CKF[CKF_OS_LOCKING_OK] = "CKF_OS_LOCKING_OK"

CKF_DONT_BLOCK = PyKCS11.LowLevel.CKF_DONT_BLOCK
CKF["CKF_DONT_BLOCK"] = CKF_DONT_BLOCK
CKF[CKF_DONT_BLOCK] = "CKF_DONT_BLOCK"


# CKG constants
CKG = {}
CKG_MGF1_SHA224 = PyKCS11.LowLevel.CKG_MGF1_SHA224
CKG["CKG_MGF1_SHA224"] = CKG_MGF1_SHA224
CKG[CKG_MGF1_SHA224] = "CKG_MGF1_SHA224"


# CKZ constants
CKZ = {}
CKZ_DATA_SPECIFIED = PyKCS11.LowLevel.CKZ_DATA_SPECIFIED
CKZ["CKZ_DATA_SPECIFIED"] = CKZ_DATA_SPECIFIED
CKZ[CKZ_DATA_SPECIFIED] = "CKZ_DATA_SPECIFIED"


# CKD constants
CKD = {}
CKD_NULL = PyKCS11.LowLevel.CKD_NULL
CKD["CKD_NULL"] = CKD_NULL
CKD[CKD_NULL] = "CKD_NULL"

CKD_SHA1_KDF = PyKCS11.LowLevel.CKD_SHA1_KDF
CKD["CKD_SHA1_KDF"] = CKD_SHA1_KDF
CKD[CKD_SHA1_KDF] = "CKD_SHA1_KDF"

CKD_SHA1_KDF_ASN1 = PyKCS11.LowLevel.CKD_SHA1_KDF_ASN1
CKD["CKD_SHA1_KDF_ASN1"] = CKD_SHA1_KDF_ASN1
CKD[CKD_SHA1_KDF_ASN1] = "CKD_SHA1_KDF_ASN1"

CKD_SHA1_KDF_CONCATENATE = PyKCS11.LowLevel.CKD_SHA1_KDF_CONCATENATE
CKD["CKD_SHA1_KDF_CONCATENATE"] = CKD_SHA1_KDF_CONCATENATE
CKD[CKD_SHA1_KDF_CONCATENATE] = "CKD_SHA1_KDF_CONCATENATE"

CKD_SHA224_KDF = PyKCS11.LowLevel.CKD_SHA224_KDF
CKD["CKD_SHA224_KDF"] = CKD_SHA224_KDF
CKD[CKD_SHA224_KDF] = "CKD_SHA224_KDF"

CKD_SHA256_KDF = PyKCS11.LowLevel.CKD_SHA256_KDF
CKD["CKD_SHA256_KDF"] = CKD_SHA256_KDF
CKD[CKD_SHA256_KDF] = "CKD_SHA256_KDF"

CKD_SHA384_KDF = PyKCS11.LowLevel.CKD_SHA384_KDF
CKD["CKD_SHA384_KDF"] = CKD_SHA384_KDF
CKD[CKD_SHA384_KDF] = "CKD_SHA384_KDF"

CKD_SHA512_KDF = PyKCS11.LowLevel.CKD_SHA512_KDF
CKD["CKD_SHA512_KDF"] = CKD_SHA512_KDF
CKD[CKD_SHA512_KDF] = "CKD_SHA512_KDF"

CKD_CPDIVERSIFY_KDF = PyKCS11.LowLevel.CKD_CPDIVERSIFY_KDF
CKD["CKD_CPDIVERSIFY_KDF"] = CKD_CPDIVERSIFY_KDF
CKD[CKD_CPDIVERSIFY_KDF] = "CKD_CPDIVERSIFY_KDF"

CKD_SHA3_224_KDF = PyKCS11.LowLevel.CKD_SHA3_224_KDF
CKD["CKD_SHA3_224_KDF"] = CKD_SHA3_224_KDF
CKD[CKD_SHA3_224_KDF] = "CKD_SHA3_224_KDF"

CKD_SHA3_256_KDF = PyKCS11.LowLevel.CKD_SHA3_256_KDF
CKD["CKD_SHA3_256_KDF"] = CKD_SHA3_256_KDF
CKD[CKD_SHA3_256_KDF] = "CKD_SHA3_256_KDF"

CKD_SHA3_384_KDF = PyKCS11.LowLevel.CKD_SHA3_384_KDF
CKD["CKD_SHA3_384_KDF"] = CKD_SHA3_384_KDF
CKD[CKD_SHA3_384_KDF] = "CKD_SHA3_384_KDF"

CKD_SHA3_512_KDF = PyKCS11.LowLevel.CKD_SHA3_512_KDF
CKD["CKD_SHA3_512_KDF"] = CKD_SHA3_512_KDF
CKD[CKD_SHA3_512_KDF] = "CKD_SHA3_512_KDF"

CKD_SHA1_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA1_KDF_SP800
CKD["CKD_SHA1_KDF_SP800"] = CKD_SHA1_KDF_SP800
CKD[CKD_SHA1_KDF_SP800] = "CKD_SHA1_KDF_SP800"

CKD_SHA224_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA224_KDF_SP800
CKD["CKD_SHA224_KDF_SP800"] = CKD_SHA224_KDF_SP800
CKD[CKD_SHA224_KDF_SP800] = "CKD_SHA224_KDF_SP800"

CKD_SHA256_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA256_KDF_SP800
CKD["CKD_SHA256_KDF_SP800"] = CKD_SHA256_KDF_SP800
CKD[CKD_SHA256_KDF_SP800] = "CKD_SHA256_KDF_SP800"

CKD_SHA384_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA384_KDF_SP800
CKD["CKD_SHA384_KDF_SP800"] = CKD_SHA384_KDF_SP800
CKD[CKD_SHA384_KDF_SP800] = "CKD_SHA384_KDF_SP800"

CKD_SHA512_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA512_KDF_SP800
CKD["CKD_SHA512_KDF_SP800"] = CKD_SHA512_KDF_SP800
CKD[CKD_SHA512_KDF_SP800] = "CKD_SHA512_KDF_SP800"

CKD_SHA3_224_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA3_224_KDF_SP800
CKD["CKD_SHA3_224_KDF_SP800"] = CKD_SHA3_224_KDF_SP800
CKD[CKD_SHA3_224_KDF_SP800] = "CKD_SHA3_224_KDF_SP800"

CKD_SHA3_256_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA3_256_KDF_SP800
CKD["CKD_SHA3_256_KDF_SP800"] = CKD_SHA3_256_KDF_SP800
CKD[CKD_SHA3_256_KDF_SP800] = "CKD_SHA3_256_KDF_SP800"

CKD_SHA3_384_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA3_384_KDF_SP800
CKD["CKD_SHA3_384_KDF_SP800"] = CKD_SHA3_384_KDF_SP800
CKD[CKD_SHA3_384_KDF_SP800] = "CKD_SHA3_384_KDF_SP800"

CKD_SHA3_512_KDF_SP800 = PyKCS11.LowLevel.CKD_SHA3_512_KDF_SP800
CKD["CKD_SHA3_512_KDF_SP800"] = CKD_SHA3_512_KDF_SP800
CKD[CKD_SHA3_512_KDF_SP800] = "CKD_SHA3_512_KDF_SP800"

CKD_BLAKE2B_160_KDF = PyKCS11.LowLevel.CKD_BLAKE2B_160_KDF
CKD["CKD_BLAKE2B_160_KDF"] = CKD_BLAKE2B_160_KDF
CKD[CKD_BLAKE2B_160_KDF] = "CKD_BLAKE2B_160_KDF"

CKD_BLAKE2B_256_KDF = PyKCS11.LowLevel.CKD_BLAKE2B_256_KDF
CKD["CKD_BLAKE2B_256_KDF"] = CKD_BLAKE2B_256_KDF
CKD[CKD_BLAKE2B_256_KDF] = "CKD_BLAKE2B_256_KDF"

CKD_BLAKE2B_384_KDF = PyKCS11.LowLevel.CKD_BLAKE2B_384_KDF
CKD["CKD_BLAKE2B_384_KDF"] = CKD_BLAKE2B_384_KDF
CKD[CKD_BLAKE2B_384_KDF] = "CKD_BLAKE2B_384_KDF"

CKD_BLAKE2B_512_KDF = PyKCS11.LowLevel.CKD_BLAKE2B_512_KDF
CKD["CKD_BLAKE2B_512_KDF"] = CKD_BLAKE2B_512_KDF
CKD[CKD_BLAKE2B_512_KDF] = "CKD_BLAKE2B_512_KDF"


# CKZ constants
CKZ = {}
CKZ_SALT_SPECIFIED = PyKCS11.LowLevel.CKZ_SALT_SPECIFIED
CKZ["CKZ_SALT_SPECIFIED"] = CKZ_SALT_SPECIFIED
CKZ[CKZ_SALT_SPECIFIED] = "CKZ_SALT_SPECIFIED"
